(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1331753,      23013]
NotebookOptionsPosition[   1324406,      22758]
NotebookOutlinePosition[   1326426,      22819]
CellTagsIndexPosition[   1326245,      22813]
WindowTitle->Automatic
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Code Summary and Visualization", "Title",
 Editable->True,
 CellOpen->True,
 TextAlignment->Center,
 CellTags->{
  "DiaryDate[{2015, 9, 10, 21, 44, 32.265350}]", 
   "CellGUID[97660343305484732195791915835262927755]"},
 CellID->887157224],

Cell[CellGroupData[{

Cell["Introduction", "Section",
 CellChangeTimes->{{3.650970138013183*^9, 3.65097014030788*^9}},
 CellID->180589747],

Cell["\<\
This notebook first summarizes the functions defined in the notebook \
\[OpenCurlyDoubleQuote]Semi-Analytic Approach\[CloseCurlyDoubleQuote] so that \
they can be used without needing to review and execute that notebook in its \
entirety.  Then particular visualizations are presented along with the \
methodology for exporting them to external files as TIFFs.\
\>", "Text",
 CellChangeTimes->{{3.650970144107945*^9, 3.650970155291191*^9}, {
  3.650970229276019*^9, 3.650970325045815*^9}},
 CellID->1893466378],

Cell["For all cases the disk has a (dimensionless) radius of 1. ", "Text",
 CellChangeTimes->{{3.65097326691854*^9, 3.650973282949799*^9}},
 CellID->920068908],

Cell[TextData[{
 "Note that in the execution of these functions warning messages may appear \
from the internal execution of the ",
 StyleBox["NIntegrate", "MB"],
 " function.  These are a consequence of the numerical integration symbolic \
pre-analysis encountering expressions that do not evaluate to purely \
numerical expressions\[LongDash]these warnings can be ignored. "
}], "Text",
 CellChangeTimes->{{3.6509749955563498`*^9, 3.650975124242313*^9}, {
  3.650984405211095*^9, 3.6509844151622972`*^9}},
 CellID->230290156]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discussion of exporting ", "Section",
 CellChangeTimes->{{3.650971832291875*^9, 3.650971836179525*^9}},
 CellID->1865458936],

Cell["\<\
If a graphic is assigned to a parameter then the graphic can be exported as a \
TIFF at a particular size and resolution as follows. \
\>", "Text",
 CellChangeTimes->{{3.6509718406423397`*^9, 3.650971903799758*^9}},
 CellID->1654574799],

Cell[TextData[{
 "Here is an example of a graphic assigned to the parameter ",
 StyleBox["myPlot", "MB"]
}], "Text",
 CellChangeTimes->{{3.6509719082475986`*^9, 3.650971927598682*^9}},
 CellID->1518235781],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myPlot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"EllipticK", "[", "x", "]"}]}], 
     RowBox[{"1", "+", 
      SuperscriptBox["x", "2"]}]], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "2"}], ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.650971929184827*^9, 3.650971994954974*^9}},
 CellID->505435398],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVV2c4Fn4bRaS0NElIEhkJGRGOEUUJWUlRFCIjW5K/iqhsMpKZkZVVsvpZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{-2, 1}, {0., 2.080871566833756}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.650971961078738*^9, 3.6509719954889717`*^9}, 
   3.6509745634981947`*^9},
 CellID->1860267114]
}, Open  ]],

Cell[TextData[{
 "Then Export it as follows to a file thePlot.tiff with an ",
 StyleBox["ImageSize", "MB"],
 " of 500 and an ",
 StyleBox["ImageResolution", "MB"],
 " of 300 (the TIFF file will be placed on your file system in the directory \
where this notebook is located; the file name should have the \
\[OpenCurlyDoubleQuote].tiff\[CloseCurlyDoubleQuote] suffix):"
}], "Text",
 CellChangeTimes->{{3.6509720002362223`*^9, 3.65097211997293*^9}, {
  3.650974895954852*^9, 3.6509749253133783`*^9}, {3.650981262146661*^9, 
  3.650981262368864*^9}},
 CellID->348050185],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<testPlot.tiff\>\""}],
      "}"}], "]"}], ",", "myPlot", ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650972024725526*^9, 3.650972029321805*^9}, {
  3.650974394139292*^9, 3.650974394513493*^9}, {3.6509748619974403`*^9, 
  3.650974881211886*^9}},
 CellID->663446425],

Cell[TextData[{
 "For each of the main visualization examples below the appropriate ",
 StyleBox["Export", "MB"],
 " function is also included."
}], "Text",
 CellChangeTimes->{{3.650974777552346*^9, 3.65097485152538*^9}, 
   3.650974934424961*^9},
 CellID->926003645],

Cell[TextData[{
 "You may also substitute the expressions like ",
 StyleBox["FileNameJoin[{NotebookDirectory[],\[CloseCurlyDoubleQuote]testPlot.\
tiff\[CloseCurlyDoubleQuote]}]", "MB"],
 " with a full path to a .tiff file that you wish."
}], "Text",
 CellChangeTimes->{{3.650981280992914*^9, 3.65098130727853*^9}},
 CellID->1739007708]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Section",
 CellChangeTimes->{{3.650910734893384*^9, 3.6509107371237593`*^9}},
 CellID->1454947651],

Cell[CellGroupData[{

Cell["Functions for fields and potentials", "Subsection",
 CellChangeTimes->{{3.65097132495829*^9, 3.650971330372635*^9}},
 CellID->2010225878],

Cell[CellGroupData[{

Cell["Here are the functions for a uniform ring charge", "Subsubsection",
 CellChangeTimes->{{3.650970764609665*^9, 3.650970779111369*^9}, 
   3.650974513944557*^9},
 CellID->248880934],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["radialChargeFactor", "MB"], "[", 
    RowBox[{"a_", ",", "\[Rho]_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{"2", " ", "\[Rho]"}], "a"]}], ";"}]], "Input",
 CellChangeTimes->{{3.6506577639376783`*^9, 3.650657778425453*^9}, {
   3.650658214296318*^9, 3.650658248414599*^9}, {3.6506588042440023`*^9, 
   3.650658822225803*^9}, {3.650730786908121*^9, 3.650730787836318*^9}, 
   3.650730826216053*^9, 3.650898706160748*^9},
 CellID->858673513],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f1", "[", "m_", "]"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"EllipticE", "[", 
       FractionBox[
        RowBox[{"2", " ", "m"}], 
        RowBox[{"1", "+", "m"}]], "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
      SqrtBox[
       RowBox[{"1", "+", "m"}]]}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6506578098725557`*^9, 3.650657896189987*^9}, {
   3.650658021035164*^9, 3.650658031127488*^9}, {3.650658312174068*^9, 
   3.65065832020749*^9}, 3.650731039628167*^9},
 CellID->259879548],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f2", "[", "m_", "]"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"EllipticE", "[", 
         FractionBox[
          RowBox[{"2", " ", "m"}], 
          RowBox[{"1", "+", "m"}]], "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
         RowBox[{"EllipticK", "[", 
          FractionBox[
           RowBox[{"2", " ", "m"}], 
           RowBox[{"1", "+", "m"}]], "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", "m", " ", 
      SqrtBox[
       RowBox[{"1", "+", "m"}]]}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6506578098725557`*^9, 3.650657909252202*^9}, {
   3.6506580496960773`*^9, 3.6506580705776653`*^9}, {3.650658321279385*^9, 
   3.6506583246551332`*^9}, 3.650731042790305*^9},
 CellID->312793153],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]", "[", 
    RowBox[{"a_", ",", "r_", ",", "\[Theta]_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{"2", " ", "a", " ", "r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["r", "2"]}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.6506583309067793`*^9, 3.6506583364912786`*^9}, {
   3.650658381109253*^9, 3.6506584187520447`*^9}, {3.6506585015769043`*^9, 
   3.650658504502246*^9}, 3.650970824456176*^9},
 CellID->1171745599],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExRing", "[", 
   RowBox[{"a_", ",", "r_", ",", "\[Theta]_", ",", "\[Rho]_"}], "]"}], ":=", 
  " ", 
  RowBox[{
   RowBox[{"radialChargeFactor", "[", 
    RowBox[{"a", ",", "\[Rho]"}], "]"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
        RowBox[{"a", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             SuperscriptBox["r", "2"], 
             SuperscriptBox["a", "2"]]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]], ")"}], 
      RowBox[{"f1", "[", 
       RowBox[{"\[Mu]", "[", 
        RowBox[{"a", ",", "r", ",", "\[Theta]"}], "]"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          FractionBox[
           SuperscriptBox["r", "2"], 
           SuperscriptBox["a", "2"]]}], ")"}], 
        RowBox[{"3", "/", "2"}]]], 
      RowBox[{"f2", "[", 
       RowBox[{"\[Mu]", "[", 
        RowBox[{"a", ",", "r", ",", "\[Theta]"}], "]"}], "]"}]}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.650658121579467*^9, 3.650658127075223*^9}, {
   3.650658275586061*^9, 3.650658277495064*^9}, {3.65065858260315*^9, 
   3.6506586134442453`*^9}, {3.650658762119834*^9, 3.650658790459303*^9}, {
   3.650658867089611*^9, 3.6506588749823103`*^9}, {3.650658988427607*^9, 
   3.6506589980096197`*^9}, 3.6507307953839903`*^9, {3.650731538288946*^9, 
   3.65073153871275*^9}, {3.650804924089272*^9, 3.6508049246711617`*^9}, {
   3.6508948468126383`*^9, 3.650894846962665*^9}, 3.6508987075297823`*^9, 
   3.650970483830285*^9},
 CellID->17249391],

Cell[BoxData[
 RowBox[{
  RowBox[{"EzRing", "[", 
   RowBox[{"a_", ",", "r_", ",", "\[Theta]_", ",", "\[Rho]_"}], "]"}], ":=", 
  " ", 
  RowBox[{
   RowBox[{"radialChargeFactor", "[", 
    RowBox[{"a", ",", "\[Rho]"}], "]"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      FractionBox[
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
       RowBox[{"a", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[
            SuperscriptBox["r", "2"], 
            SuperscriptBox["a", "2"]]}], ")"}], 
         RowBox[{"3", "/", "2"}]]}]], ")"}], 
     RowBox[{"f1", "[", 
      RowBox[{"\[Mu]", "[", 
       RowBox[{"a", ",", "r", ",", "\[Theta]"}], "]"}], "]"}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.650658927974042*^9, 3.650658961163094*^9}, {
   3.650659004746805*^9, 3.650659012818315*^9}, 3.650730797135723*^9, {
   3.6507315659931*^9, 3.650731566639855*^9}, {3.6508049265351477`*^9, 
   3.650804926775066*^9}, 3.650898708385182*^9, 3.650970485069113*^9},
 CellID->1455839901]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here are the functions for the electric field of the uniform charged disk\
\>", "Subsubsection",
 CellChangeTimes->{{3.650971046012376*^9, 3.650971057044208*^9}},
 CellID->340216895],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              RowBox[{
               SuperscriptBox["r", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}]}], " ", 
           RowBox[{"EllipticE", "[", 
            FractionBox[
             RowBox[{"4", " ", "a", " ", "r", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["r", "2"], "+", 
              RowBox[{"2", " ", "a", " ", "r", " ", 
               RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], "+", 
          RowBox[{
           RowBox[{"EllipticK", "[", 
            FractionBox[
             RowBox[{"4", " ", "a", " ", "r", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["r", "2"], "+", 
              RowBox[{"2", " ", "a", " ", "r", " ", 
               RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["r", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "r", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ")"}]}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", " ", "r", " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          FractionBox[
           SuperscriptBox["r", "2"], 
           SuperscriptBox["a", "2"]]}]], " ", 
        SuperscriptBox["r0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "-", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          FractionBox[
           RowBox[{"2", " ", "a", " ", "r", " ", 
            RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["r", "2"]}]]}]]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650659607726983*^9, 3.650659720983036*^9}, {
   3.650660199036735*^9, 3.6506602057557383`*^9}, {3.6508079857330017`*^9, 
   3.650807986014132*^9}, 3.65080815859853*^9, {3.650971532515733*^9, 
   3.650971535170795*^9}},
 CellID->805446546],

Cell[BoxData[
 RowBox[{
  RowBox[{"EzUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", "r", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"EllipticE", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
      RowBox[{"\[Pi]", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SuperscriptBox["r", "2"], 
          SuperscriptBox["a", "2"]]}]], " ", 
       SuperscriptBox["r0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}]]}]]}]], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650659607726983*^9, 3.650659720983036*^9}, 
   3.65066019498035*^9, {3.650807989702139*^9, 3.6508079900381527`*^9}, 
   3.650808159676626*^9, 3.6509715395890417`*^9},
 CellID->814147825],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", 
    RowBox[{"0", "|", "0.0"}]}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.650927785069584*^9, 3.6509277902197943`*^9}},
 CellID->1323435006],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", 
    RowBox[{"\[Pi]", "|", 
     RowBox[{"N", "[", "\[Pi]", "]"}]}]}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.650927785069584*^9, 3.6509277902197943`*^9}, 
   3.650927980592544*^9, {3.650928012437546*^9, 3.650928019059594*^9}},
 CellID->1704025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here are the functions for the electric field of the non-uniform charged disk\
\
\>", "Subsubsection",
 CellChangeTimes->{{3.6509102830855618`*^9, 3.650910327090646*^9}},
 CellID->472502647],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", " ", 
          SqrtBox[
           RowBox[{"1", "-", 
            FractionBox[
             SuperscriptBox["a", "2"], 
             SuperscriptBox["r0", "2"]]}]], " ", 
          RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"EllipticE", "[", 
              FractionBox[
               RowBox[{"4", " ", "a", " ", "r", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["r", "2"], "+", 
                RowBox[{"2", " ", "a", " ", "r", " ", 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], "-", 
            RowBox[{
             RowBox[{"EllipticK", "[", 
              FractionBox[
               RowBox[{"4", " ", "a", " ", "r", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["r", "2"], "+", 
                RowBox[{"2", " ", "a", " ", "r", " ", 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["r", "2"], "-", 
               RowBox[{"2", " ", "a", " ", "r", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ")"}]}],
          ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "r", " ", 
          SqrtBox[
           RowBox[{"1", "+", 
            FractionBox[
             SuperscriptBox["r", "2"], 
             SuperscriptBox["a", "2"]]}]], " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["r", "2"], "-", 
            RowBox[{"2", " ", "a", " ", "r", " ", 
             RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{"2", " ", "a", " ", "r", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["r", "2"]}]]}]]}], ")"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650659607726983*^9, 3.650659720983036*^9}, {
   3.650660199036735*^9, 3.6506602057557383`*^9}, {3.6506620057514353`*^9, 
   3.650662023850267*^9}, 3.650662943717815*^9, {3.650807997190048*^9, 
   3.650808004261982*^9}, 3.650808160732793*^9, 3.6509715413493443`*^9},
 CellID->493008203],

Cell[BoxData[
 RowBox[{
  RowBox[{"EzSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"6", " ", "r", " ", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["a", "2"], 
          SuperscriptBox["r0", "2"]]}]], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"EllipticE", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
      RowBox[{"\[Pi]", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SuperscriptBox["r", "2"], 
          SuperscriptBox["a", "2"]]}]], " ", 
       SuperscriptBox["r0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}]]}]]}]], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650659607726983*^9, 3.650659720983036*^9}, 
   3.65066019498035*^9, {3.65066201470468*^9, 3.650662038759881*^9}, 
   3.6506629552286386`*^9, {3.650808007549223*^9, 3.650808008853302*^9}, 
   3.65080816157265*^9, 3.650971542118136*^9},
 CellID->996957695],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", 
    RowBox[{"0", "|", "0.0"}]}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.650927785069584*^9, 3.6509277902197943`*^9}, 
   3.6509285036865063`*^9},
 CellID->861970878],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", 
    RowBox[{"\[Pi]", "|", 
     RowBox[{"N", "[", "\[Pi]", "]"}]}]}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.650927785069584*^9, 3.6509277902197943`*^9}, 
   3.650927980592544*^9, {3.650928012437546*^9, 3.650928019059594*^9}, 
   3.650928505054163*^9},
 CellID->219863884]
}, Open  ]],

Cell[CellGroupData[{

Cell["Here is the function for the potential for a uniform ring", \
"Subsubsection",
 CellChangeTimes->{{3.650894853649828*^9, 3.650894862585609*^9}, {
  3.6509712380688963`*^9, 3.650971250952511*^9}},
 CellID->610290968],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialRing", "[", 
   RowBox[{"a_", ",", "r_", ",", "\[Theta]_", ",", "\[Rho]_"}], "]"}], ":=", 
  " ", 
  RowBox[{
   RowBox[{
    StyleBox["radialChargeFactor", "MB"], "[", 
    RowBox[{"a", ",", "\[Rho]"}], "]"}], 
   FractionBox[
    RowBox[{"4", " ", "a", " ", 
     RowBox[{"EllipticK", "[", 
      FractionBox[
       RowBox[{"4", " ", "a", " ", "r", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["r", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
    RowBox[{
     SqrtBox[
      RowBox[{"1", "+", 
       FractionBox[
        SuperscriptBox["r", "2"], 
        SuperscriptBox["a", "2"]]}]], " ", 
     SqrtBox[
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"2", " ", "a", " ", "r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"]}]]}]]}]]}]}]], "Input",
 CellChangeTimes->{{3.650894868622616*^9, 3.650894893009386*^9}, 
   3.650898710761579*^9, 3.6508989458408527`*^9, 3.650970492188671*^9},
 CellID->116977404]
}, Open  ]],

Cell[CellGroupData[{

Cell["Here is the function for the potential of the uniform disk", \
"Subsubsection",
 CellChangeTimes->{{3.650910346931017*^9, 3.6509103621373053`*^9}, 
   3.6509710689158773`*^9},
 CellID->1840899936],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"8", " ", 
       RowBox[{"EllipticK", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
      RowBox[{"\[Pi]", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SuperscriptBox["r", "2"], 
          SuperscriptBox["a", "2"]]}]], " ", 
       SuperscriptBox["r0", "2"], " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}]]}]]}]], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650895087553069*^9, 3.6508951665150642`*^9}, 
   3.6508990189751797`*^9, 3.6509715431085377`*^9},
 CellID->1316350825],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialUniformDisk", "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", 
  RowBox[{"PotentialUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"z", ",", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}]]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.650895883511196*^9, 3.650895930537702*^9}},
 CellID->1562829634]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here is the function for the potential of the non-uniform disk\
\>", "Subsubsection",
 CellChangeTimes->{{3.650910346931017*^9, 3.6509103621373053`*^9}},
 CellID->817609279],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"12", " ", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["a", "2"], 
          SuperscriptBox["r0", "2"]]}]], " ", 
       RowBox[{"EllipticK", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
      RowBox[{"\[Pi]", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SuperscriptBox["r", "2"], 
          SuperscriptBox["a", "2"]]}]], " ", 
       SuperscriptBox["r0", "2"], " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}]]}]]}]], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650895087553069*^9, 3.6508951665150642`*^9}, 
   3.6508990189751797`*^9, {3.6509105026707363`*^9, 3.650910521736309*^9}, 
   3.650971544300733*^9},
 CellID->342221411],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialSqrtDisk", "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", 
  RowBox[{"PotentialSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"z", ",", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}]]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.650895883511196*^9, 3.650895930537702*^9}, {
  3.6509105069919977`*^9, 3.6509105083361177`*^9}},
 CellID->983919930]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Function that creates a 3-D field line plot [note that this function \
generates a plot that does not show the proper 3-D divergence of field lines \
at \[Infinity] \[LongDash] as discussed in emails]\
\>", "Subsubsection",
 CellChangeTimes->{{3.650910770068207*^9, 3.65091077761837*^9}, {
  3.6509122276184587`*^9, 3.6509122329589*^9}, {3.650971382018449*^9, 
  3.650971439551566*^9}},
 CellID->1712598878],

Cell[BoxData[
 RowBox[{
  RowBox[{"squareRootStreamPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"nXZLines_Integer", ",", "plotRadius_"}], "}"}], ",", 
    "nRotations_Integer"}], "]"}], ":=", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "sqrtStreamPlot", ",", "graphicsComplex", ",", "graphicsComplex3D", ",", 
      "revolutionDisk", ",", "fieldLines"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sqrtStreamPlot", "=", "\[IndentingNewLine]", 
      RowBox[{"StreamPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ExSqrtDisk", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SqrtBox[
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
            RowBox[{"ArcTan", "[", 
             RowBox[{"z", ",", "x"}], "]"}]}], "]"}], ",", 
          RowBox[{"EzSqrtDisk", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SqrtBox[
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
            RowBox[{"ArcTan", "[", 
             RowBox[{"z", ",", "x"}], "]"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "plotRadius"}], ",", "plotRadius"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "plotRadius"}], ",", "plotRadius"}], "}"}], ",", 
        RowBox[{"StreamPoints", "\[Rule]", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"n", "=", "nXZLines"}], "}"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"RotationMatrix", "[", " ", 
               RowBox[{"2", "\[Pi]", " ", 
                FractionBox["i", "n"]}], "]"}], ".", 
              RowBox[{"{", 
               RowBox[{"plotRadius", ",", "0"}], "}"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "0", ",", 
               RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"StreamStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Line\>\"", ",", 
           RowBox[{"Directive", "[", 
            RowBox[{"Red", ",", "Thick"}], "]"}]}], "}"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"graphicsComplex", "=", 
      RowBox[{"Cases", "[", 
       RowBox[{
       "sqrtStreamPlot", ",", "_GraphicsComplex", ",", "\[Infinity]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"graphicsComplex", "=", 
      RowBox[{"First", "[", "graphicsComplex", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"graphicsComplex3D", "=", 
      RowBox[{"graphicsComplex", "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x_", "?", "NumberQ"}], ",", 
          RowBox[{"z_", "?", "NumberQ"}]}], "}"}], "\[RuleDelayed]", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "z"}], "}"}]}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"revolutionDisk", "=", 
      RowBox[{"RevolutionPlot3D", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"ColorFunction", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "x", ",", "y", ",", "z", ",", "t", ",", "\[Theta]", ",", "r"}], 
            "}"}], ",", 
           RowBox[{"Blend", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"White", ",", 
               RowBox[{"Darker", "[", 
                RowBox[{"Blue", ",", "0"}], "]"}]}], "}"}], ",", 
             RowBox[{"Rescale", "[", 
              RowBox[{
               SqrtBox[
                RowBox[{"1", "-", 
                 SuperscriptBox["r", "2"]}]], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
        ",", 
        RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
        RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"fieldLines", "=", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n", "=", "nRotations"}], "}"}], ",", "\[IndentingNewLine]", 
        
        RowBox[{"Graphics3D", "[", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"GeometricTransformation", "[", 
            RowBox[{"graphicsComplex3D", ",", 
             RowBox[{"RotationTransform", "[", " ", 
              RowBox[{
               RowBox[{"i", " ", 
                FractionBox[
                 RowBox[{"2", "\[Pi]"}], "n"]}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], 
       "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"fieldLines", ",", "revolutionDisk", ",", 
       RowBox[{"Boxed", "\[Rule]", "True"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.650913522764955*^9, 3.650913526398478*^9}},
 CellID->926021805]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here is the function to generate an image of a non-uniform charge density\
\>", "Subsubsection",
 CellChangeTimes->{{3.6509711310001993`*^9, 3.650971161717347*^9}},
 CellID->1662874529],

Cell[BoxData[
 RowBox[{
  RowBox[{"revolutionDisk", "[", 
   RowBox[{"zCoord_", ",", "opacity_"}], "]"}], ":=", 
  RowBox[{"RevolutionPlot3D", "[", 
   RowBox[{"zCoord", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "x", ",", "y", ",", "z", ",", "t", ",", "\[Theta]", ",", "r"}], "}"}],
        ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"White", ",", 
           RowBox[{"Darker", "[", 
            RowBox[{"Blue", ",", "0"}], "]"}]}], "}"}], ",", 
         RowBox[{"Rescale", "[", 
          RowBox[{
           SqrtBox[
            RowBox[{"1", "-", 
             SuperscriptBox["r", "2"]}]], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], ",", 
    
    RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
    RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Opacity", "[", "opacity", "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.650751586671492*^9, {3.65075162596402*^9, 3.6507516323959417`*^9}, {
   3.650751664932559*^9, 3.6507517004653797`*^9}, {3.6507517357988787`*^9, 
   3.6507517543910847`*^9}, 3.650751988407057*^9, {3.650930080380415*^9, 
   3.650930081081628*^9}, {3.650931447609666*^9, 3.6509314484878674`*^9}, {
   3.650931621636223*^9, 3.650931629106642*^9}, {3.65093166203267*^9, 
   3.650931665812172*^9}, {3.6509317383194847`*^9, 3.650931750785306*^9}},
 CellID->1495100134],

Cell[BoxData[
 RowBox[{
  RowBox[{"revolutionDisk", "[", "]"}], ":=", 
  RowBox[{"revolutionDisk", "[", 
   RowBox[{"0", ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.650931457624112*^9, 3.650931463687875*^9}, {
  3.650931755726544*^9, 3.650931756021132*^9}},
 CellID->2003832896]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples of use of the functions in visualizations", "Section",
 CellChangeTimes->{{3.650912243333683*^9, 3.650912252413649*^9}, {
  3.650971371868391*^9, 3.650971375866702*^9}},
 CellID->701478177],

Cell[CellGroupData[{

Cell["Field lines in the x-z plane", "Subsection",
 CellChangeTimes->{{3.650912960373966*^9, 3.6509129660439453`*^9}},
 CellID->999040880],

Cell["\<\
Note that the number of nStreamlines should be divisible by 4 in order for \
this plot to show proper symmetry with respect to reflection across the axes.\
\
\>", "Text",
 CellChangeTimes->{{3.650971464127602*^9, 3.650971508427746*^9}},
 CellID->1216818166],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sqrtDiskStreamPlot", "=", "\[IndentingNewLine]", 
  RowBox[{"With", " ", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"nStreamlines", "=", "32"}], ",", "\[IndentingNewLine]", 
      RowBox[{"plotRadius", "=", "4"}], ",", "\[IndentingNewLine]", 
      RowBox[{"diskThickness", "=", "4"}]}], "\[IndentingNewLine]", "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"StreamPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ExSqrtDisk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SqrtBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"z", ",", "x"}], "]"}]}], "]"}], ",", 
        RowBox[{"EzSqrtDisk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SqrtBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"z", ",", "x"}], "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "plotRadius"}], ",", "plotRadius"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        RowBox[{"-", "plotRadius"}], ",", "plotRadius"}], "}"}], ",", 
      RowBox[{"StreamPoints", "\[Rule]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", "=", "nStreamlines"}], "}"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RotationMatrix", "[", " ", 
             RowBox[{"2", "\[Pi]", " ", 
              FractionBox["i", "n"]}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"plotRadius", ",", "0"}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"First", "@", 
         RowBox[{"Plot", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", 
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"ColorFunction", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x", ",", "y"}], "}"}], ",", 
              RowBox[{"Blend", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"White", ",", 
                  RowBox[{"Darker", "@", "Blue"}]}], "}"}], ",", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   SuperscriptBox["x", "2"]}], ")"}], 
                 RowBox[{"1", "/", "2"}]]}], "]"}]}], "]"}]}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", " ", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"AbsoluteThickness", "[", "diskThickness", "]"}], 
             "}"}]}]}], "]"}]}], "}"}]}], ",", 
      RowBox[{"StreamStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Line\>\"", ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Red", ",", "Thick"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "False"}], ",", 
      RowBox[{"RegionFunction", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "z", ",", "vx", ",", "vz", ",", "n"}], "}"}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}], "<", 
          SuperscriptBox["plotRadius", "2"]}]}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.650912989734029*^9, 3.650913097242257*^9}, {
   3.650915679184301*^9, 3.65091568111718*^9}, {3.650971346789497*^9, 
   3.650971358252121*^9}, 3.650971457642664*^9, {3.650972921506414*^9, 
   3.6509729221682243`*^9}},
 CellID->1331015451],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJx1XXdUFcnTBSQLgjnnHNectceEOSfMiWAWdVdBxYAYMYBZFMWsiBFRV9Fu
c8KAgVUEJYOI5Azi99iueb991/P5z54++5jprrrVM111b03dmYtG2Rvo6ekV
m+jplfx34cb9Sy31rJXNKQFp66Jc+BnjjseGrbRSViTop542GR3UYeIF/7KL
yigi6Wxbp+fzg5pvrPHeaZil8vFxywWHgp2DPBoVh293zGUN7kRvtP/sFVQ5
++6zBItsFl+/YoNv3/cGhRy5/PrIhCw2JX1c/0V+e4KuTi/lVq68hWK78Vli
anW3oL2J/c+63jRXLj5Yu7X83M1Bb8+MvjSvn7Fi52f2+dbtfUHOUUMObUo1
VAbcrvMqPetgUI/e/Wr8VWSm+A9ziKoe5hF0Mu3ZXo+2Zko9e59tb3buDHqe
+aHCvYmmyqZS5R8feOQVdHnwnIMV/zJROlbTc6odvztox8Jbj7q/KaWE5b68
NiXgcNCLKS+HPd5ioEw6MuT1l/CjQaYhe1037NVX7ux712VuvWNBjlXPsc9r
9ZTmT+9P9N5wPGhzYdqpLUN+sUkjltkVTjse5Np2+tr1k36yjWXDGzwVR4NC
nfZfWvelkHV7WPdR5mjvIJM1TatcblHAHGbvOdwzfXdQUs7z7z93ZbJV+lXL
m23zDMpOnzfm25UMFj60cqvXr3cEufdLdm3cPoMtfXGw7FJfzyB949rvTp5L
ZyktjTe0q7crKPj84sx/LNJZRHzF2Qv27ww6a1p7691raezI0HufzzfYHFRm
l9OA/SPTWMxe/yp5fhuDREzN28NCUtlm15XlGi57fyfyc3WPhVdSWURceKuq
zy05jvH3eD28H84H54vrwfWiPRAviCfEG9oX7Y/+Qf+hf9H/iA/ED+IT8Yv4
Q3wifhHfGB8YPxiPGK8Yz2c+T3RO/WWlWD2OvmmYdfy23r//rBU9+lfLy7ji
X3ZWiufV3q6vXyeyukMMLXIiyyiBj6vnrtqeyNw31dmy6Zulct21OP2gSGCt
j439tSvSQql3KSb0a2w8G9a264u8Ldns9fbEJVvsgtmFFjWMXq7MZG/rDN7p
q/+UuW0aH1f7XmmlZ1aH0fo5cWxL1vLJNzaZK3k7F038mRbLnGeb9Fi4yFiZ
nxgxLXRdFPO/FWO3t7mZssry2p46r2KY9cXT0zosMFVqBJqc9GkVw8b5PynO
PmGi5Oc28ruxIZoVrdlStmoFI+XZC8u0L5MiWcqV6EWXfpVSliwMaFgn6gsb
P7DlhOgnBsqT+KknEp6HM4vbDa6NDtVXepZtbBPb9DNr8MTGq9xjPcU8aulg
sxGfWD3DJgmJ736xdpmXL+YH/8OKr/T8aRP1kyUNbBV+vGwoy3id8S7AsYh9
Xh23fMSd90xp9uBtVFABG3grd3lMx3csq/TytBoL81nw8pFvI4pD2LV15pVO
ZOSyWItno8P2vvnNPmg//D1eD++H88H54npwvWgPtBfaE+2N/kP/oP/Qv4gH
xAviDfGIeC1/wvfcpplWyrinm6P88hLZ5cm5r/drxuan53S/qRl3fmbsFrfZ
Uhk366rH7OV57FPE27OnK1sqMXcSq8ZXzGOVPN+MetjJQvk5q3GvtDG5zNB8
euKrAaWVCi57Yq9szGHORscnsUdZbH/p/kvKm0Swrr4d3DJvZLCnSUURKWc+
so4fjl0d8SWNLQhb3zxq5nuWZ/WSPbYxV2brH+/pdSabdQjt/zaulZky1qSH
k1VgFvv6R81JzdYZKUeSvUXymnR25eWjuqsLTJSr9U5mlzuXyfoY17tXcbSJ
MvHKpEY9KmeymY7dL389bqyM+15xsJtrBvPZviNzTHdDpZ/RHgfbmWkspdGB
1wZdSylRDwcer1KUwk7PLhX/RxUDZWXc159JeclsslnVW7Nb6yu9SnvGV534
ncW2yq/8s7me8mOBQand7t9Y92YDRsX9XcxORXvbppROZMZ3rEpVSCxifbYd
rFxtejx7uK3Z+PHLC1nWE5dLs8ziWFzz5C5lP+azptc8bOe5xbBLcS3y5+zP
Y7PbPp36aHg0q1y2HUtslcuUqIYr66RHstzJy2vuck9hU282Vcy6vWGDHcsM
Cjv+nY2y2Nq147Mn7EngnyEtNH5a6HqjQWeTINbXvKvdlR6J7OWSntVmZAay
j3MexLV3TWA1Zjwz/LT4IgvPvziyzo145lUr/cw766Ps8MdLdauOimerO3bz
qpi2nXU9qV94qnM8s29Qq8rDIxuYW78uf9WuHc+OKp/qHJm5gtWJXxCxwSie
GZa2tzDwmcl6bQ/8ekCDO72oY/UbOV29i2P8PV4P74fzwfnienC9aA+0F9oT
8Yf4RPyif9B/6F/0P+ID8YP4QvwhPhG/iG+MF4wHjBeMJ4w/jE+Md9wPcL+4
2+HA/cmelkroZeerH1zzmM32tq/nacazzl08Ha0ZL8mJrRnvba4M8ah04cMT
fWXCueX7bu8xV95Hp8d439dXtvmVS3ZqrRm3fnGwcJW+4rFr3PIGc82Uygdc
R7fN1FPMqk/v92GfqeJ9d+/d5tP1lN1Wz3wGP0tj8QFLj/cxiGZNojLX+pdL
YQvcu9pOvxvBbAKqPhqQk8SeOC7/0unsP6zj+bEJLQNMlAGbU1oXuP1i32/x
jtFBxspQLxu7nGbFzOrjm0W7nPSVluXivmVeyWHP21Tct/GikbKvfaeosZeL
2JPnJ50G1TBSAqqZbyoTU8iW5wY7XnIzVJaVebi4XulC1qTM6n6urqWUky+i
895557PwuOZr+6YaKNeuD+1xMiSPuaQ5/hg8wUCZ+2uQW9Wfuazxhp15Xefr
KY63JrfY1iObOXRLLjO4wy8WtjSg3CerLHbaKb18+LSfzOTUrqAztzOYS+kv
AfEJhaxuut+l7LPprGjgvNUevQvYlR0PX0xcksbed63vF5+ex6a3qjXTIjWF
Fazy62rvnMtsl+s7pAUms6TkBUsvD85h0cMd9rVISmIHAse/WFSQxVYEJNU6
8CWRDRice351SibLbLrixMOOCewP5zYzmt7PYCEuY2bkjoz7zZ5ob/QH/j1e
H++P88P54/pw/WgftB/aF+2P/kd/oT/R34gHxAviCfGH+ES8YzxgvFxd+u2d
7SFzJSjVIL+NJr5OHCvT1EEzfjr7YpdumvG7coGfLQ4ZK+bu91eEehsrAzrt
Dh7W31i5drl85cg+xsrC1p2OGR81Uqr102+cu8dIWTdhTMy774bK3Z+fzi8L
M1TmuPnUTm6TzOYEPz3T4GY8u5li0za59jdm0GFAZMUr0Wyb3ql2ubPiWXLt
Pb3GnYlgIV0/O+Y0M1QcqvVbN6usoXItYMaLLRNLKa/s2j+71KmUUvFG10r7
r/xko+ocPTsjpYjFFz7q1GCZgXLWYdi19QMMlJPHi6cHF+grBpEDD1pp5t9w
cHzoJBd95dS5LktNmL6yeHZ895CDesrTQ/kH7EfrKZHel7Lb1dFT5tjXf+1z
6hfT++usnaXyi922P+JQfl8xKzpnYOyaVcgS4vW2Xi6nid/r3m+/bytg0wP6
vq3omc92n7G9lVyQx/x2V7M2j8hld2zuHTh1I5dZVu924c9VOexA13rGFYbl
sNHlvx98npLFTH13xQc2z2Z54bdrdPTPZOvez+2SGJ/JfvAHRYtYBnNreX+D
W3QGi66r59KocjobFL+o+niezq6VaTS0345UdmKYxc6WoWms6yC7JhFzfzBj
o8thm06kslXD4kWFoiR2buTKpXrZMWx0eGePLhVD2d/9M5MtXkSxDYcOmrUp
DmbO/1h6J/Gv7EuTf2zqJd9io8OWpq+/+YU9KBw71EtcYSe3Xmhn4hfBIrZV
791sxFH255qNNcfYRzDvzF4xNtF72M2QUzs71Ilgm1aXb3rc2Z1Zd9rUN6JM
BFvR5bGeR+PVbKL3w6mrf4azs/tKFXUcvpTN2rwrtkpyOHuRcipn5Jvp7Fy5
m+MvhoWz212UxAt2fTmO8fd4Pbwfzgfni+vB9aI90F5oT8Qr4hnxjv5B/6F/
0f+ID8QP4gvxh/hE/CK+Mb4wHjBeMJ4w3jAeMV4xvjH+cT/B/Qb3o1Vn5vTZ
7WusTL1/JnSX5r8vu61xOPKf/3Y1/fV2y2N9xdzlztcHmn0uYO+OmSma94iv
Tbtsual5r1jvH+kz0E1fCS1bO2iIZp/MGrg/s7BIT5n8a+tQsxlmSl/zNYNN
FukpV5I+upi6myrGD5eOqN07hnmEVTs5Y2ocm2tYOdischRb6dzBaUF4JHN0
iFz7dfwXNriV59Dtxp/Y9DI2nqv8f7HOBS3bPthrojxsGNqiz8xi5h24ffSL
3cbKkdB+TvN75LJ7veaFvk/XU+anNBozJ6+IVbjU6MtsZyPFN/jkW4MORSyj
aoGf+VdDpVzR5R/ZjoUs3rnx25gehkr92rWerTMqYIeO9+u5plEpJbBg1ucr
ffPZqG8zb1ruMFCyJpsZr3bJY/1Gtg+s8UNfWZh268jy8GzWW7/UtdOXfrFw
115HK/Es5lxuws3k2J+scEWf9e3WZrIMqyAT66hCVu1vj4wFazJYo9X7Yjb2
LGA3Ci6sdpmeznxHi9nZDnnsS0jW38dd0ljzoLwmcQk57FbBI6PFmufuiVVm
ftM7ZbMa7oub/hrxg529drCbyz+ZrH3Xbh9Hun1nvv0XHeg5MIPN3X7pTHiZ
JHbmhv/8gYbprKtd4tCvToms/ZLchg6NU9mxHj5DNjZIYB8yRgUYvkhmXV4O
8m4fEMeY6cWijOpJ7PX8dBueE8ZSNEs0XPvmtzH6A/2F/sTr4/1xfjh/XB+u
H+2D9kP7ov3RP+g/9C/iC/GAeEE8Id4Qj4hXxDfiH+MJ4w3jsV5TPd+2mn3k
Ws6rl7b/eU9R31tiMyflhWrODZG337WaojlHDHk6+Hm/Onlsd/rGdi2qWyri
b1FcbJfLVm6OruvY2kLJqnnVf4ZPDmtn/CU/tENpZfMHP+sW1z+xX7WXe4zW
7N97b5br0kaEssSaw5q3fRzFulwNGnWo4Xs2aJmTT2iVMHZ+wI/+/R5ns56D
LkRPamyuDGo2/P6qiCy24/7OljUNzJRtPj8S7G+ksufZjiOVkwbKuP5t2yVF
ZDKfKnNSxnET5WOP0LRzozPZxOub3MZbmyjjGqRfWaR5/43NrtGln62xktl+
bvGNF+ksZHqn68dqGSkzLTremtcvnY3q26TPzKWGSuyCGe7vb2jwkn55gvvd
UsqfvZNcRrz4weJ413ItHfWV+cNqh4/rmczCOnrZf7bXU9bmRX77yy2J1c+N
aey1uZhtrLjM/UbNbyxr7cVLHgFFLOXRmE6xOxKY/px2jb8eL2DNjLI+nhgW
z/ydf/i1zMljo+PyGnxIjGUd9AcNq1sul9mtnff9/bMY1jT+9fSszdlsc60x
ZQ9siWYp1qZVlOBMJn4cco/dHMU65/xxM2dGBvsxKmRajXmRrO1zo5ebnqSx
RtkZbhUsvrIjga1vD9DEQU1L3yEfrSKY7aXqXk2yvzPPH7fLX/oSwpb9+nnt
Yvobdv+feUsHPX3N+lqH+Qx5w9mc1r2+W/z9irWq+XKVx8RA9n7f4Ttzj79k
OaULa95of5KdX/Ih7cikl8xu3Y/AWscOs9xLLfpPr/CSZbj/ZXrYx5NdWPfl
2qXgYNYu0yin/9LFrJVTk4SO14PZ2ePlF790Z7+N8fd4Pbwfzgfni+vB9SLe
EI+IV7Qf2hftj/5B/6F/0f+ID8QP4gvxh/hE/GL8IN4xHjBeMJ5+izeIR4xf
jG/cL3A/wf0G9yM1r6HmOYJrni3nWeEb69qwRmrfGVZKiFgc2Nw7kTEf/W2j
Esoolod7D/z4LoF12Di2l3uspbKpT/CJzF/xbJ2T68jjry2UsYVLt3Rr9oz9
c+zBnvnb4lm7Pjdal+v2mHG39pPL2EUxt8Blt2r7PWDvU3u0vJP7kTk0SqkV
Vi2e9ehfOOTWidLKxKfxZ43rxbGfuz48mTLFXDmXcykw7u5XZhPSJSvEvpTi
v/9Ov8gvUeziraHB9lbGytZFFa5ePhzLbOpcNmh20Uw5MKtL92lWsSy81w3n
hlmmyqaTY/uXWxHD7ucmNR3xh6kytu2cd8/Co1lOr8GV/KaZKAsvNGm0aEwU
23a4YKDzeCMl8dKcF2PvR7J7yVXbl9prqJxbUfuu6/0Iln3HNHOstYHSdUq1
WjOahzP32x5HWvzUU0bZpmf0nxXGOq12vXFy+y92a3X6yMycj8yseG3P0IM/
WQfzNXfNpv3Dqn0YN93OvpBNHdOhqlPVUBbe3la/zZF85j18fczoC+/Zpo4N
nFceymVVlPhzX7a+YzFuXj5Ohdlsy+GbCwJt3rKKjQ0fuzTIYgM8Jgyt1zeE
lTlVNM3xdAabXvlm0cIGb1jB+62tV2WnsQrBg4L3u75iF/v2zXvbJJX194gc
F7I2mE3tbFqtlWkyGzRk5Yt/Ft5j/aYtNwwxfP3bGP2D/kP/4vXx/jg/nD+u
D9eP9kH7oX3R/ugf9B/6F/GGeEC8IB4RX4g/xCfiF/GP8YHxhvGI8fq4zJFF
/nmJrNE594Wb/1M3UesoHxMbDHHo7MxqjxrT/cMvK20d8WPMwUlBbv8bv6sz
Y3jFBWW048M5z2+n9rbUjp0MfI+s+jOOqePa+mOLNg6I1I7HnN5+bPnNUO14
4750e5vi0tq/7/Bt0ecYb3PtuPRio8NVB5fSjocKj5fmP42044ejbFvnhZlp
x9NmJYzOsvzf2KR6TZuP7Uy14zsu+cYnh5hox9X/SSte3+9/10vuWt5q3XpD
7dj3W7eWed/0teMEvXPC8K2edvyHw4lsy+a/tOvpbTCjRo/WP7XjwOsdm/6d
UaAdDzk484hF43zteO/IXtvW1srVjj8t8R3ouzJbOy57wL57vm+mdry0adG6
OnUztOPMF76r8hakaceP/dc7zamcoh2vsrz7yDQrSTvOqnv+5fglz7Vjm6HX
6n1adUk7XtL0zdhepnu043WH3i3o4L9OO57QY3PLribO/5tP0OkHj0bN0Y4n
T1huci253f87xt/j9fB+OB+cL64H8YX4Q3yifdB+aF+0P/oH/Yf+Rf8jPhA/
iC/EH+IT4wXxjHjHeML4wPjB+ML4w/jF+Mb9AvcT3G9adN8zNe0/+5H8Z61Y
VN5auO91Ij8UZHXmg532/YSr+52F3A+5uh9ulPslV/fL8fL5xT/S86ujfL7x
e/R82yiff/wjPf/s5f7Le9L+ayv3Z15E+7OffF7wAfS88JPPA36Bngeb5P7O
+9L+vlfu//wT7f/u8vnABT0fRsnnB8/SfT/h8H7C79PzyF8+v3gePb+YfL7x
TfR8Gyeff7w7Pf/uyucjt6DnY2f5/OQ16PlpJ5+vPIqer4fl85dvoedvNfl8
5rH0fPaQz29eiZ7fg+TznVvT832mfP7zInr+V5bvB/wqvR8MlO8PfCa9PwyV
7yN8AL2P4Bj9g/5D/+L18f44P5w/rg/Xj/ZB+6F90f7oH/Qf+hfxhnhAvCAe
EV+IP8Qn4hfxj/GB8YbxiPFK7ycc3k+4+n4yYverbX3X5PGTR9p3tfTUnl84
5FM45FM45FN4ezof7ZTnU25UR55PveX5lSfT+bW7PN/y4XS+9ZfnLc7ovDVE
nse4J53HdsnzIA+m8+AEeX7jvnR++yzPd3wKne8myPMfT6DzX448H/J3dD60
l+dHPobOjwnyfMlb0vlyhTyP8gQ6jy6R51UeTufVTfI8yxvTeXabPO/yHDrv
ZsnzMDek83AreV7mF+i8PEGep3lnOk87yPM2b0Ln7a3yPM7V8/h9eV7nXem8
nibP87w9nefryPM+96TzfgOZD+BTKR+wW+YX+CrKLwiZf+A1KP9gJ/MTPK2G
zE+8lPkLPobyFydlfoMbrpX5jTSZ/+BT1sv8x2mZH+GdEmV+pJHMn3DrnHL/
5k9wjL/H6+H9cD44X1wPrhfxhnhEvKL90L5of/QP+g/9i/5HfCB+EF+IP8Qn
4hfjB/GO8YDxgvH0W7xBPGL8YnzjfoH7Ce43uB9RPoWr+RSq7wio7wio74h/
KJ+cKfPNQs0395H5aHGJ8tF6sh7AV1E9wF7WC/gCqhdMlfUE3pbqCZNlfpt3
oPz2XZn/5nsp/71X5t/5Tcq/z5T5cm5J+fI9Mp/Ov1E+3Ujm2/lnyrdXkfl4
7kX5eD+Zr+cDKF+fJPP5vDvl8+1l/p+3pvz/e1kf4I5UH8iS9QMeTfWD8rK+
wCtRfeGKrD/w3VR/+CjrE7w21Scuy/oFP0j1C2tZ3+CHqb7RQtY/+AGqf8yU
9RHuS/WRtrJ+whtR/WSPrK/wu1RfaSvrL7wN1V+eynoO/0j1HByjP9Bf6E+8
/m/3h/nh/HF9uH60D9oP7Yv2R/+g/9C/iC/EA+IF8YR4QzwiXhHfiH+MJ4w3
jEeq7wio7wi1vkN8FAF8FBGgy0cRVXX5KOIO1Y+dZH2e/0n1eS7r97wM1e+9
ZH2fG9SR9f23sh4t1Hp0oKxXi9dUr64i6+V8PNXLE2V9W5yj+vZpWf8Wpaj+
3VjWx8UZqo8vlfVz8Zzq59Gyvi7mU329lKy/c07192JZr+fJVK9fIev53IHq
+ftkvZ9fpnr/XckH4NbEB/CWfAE+nvgCpSWfgP8kPoG75BvwTOIbuEs+Ao8n
PsIwyVfggvgKZySfgdsQn8FS8h34RuI7XJD8CT6b+BNc8iv4I+JXbJD8C+7Q
VPIvpkt+Bh9QJPkZVyR/g9fbKfkbayW/g5vkSH7HA8n/4MM3SP5HdckP4S0G
SH6IveSP8CZndfgo/GPD0//yS7wl/4Tr2Q39l3+CY/w9Xg/vh/PB+eJ6cL1o
D7QX2hPxinhGvKN/0H/oX/Q/4gPxg/hC/CE+Eb+Ib4wvjAeMF4wnjDeMR4xX
jG+Mf9xPcL/B/Yj4KAL4KELloxC/VQC/VQC/VXzQ5beKKrr8VnGI+H5ekk/J
Y4hPWU/yLbk98S37SD4mf6jLbxUDiT+YLPmFYjjxC60lv1Go/MYXko8o9hMf
8bnkK4rrxFd0kXxG4Ux8xqaS7yhUvuMXyYcUwG8Vc4gv2VTyK8Vs4lcukPxL
HkH8y/OSn8nNiJ+5SvI3eT3ib/6U/E6u8jtDJP+TT9Tlt/JxxA9NkfxRnkT8
0f2SX8qdiV86RPJPeSHxT1tJfip/Q/zUiAmfOpq2SuSR014Fem0PYdN2+cf4
nI/jSxPvH+ox8/FvY/w9+gP9hf7E++P8cP64Plw/2gfth/ZF+6N/0H+IH/Q3
4gHxgnhCvCEeEb+Ib4wXjCeMN+LHCuDHCpV3QnoYAXoYAXoYAXoYofLjl0o9
Ad9DeoIOUm/AH5LeoK3UI/DZunoYAXoYofLxv0h+v/DV1cMI0MOISbp6GDGe
+P/eUi8gVL3Ad6knENGkJzgh9QZiNekNbKUeQfQmPUKU1CuIFNIrdJF6Bn6W
9Ay/gv7VO/DepHe4K/UQPJP0EF+kXoI3Jr3Ecamn4DNJT1FW6i14T9JbJEv9
Bh9N+o1+Ut/BB5C+A8f4e7Qv2h/9g/fH+eH8cX24frQP2g/ti/ZH/6D/EA/o
b8QD4gXxhfhDPCPeMR5I7yFA7yFUXsSwdgfK/2VnJQYm/PyvnlKAnlKo+rU/
pL5NqPq2oVIPyF/q6il5COkFR7avOtXkcTrfM/l1yvD0B6peTqh6uc1STydU
Pd0yqc8T80ifd17q74Sqvysj9XmiGunzxkr9nsgj/V6B1PuJp6T3S5Z6QLGI
9IBjpV5QPCS9YGmpJxTdSU9YX+oNhQnpDetKPSJvTXrEn1KvyBNJr5gm9Yw8
jPSMTOod+QBV7yj1kPw56SGvSr0kjya9JNoH7Yf2xb/H6+P9cX44f1wfrh/t
g/ZD+6L90Z/oL/Qn+hvxgfhBPCJeEc+ktxSgtxQqb+D6qXMl/QaEp+sfK9u5
rGCkTxbQb0AE6fYbEO9I37xD6r95NdJ/V5X6cB5O+vC3Uj/OR5N+/JrUS4ux
pJfeL/XU4izpqUOlXltMI732SqnnFn1Jz61IPbY4S3rsM1KvLaqRXvuN1HOL
daTnDpR6b/EH6b29pF5cfCC9+GupJxdjSE9eWurNxS3Sm8+VenTRlPTo26Ve
nduSXn2d1LPztaRnD5N6d96O9O7mUg/PJ+v2G+BOpK/Pkvp7/pD09zjG36M9
0d7oD7w/zg/nj+vD9aN90H5oX/Qf+hf9g/5D/6L/ET+IL8Qr4hnxTnp8Ya2r
xxdqxfpKBceduZrnh3f+/ZlGLxM5xBuHeOStdeOVj6D9LUTub/wS7X/v5f7H
1f1xr9wfOcQ/36K7P3DSdwvSd3N/3f2El6X9hvTdfDztR6T/5kW6+xcnPblw
kvsbJ725eCT3P26puz/yhrR/msr9kzeg/bWN3F/5L939l+fQ/hwu92fem/Zv
0svzHNrfSU/PA2n/J709t2p4/N758Wm8l/2qDZHhnO9dXueqf7UUfqzlmjb9
Xa/zGh5+df29vnPztZd3bux+gu8LO2K+JDqJ19jZZnV7p738w6mlOVv+SOLB
dlEvrM7M5N8Lrk8bVT6Jbw468zHCdRDDMf4er4f3w/ngfNG/6H/EB64f7fOb
/cC+aH/0D/oP/Yv+R3wgfhCPiDfEI+IV8Y34x3jCeMN4hOcfh+cfT/qr+QQL
zfuh8ZtyXn3W5HE4b3H1/TJWvl9yeP/k8H7KF9P7vJd8n+ft6H3/nnzf5210
zwMc3nd5e933YR5O79dH5fs1v6z7/swVer8mPTWfTu/fpLfm6vu6jXxf50n0
Ph8j3+f5cXrfd5Xv+3y87nmAq+eFVHle4Op5wk+eJ7h63iB9OVfPI6Q/53Be
4afoPGMnzzNcPe8wed75zT5oP7Qv/j1eH++P88P54/pw/WgftB/aF+2P/kR/
oT/R34gPxA/iEfGKeIbzEofzEod8oVDzF6TvFdsov1FJ5jeEOeU/Dsr8h9hD
+SXSX/OmlH9aJPNPfADlp17I/BTvTPkUG5lP4SmUbxki8y28POV7/pD5Hv6K
8jOkX+YvKH9zTeZv+Crd/A5vQfmfUzL/w6MoP3Rd5oe4K+WP5sn8EW9B+aZ5
Mt/EnSgf9UXmo/hFyleZy3wVX0P5rPoyn8X1Bsl811WZ7+KkF+eTZT6MF1O+
bILMl/EMyqcly3wa96Z8m4vMt/ERlI8rkvk43obydW9lvo5HU/7vh8z/8dmU
H/SX+cHfxvh79Af6C/2J98f54fxxfbh+tA/aD+2L9kf/oP8QP+hvxAPiBfGE
eEM8In4R3xgvGE8Yb5AvFJAvFFC/FFAvEFBPEFBvEPOonjNX1nP4Lar3GMt6
D99B9aB8qU/mUL8Qan2D9LaiAtVXRsj6Ck+gesgZWQ8Rp6heQvpd0YjqKaTv
FUuo3vJE1lsE6YOFo6zH8F9/ynrN37JewwupvhMn6zt8GdV/psr6Dye9Mj8n
60Oc9MzcQtaPOOmd+UhZX+JmVH/KlfUn7kb1KdJLc7V+RXpqPpjqW6S35iep
/tVN1r+4KdXHXGV9jPtTvW2mrLfx21SPOyrrcb+N8ffoD/QX+hPvj/PD+eP6
cP1oH7Qf2hftj/5B/yF+0N+IB8QL4gnxhnhE/CK+MV4wnjDeoD4noD4ngE8k
gE8k3HT5C0LlN0yR/Aah8h9I3ypIX8w3S/4Jn0P8FGfJT+GziL/SW/JX+FTi
U5BeVtwnvsVBybcQh4nvcVfyPcRc4meQ/lb4EH8jXfI3hBXxO+Ikv0PUIf6H
t+R/iMvEDxku+SEijfgjvSV/RMwnvkkPyTfhpDfmf0o+Ci8ivkqq5KvwGsRn
aSD5LPwm8V2OSr4LjyQ+TAvJh+F3iC9Demheh/g0pJfmnYhvQ3pqPo/4OKS3
5qTH5m0lX4eTXpu/k3weTnpu3kPyfXgw8Ye+Sf4Qv7+6ywpD/Y/81tPF83wN
xG9j/D36C/2J/sb74/xw/rg+XD/aB+2H9kX7o3/Qf+hf9D/iD/GCeEK8IR4R
r4hnxD/GB8YbxiPGK/CNBPCNBPChBfAPxWBdfqLguvxFkUn8xg6S3yg8iV9q
LPml3If4p6mSf8p7Ej91jOSnctKfckXyJcVg4lN6ST6lUPmcLyWfU9gS//K4
5F+KMOJnTpX8TGFL/M1Eyd8UKr/zveR3CpX/OVbyP4XKD20l+aFC5ZMmSj6p
WEx80wjJNxUbiY/aRPJRucpXzZd8Va7yWU0kn5WrfNerku/KxxMftovkw3J7
4ss2k3xZ7kF82nTJp+Uq37a75NtylY/bQfJxOemf+WHJ1+UNic87Q/J5+R7i
B7tLfvBvY/QH+gv9idfH++P8cP64Plw/2gfth/ZF+6N/0H/oX8QX4gHxgnhC
vP2GR8Ar4hvxj/GE8YbxiPEKfGGRdfDxlZTy37hn4cUS/bUAvYQAPYUAvYUY
TPqXN1L/wpuTPuaW1MfwFaSfeS71M9yO9BvdpX5DqPqOQqnvED6kN+kt9Sbi
DOlJ/KSeRGwkfUhvqQ8Re0g/8lHqR8R60pfclfoSMYL0JxlSfyJmk15ls9Sr
iBjSs9yVehZxnPQvmVL/IjqSPma91MeI4aSfIX0vv076GlOpr+GtSX9TRepv
+CTS50RIfQ7fTfodd6nf4WVJ3xMp9T3cjfQ/ZaX+h/cjfRDpl/lE0g/lSv0Q
1yd90RGpL+LdSX9kK/VHvA/pmdpKPRN/HTNg/BQDzt3md9njW+7v38b4e/Qf
+hf9j/fH+eH8cX24frQP2g/ti/ZH/6D/0L/of8Qj4gXxhHhF/CE+Eb+Ib4wP
jB+MR4xXjGfQPwnQP4kDNVsY+lxYzjPcp/X48MtKW1civaR2/FbqKbXjQ1Jv
qR3Pk/pXro5rSH2sdjxE6me14w1Sv6n9+3ZS36kdm0u9qXY8SOpJteP7Uh+q
HU+W+lHt2EjqS7XjW1J/qh1XlXpV7ThJ6lm146NS/6odx0l9rHbcUupntetR
pL5WOw6Q+lvteIDU52rHu6R+Vzt+K/W92nEZqf/VjhdLfbB2nCH1w9rxQ6kv
1o6dpf74/7U/+gf9h3+P18f74/xw/rg+XD/aB+2H9kX7o3/Qf4gn9DfiAfGG
+EF8If4Qn4hvxD/GE8YbxiPpl7Vj+c9aLOxZv3JJf5WA8IL/Pt/Vfg0C+jkI
6PcgRlD/jVDa31tTfw7Sv/K11L8jnJ4Pav8I0mcK6C8hTlK/i360n0I/C6H2
p+hH+5/av+Kzuj9Sf4t7tH+O0e1/IdR+GdtpP07Q7achTuv23xCdqT/HBtr/
R1D/jq70fLhB/T3M6fnRhvp/VKXny2TqD/KFnj97qX/IBno+VaD+IlH0/HKn
/iPl6fk2kPqTVKDn32TqX5JPz0cL6m/iT89PhfqfTKbn60DqpzKRntcf5POc
3abnOY7x9+g/9C/6H++P88P54/pw/WgftB/aF+2P/kH/oX/R/4hHxAviCfGK
+EN8In4R3xgfGD8YjxivGM/Qf0VA/xX1PM/gPK/2ZxLQv0lAfycB/Z/EDuq/
ZUDnP9KTsiQ6H3bX7d/F/XX7SannHbXflPDU7Xelno/YYd3zvNq/Soyn/lYx
dL7Kpv5Xb+j8ZUf9sUbQ+Sye+mc1o/Obi26/LeGk249LbKB+XQ3ovOih28+L
Z1C/LwM6b7agfmB+uud5tV8Yd9TtJ6aed9V+Y+p5mHXRPc+zdnRerkv9zHbq
nufZFDpv76L+aUvp/I5j9Af6C/2J18f74/xw/rg+XD/aB+2H9kX7o3/Qf+hf
xBfiAfGCeEK8IR4Rr4hvxD/GE8YbxiPGK/RTE9DfVUB/VwH9JAX0mxQ2uv0o
RRnqB7qP8rdLqF/oRsrvLqF+opMo/2tH/S27UD7yKfW/PET5yuPUf/MB5Uud
qF9mJcpvnqR+mtmU/6xE/TYTKT/aiPpxHqb86U3q1zmG8qs51M/ThvKvTtT/
sy/layOpP6gL5XP1Vsr+oTmU761D/UVbUD44iPqPnqZ8cRz1J+1A+eRH1L/U
j/LNjai/6UXKR/eg/qenKF+9hPqj+lM+uzf1T+1J+e5z1F81kvLhvaj/6mDK
l4dRP1ejfJl/fyfz88z8mczP4xh/j/5Cf6K/8f44P5w/rg/Xj/ZB+6F90f7o
H/Qf+hf9j/hDvCCeEG+IR8Qr4hnxj/GB8YbxiPEK/V8F9H8VN++svmzga6yY
737wrcYxYwH96wX0ixbQT1pAv2nhQP28Z1N9NpD6fZei+u1m3X7gar1dcdSt
tyuvdevtbAzVS0l/qPhRfZP0iYoh1T9Jv6ic0a23K8+ofhpF/bhJ/8jVft1B
uvV2lkj12j91+39zL93+4Py2bv9wvk+3vzg3pP7jOVRPXqPbn5yvpv7lkVSP
Hqjb35z7Uv/zjlTPNqT+6Np6N/VbH0H18xvUj30r1ddxjL9Hf6C/0J94f5wf
zh/Xh+tH+6D90L5of/QP+g/xg/5GPCBeEE+IN8Qj4hfxjfGC8YTxBv3ZBfRn
F/C9FwHfe1H5Ngrp84T6fQvS7wn1+xek7xO76PsiCcSHakTfH1lCfKm+9H2S
YOJTqd/TIL0gV7+3QXpCTnpGpTXxk9TvcxwgPtEz+n4H6RO5M33fw4X4SKRv
VE4TX4n0j4rKZ1pB3w+ZT3wn0lMqKj9qPn2PJJL4U2fpeyUqv4r0mqwB8a/U
750EED+L9J5sKvG3Cul7KZOI35VG31NJIf6X+r2VVcQPG0bfYykm/pj6vZZ3
xC+Lknw1lkp8tZmSz8Y8ic+GY/w9+gP9hf7E++P8cP64Plw/2gfth/ZF+6N/
0H+IH/Q34gHxgnhCvCEeEb+Ib4wXjCeMN/hejIDvxQjiayvA11aAr61+/4nD
96E4fD+KL6fvbZH+kneh73E9Ir5xB/peF/C11e9RcfheFVe/fwV8bfX7Vrwf
ff9qMvF7Z9H3sUgvydXvaal84R/0vS3SX/JT9D0ulW88kb7XpfKR1e95qXzl
nvS9r3PEZzai74H1Jb6z+r2wHOJDq98Ta0Z86bP0vTGVT12Jvkem8q0z6Ptm
Y6TelQ+i758NknrY38b4e7Qv2h/9g/fH+eH8cX24frQP2g/ti/ZH/6D/EA/o
b8QD4gXxhfhDPCPeMR7ge2gcvofG46dYeeXaWSmNk3cv/o++SQF9kwL6JqU+
6THge5n8In1PU9W3qN+PVHT1TEq+rp5JWairZ1JAz6TU1NUzKQW6eiblua6e
Sf0+pqpnUZ6SnkX9viYjvQt8f5PX1/0+p6qnUb/fyUlvyj6R3qaX7vc/OXwf
lAfQ90NjSM+D9kH74e/xeng/nA/OF9eD60V7oL3Qnmhv9B/6B/2H/kU8IF4Q
b4hHxCt8b5TD90a5j31q/1eeVopp2QrxFwpjWdi6OxMXFmt+v9y5fH7sVT64
fPl7HruslD6+hu51I2P51E6Fi7uvtFJ6tT3r75sTz5qcHDLAscBKeZsyY3Fn
+/v85K7UURGa/z9sclHHrYnxvFKP0zYl17O7ahAbODqAhT5rWbfk96+Mrrib
htxn+wYkuJ4VVsrdy4/cAwK+8o7XGx16xq2UI7nPjC6lf2W9Jwy0YcOtlO8f
arW+vyiJT7wZ5xC1z1JZVtRuVoNpebxc+6a760daKpazv9l4pObwlgcHKSW/
N7cMu3LIOYlVazF6zET9OHa2e5pnsKeVCEty+Pfvr1iWLVg3LY+17L18gvVX
S+XL2p5Hg7Nz2Ijn7239TXJZmx57z7t/tlQc/dvcfTojj9k+6phUW/N3+Suq
2+RaJ7AvNb2PfHKxUsou+NTl/fwkZn75pcNWzX29xo+utmj7Vea8I3/TFc26
PZv3PW8Wdp91n97dvK1m3Z62LmYl81llaLNaMx9lYcv31sd+fGUtXbvdKK2x
Q6f0lefqJ8TymMxXPv5eVkrGEt+C+vWv8sPnvHaWXC/F4UHDf5bd59eXz0lP
1VxPDFrqMbVUAm/1sG6e8worxSXvmu3wS1/5zZoJ979rrlccvsy2lmMSn/fm
/fmmI6wUW4sahxfPyOOGtTO+laznevONTXbq53LfZdn5+8Itla2795fYR+z3
bFVcYp/oe3GTNPYRQa1i35XYx3rr/t4a+4phg5wrHtbY9+S9nGkaPIje5SIC
S/Dg8dVussbfYthcB98bGn8vMdgwWONvsdbStoO5xt9ZRt0aaPAmVvqMyivB
2/FDuY80/hbjGnhElvj77uk9BzV4E2uXZdero8FbRKThyJL7Deny4u09jf+v
/nWrT8n1z1h/OJCpwWf1267VS66fMux59XYa/GU+12ca/ImwFe/dt2jw59DQ
bYQGX+LNZdOQyxp82f791LFkfcJgwrQS/Dimex7R4EcMCx9VsQQ/tm71DErs
MdXvndH+cEuRUqrHwRJ7JU38UOJ/cS/SfnKJvfddcE7S2FvE9HluXWLfEJNv
1zX2FT86tKhUR+OvJ4Me7tH4S5S5ZfvHO42/ugYUF2r8JVqlxv5VgpfplZct
0eBFJL+M61/i77P6K9Zp/C3SlqSOHarx30B+8qXGf2Lbd+P+SzR4ujjuzMqS
63WeVz7OQoOn5NZt09tornd1cK25JXiMTdlzRoNHEZkWH3Bcg6cJW0N8NHgS
w2r7iBL8lhnW+HvJ/O2a6buU4NtuafmbGnzj+ySD/I4C9RwF9ILq74X6e+i3
JOD/i/8DA+ZdNA==
    
    "], {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, 
      {RGBColor[1, 0, 0], Thickness[Large], 
       LineBox[{33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
        48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
        65}], LineBox[{89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
        102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112}], 
       LineBox[{148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 
        160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 
        174, 175, 176, 177, 178, 179, 180, 181, 182, 183}], 
       LineBox[{212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 
        224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 
        238, 239}], 
       LineBox[{278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 
        290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 
        304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316}], 
       LineBox[{348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 
        360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 
        374, 375, 376, 377, 378}], 
       LineBox[{416, 417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427, 
        428, 429, 430, 431, 432, 433, 434, 435, 436, 437, 438, 439, 440, 441, 
        442, 443, 444, 445, 446, 447, 448, 449, 450, 451, 452, 453}], 
       LineBox[{485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 496, 
        497, 498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 
        511, 512, 513, 514, 515, 516}], 
       LineBox[{554, 555, 556, 557, 558, 559, 560, 561, 562, 563, 564, 565, 
        566, 567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 
        580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 590, 591}], 
       LineBox[{623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
        635, 636, 637, 638, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648, 
        649, 650, 651, 652, 653, 654}], 
       LineBox[{693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
        705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 718, 
        719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 729, 730}], 
       LineBox[{762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 772, 773, 
        774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 787, 
        788, 789, 790, 791, 792}], 
       LineBox[{831, 832, 833, 834, 835, 836, 837, 838, 839, 840, 841, 842, 
        843, 844, 845, 846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856, 
        857, 858, 859, 860, 861, 862, 863, 864, 865, 866, 867, 868, 869}], 
       LineBox[{900, 901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 911, 
        912, 913, 914, 915, 916, 917, 918, 919, 920, 921, 922, 923, 924, 925, 
        926, 927, 928, 929}], 
       LineBox[{956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 
        968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979, 980, 981, 
        982}], LineBox[{1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015, 
        1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026, 
        1027, 1028, 1029, 1030, 1031}], 
       LineBox[{1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066, 
        1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076, 1077, 
        1078, 1079, 1080, 1081, 1082}], 
       LineBox[{1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121, 1122, 
        1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133, 
        1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143}], 
       LineBox[{1169, 1170, 1171, 1172, 1173, 1174, 1175, 1176, 1177, 1178, 
        1179, 1180, 1181, 1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 
        1190, 1191, 1192, 1193}], 
       LineBox[{1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 1232, 
        1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241, 1242, 1243, 
        1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252}], 
       LineBox[{1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291, 
        1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302, 
        1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311}], 
       LineBox[{1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1352, 1353, 
        1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 
        1365, 1366, 1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 1375}], 
       LineBox[{1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416, 
        1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1425, 1426, 1427, 
        1428, 1429, 1430, 1431, 1432, 1433, 1434, 1435, 1436, 1437}], 
       LineBox[{1470, 1471, 1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479, 
        1480, 1481, 1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490, 
        1491, 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500, 1501, 
        1502}], LineBox[{1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540, 1541,
         1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551, 1552, 
        1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561, 1562, 1563}], 
       LineBox[{1596, 1597, 1598, 1599, 1600, 1601, 1602, 1603, 1604, 1605, 
        1606, 1607, 1608, 1609, 1610, 1611, 1612, 1613, 1614, 1615, 1616, 
        1617, 1618, 1619, 1620, 1621, 1622, 1623, 1624, 1625, 1626, 1627, 
        1628}], LineBox[{1660, 1661, 1662, 1663, 1664, 1665, 1666, 1667, 1668,
         1669, 1670, 1671, 1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679, 
        1680, 1681, 1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690}], 
       LineBox[{1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730, 1731, 1732, 
        1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740, 1741, 1742, 1743, 
        1744, 1745, 1746, 1747, 1748, 1749, 1750, 1751, 1752, 1753, 1754}], 
       LineBox[{1785, 1786, 1787, 1788, 1789, 1790, 1791, 1792, 1793, 1794, 
        1795, 1796, 1797, 1798, 1799, 1800, 1801, 1802, 1803, 1804, 1805, 
        1806, 1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814}], 
       LineBox[{1845, 1846, 1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854, 
        1855, 1856, 1857, 1858, 1859, 1860, 1861, 1862, 1863, 1864, 1865, 
        1866, 1867, 1868, 1869, 1870, 1871, 1872, 1873, 1874}], 
       LineBox[{1902, 1903, 1904, 1905, 1906, 1907, 1908, 1909, 1910, 1911, 
        1912, 1913, 1914, 1915, 1916, 1917, 1918, 1919, 1920, 1921, 1922, 
        1923, 1924, 1925, 1926, 1927, 1928}], 
       LineBox[{1952, 1953, 1954, 1955, 1956, 1957, 1958, 1959, 1960, 1961, 
        1962, 1963, 1964, 1965, 1966, 1967, 1968, 1969, 1970, 1971, 1972, 
        1973, 1974, 1975}]}}}]},
  AspectRatio->1,
  DisplayFunction->Identity,
  Epilog->{
    GraphicsComplexBox[CompressedData["
1:eJxF03lI02EYB/BpmqVRUKlJimc2LUcYHvNg4VGu1JlZqavpZnlSmV0qlDMP
DCwZmujmspozjzkTLHNsTScy0UXpbM7UNeeB2y81c0VaYAX2vC+8vHx4vu/3
v8eZcS32sikOh4v6e/+9BJKNYWNjWYrbPKJt9Ktpb5fABe9UWC99Eazn29n6
2X8Be36O2L5rygBu2MMzjt/Xg/uogw+lpAWwfb29U830PPhUKDVP+WAO7Pgr
lelBngV7CbnMnEUdWHvzGUHVNA3OqGPx6jK14Ph7Ca4CFw0Yj3lQ455MgLOi
Y0p0M2pw4g1KsK+vClwpXYiRvlaCSabqcwSTYXCmWpbNX1WAg2oL94ly5eD0
qZWJBFsZmKI93DbgJgL7SjljhmIhmPj1YoompQp8qGjZsudWJem/2+VLzQXx
7WAJedA/QNYNxlqeZ0THy8DcNgLH+EoOFtNLrY90KcD5e2s/UnYPgxUfRsNG
2Erw9SE/9wobFbjhfZh16oAaXC7oarKInACbVI6S+8w1YNvmVnlDhBasesF0
NS+bBlNbPUtzdDpwEMcisP/ALHimovuHW/EcuNO1AHOenAdreXe8zRwWwCP4
cOZqrh7syA53GpAYwNUtCWvE3xhYKQ0Zf3N2EZzVS7NyqFkCb+4D2MgLFBxN
QvsRyRTl74xEc9YKfqi2Hc0nn+7os/6G+iRJ6d4WjSifXFP/STGG8m4dPml2
/Shvls1SWeah/G0K6dEWJbIcS2TMY+h/BPEkkSNE//E/+U3lDJRnj51JLhEj
x8o9xYV65PzH/u6r31Ff4t04lws81BcQ9JIVdR7lBftp5OMdyJesfPghGuRj
RU7KHiNyXObBsrV11M+oH68Wc1F/KM1nq/A0yncGz0gaW5GveInseGpkMp9/
wnkZ2Y/OoSWvI/8BvPBPPg==
     "], {{{}, {}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[4]], 
        LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
         12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
         29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
         46, 47, 48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 
         63, 59, 75, 69, 64, 76, 70, 77, 50}, VertexColors -> Automatic]}}}, 
     VertexColors -> CompressedData["
1:eJx11H8w1HkYB/CNi9opu+gHqu0qJXuEWD+a9Kizd+ooIcXhKqQfGyoO19VV
qFUTofNjj8LQsEw2xHaHcHIk2ShhEsd89/d3N9XUqrXd9sc999f98cxr5v3H
85l5nmc+qw7GBUQbUCgUP30Z6qt4ZpeoclYN/zo+G8d2/6SG5eztpi4rJWhD
+3HBISoJQcd36AQBU+gJ69hPm7oUYKexrjl7dwI1qTzgwZTIQaitc2Z5jKE9
T4u5zi5y4J0y/W5T+AjqnWvflJElAw7VrHOn5xBqtndfrxtVBoIBgu64bRA9
qREZzLsihXnNUwOP+SI0+KaoL2m5FETTyS7Zc/rQdYuocavaJFBkGNNe/rAb
9fU6Fe1+SAIWvIWUrK0P0OePquW9VhKITyf3F37ZgTJ6zbsXDIuh5M7BnCGb
VtT0pOU3ujwxSBf43gum30MvnxN+e3u/GCa4zdwtNg1oQ3od289ODPSZWy26
gVp0tN9nhvaJAMGDrBAGUYkygri+y0YJuPbQJ9M+pgx1TystPt1EQNu7CH5l
Bg/NCehqtywi4Nzd1b8YhGejHsaBd8pSCaAYBmqXZKWht2P9e1rj9fnWCk/2
0UR0yMJ2Q1GkPtcFvpyzOvw/TSr2OIbqc/80ZqfWFu2YbFON79HnlJKWvGob
dM+bNbmDn/MwBqvvjwiUlu5clvC5Tyu3L68nAT0rcKY5fX53vZMR1zodZSnr
qBdPELD/flPeC2E2qpNll+anETCh2Ux/ZslDC8rOXVXz9HN4TfgYXy1DFyY6
/MwWEuCVHlM+p7gS7Rrg1POG9X1cxtN/TaxFrXav7F4xS4Bj007XN5p69H1R
QdIPTP0eLUYOfzwlRIMb61OYoWKwGExf5i1vQX/MXXv++HV9rhu/MdTfjl7g
50zufqK/nyn2/LWKTrTyTPyxAnP9fS52COHwu9Gl+bHGGZES6HyUUOqQ+Qil
m67UpDZKwKvxyFhKiQilbt/8odVKCkYUk2wjt0G0hv+846sMKTAV+4S25DN0
o03U9hdaKcRXM1xWfz2C5iyfG+F4RQYTIbpCv5EXqH8Uv9DNWg5W4us3vU5P
oPPLnFhtg3Kw+81Tq3adQqNeHqn60KwAul/Y0pwbYnRuXI/xxXEl/N+/9P30
moQxgQztqWhcd5MgQXtWXc8JkqFBzArx4y4S+KmhyZaXFGjmUPdA+AUVxPq5
JSaPStB+y5YnAz4k3P+4nufKVqDyQCE3hqMCpXnY0rhnSrTcKKGuf1oFh8/Y
J6e5StA+W9p6OzMSXANJg7VuctTsRHn1ATMVJETmx1XdUqJPei/95D6pgi3k
7/QzHSR6f0Ya+tRLDaxr9wadZGK0edRzOlqjBPtt3uOF7TKUtoSzw1lBwraC
ErsGsQJt3zhhsrlMBa5GytGQUhJtqdl5o5ulhi+06oLgoyq0RreL+1eyGg6H
Rbdk/SlG+xhJ10cVSojwcReZXZahDzvMXgmGSVi4bMvlubkKtLZ+0Ya9F1UQ
IqKFeFuSKONV7QrOPDVYS7JgMkCFNr13WPwuXg1tHsaE1d8qVNGy1zeiRA1U
VtVzrUCMGsa4F1cRStBqHDKN4mRo1SxttKafhCiP1/sSjynQVea3VtikqCCK
qWESY0o0KXJWWPpWBeXTTm+5r0nU7WP07mF/NaTQ8+1SRSp0MHRj1BBPDf8A
TlOcKA==
      "]]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-4.174050091548382, 4.174050091548382}, {-4.174050091548382, 
   4.174050091548382}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.65091309907512*^9, 3.6509131734162083`*^9, 
  3.650915753817782*^9, 3.650971581942334*^9, 3.6509733168481503`*^9, 
  3.650973392820382*^9, 3.650974631485504*^9},
 CellID->1140380999]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<fieldLinePlot2D.tiff\>\""}], "}"}], "]"}], ",", 
   "sqrtDiskStreamPlot", ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650972024725526*^9, 3.650972029321805*^9}, {
  3.650974411356121*^9, 3.650974422039708*^9}, {3.650981185055019*^9, 
  3.6509811915422688`*^9}},
 CellID->238626571]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Lines in a mock 3D rendition", "Subsection",
 CellChangeTimes->{{3.650913545073086*^9, 3.650913556639111*^9}},
 CellID->647777880],

Cell["\<\
For this function squareRootStreamPlot3D the form of the arguments are most \
easily described by an example.\
\>", "Text",
 CellChangeTimes->{{3.6509735412710047`*^9, 3.65097359594705*^9}, {
  3.650974515869936*^9, 3.650974517429534*^9}},
 CellID->2009998118],

Cell["\<\
An example starting with 8 field lines in 2 dimensions, plotted out to a \
distance of 4 and then rotated through 10 separate planes: \
\>", "Text",
 CellChangeTimes->{{3.650929200040847*^9, 3.6509292594070177`*^9}, 
   3.650973602722744*^9},
 CellID->131289048],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fieldLinePlot3D", "=", 
  RowBox[{"squareRootStreamPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"8", ",", "4"}], "}"}], ",", "10"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.650913563696938*^9, 3.650913576742601*^9}, {
  3.650914260377771*^9, 3.6509142661661263`*^9}, {3.6509735817736397`*^9, 
  3.650973581875957*^9}, {3.650974358207698*^9, 3.650974368818357*^9}},
 CellID->1608222517],

Cell[BoxData[
 Graphics3DBox[{{
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], {{{1, 0, 0}, {0, 
      1, 0}, {0, 0, 1}}, {0, 0, 0}}], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], 
     NCache[{{{
        Rational[1, 4] (1 + 5^Rational[1, 2]), 
         Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^Rational[1, 2],
          Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
       0}}, {{{0.8090169943749475, -0.5877852522924731, 0}, {
        0.5877852522924731, 0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], 
     NCache[{{{
        Rational[1, 4] (-1 + 5^Rational[1, 2]), 
         Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^Rational[1, 2],
          Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
       0}}, {{{0.30901699437494745`, -0.9510565162951535, 0}, {
        0.9510565162951535, 0.30901699437494745`, 0}, {0, 0, 1}}, {0, 0, 
       0}}]], GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], 
     NCache[{{{
        Rational[1, 4] (1 - 5^Rational[1, 2]), 
         Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^Rational[1, 2],
          Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
       0}}, {{{-0.30901699437494745`, -0.9510565162951535, 0}, {
        0.9510565162951535, -0.30901699437494745`, 0}, {0, 0, 1}}, {0, 0, 
       0}}]], GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], 
     NCache[{{{
        Rational[1, 4] (-1 - 5^Rational[1, 2]), 
         Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^Rational[1, 2],
          Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
       0}}, {{{-0.8090169943749475, -0.5877852522924731, 0}, {
        0.5877852522924731, -0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 0}}]],
     GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], {{{-1, 0, 0}, {
      0, -1, 0}, {0, 0, 1}}, {0, 0, 0}}], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], 
     NCache[{{{
        Rational[1, 4] (-1 - 5^Rational[1, 2]), 
         Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {0, 0, 
        1}}, {0, 0, 
       0}}, {{{-0.8090169943749475, 0.5877852522924731, 
         0}, {-0.5877852522924731, -0.8090169943749475, 0}, {0, 0, 1}}, {0, 0,
        0}}]], GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], 
     NCache[{{{
        Rational[1, 4] (1 - 5^Rational[1, 2]), 
         Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {0, 0, 
        1}}, {0, 0, 
       0}}, {{{-0.30901699437494745`, 0.9510565162951535, 
         0}, {-0.9510565162951535, -0.30901699437494745`, 0}, {0, 0, 1}}, {0, 
       0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 0, -2.155775928685403},
        {-2.2474601342876945`, 0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], 
     NCache[{{{
        Rational[1, 4] (-1 + 5^Rational[1, 2]), 
         Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {0, 0, 
        1}}, {0, 0, 
       0}}, {{{0.30901699437494745`, 0.9510565162951535, 
         0}, {-0.9510565162951535, 0.30901699437494745`, 0}, {0, 0, 1}}, {0, 
       0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       0.45084723058998094`, 0, -0.0006223534733196737}, {
       0.4519102317955285, 0, 0.002052459797765004}, {
       0.4529720235317761, 0, 0.004714216978958831}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.9631455784784717`, 0, 4.}, {
       0.45403224651532614`, 0, 0.007361929874959089}, {
       0.45509089496706734`, 0, 0.00999571502546749}, {
       0.4593096054395496, 0, 0.020394427891449497`}, {
       0.46350269362134555`, 0, 0.030579242977989963`}, {
       0.4800119264540729, 0, 0.06934459817965348}, {
       0.496088648265292, 0, 0.10516561727050397`}, {
       0.5560364368377498, 0, 0.22650731056929999`}, {
       0.6236574416639559, 0, 0.34504545780095447`}, {
       0.6997028359110273, 0, 0.4633384361663946}, {
       0.7851468069051952, 0, 0.5841168766507112}, {
       0.8810940377698674, 0, 0.7099784161604364}, {
       0.9887122412912113, 0, 0.8432716147967336}, {
       1.052289541989844, 0, 0.9192949093724743}, {
       1.1092139312517184`, 0, 0.9861170298394968}, {
       1.1803002572004009`, 0, 1.0681519247610756`}, {
       1.2438738100875357`, 0, 1.1404876588458095`}, {
       1.3231715208767145`, 0, 1.229543792954983}, {
       1.3940620650861657`, 0, 1.3082986843521283`}, {
       1.482335659693873, 0, 1.4053847090560254`}, {
       1.5612609175827614`, 0, 1.4914646748595524`}, {
       1.659404585526685, 0, 1.5976770604713337`}, {
       1.747189544180059, 0, 1.692062892032874}, {
       1.855856978257582, 0, 1.8081986033230533`}, {
       1.9531377727465156`, 0, 1.9116395958466075`}, {
       2.0157241052832973`, 0, 1.977933701642849}, {
       2.0751061208548482`, 0, 2.040721125714729}, {
       2.1842572011022576`, 0, 2.155775928685403}, {
       2.247460134287694, 0, 2.22219772106837}, {
       2.307686267594806, 0, 2.2854074560571753`}, {
       2.419208134574058, 0, 2.4021907538523015`}, {
       2.520977794053899, 0, 2.508490571900711}, {
       2.615150238048216, 0, 2.6066716600323323`}, {
       2.7026493639914895`, 0, 2.6977370307219077`}, {
       2.784818266146349, 0, 2.7831422617801653`}, {
       2.825708118880678, 0, 2.825604399739409}, {
       2.8284271247461903`, 0, 2.8284271247461903`}, {
       2.914810923914921, 0, 2.9180032810892556`}, {
       2.9965473815112196`, 0, 3.0026779475560255`}, {
       3.0763133557854396`, 0, 3.085280342068965}, {
       3.1521383634155047`, 0, 3.1637381926742467`}, {
       3.2244413288131484`, 0, 3.2384967801224986`}, {
       3.2936411763901052`, 0, 3.3100013851643513`}, {
       3.3600281005397576`, 0, 3.3785593668107112`}, {
       3.423892295655487, 0, 3.4444780840724847`}, {
       3.4952451963804663`, 0, 3.518091798645757}, {
       3.564037289733922, 0, 3.589034128985106}, {
       3.6302685757158555`, 0, 3.657305075090532}, {
       3.693939054326265, 0, 3.7229046369620353`}, {
       3.8151011870876865`, 0, 3.8476696745232934`}, {
       3.929027285673356, 0, 3.964909308188901}, {
       3.9631455784784717`, 0, 4.}, {0., 0, 4.}, {
       0., 0, 3.9961839476042997`}, {0., 0, 3.938835826524592}, {
       0., 0, 3.8032633019939595`}, {0., 0, 3.657683817988824}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.3550089910191663}, {0., 0, 3.499157711444073}, {
       0., 0, 3.325629915573837}, {0., 0, 2.411669939914764}, {
       0., 0, 2.748555761172645}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.131813674448878}, {0., 0, 3.025314853442413}, {
       0., 0, 2.9124222321399587`}, {0., 0, 2.658943168377744}, {
       0., 0, 2.564211004042013}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.102548127324656}, {0., 0, 1.948011359715007}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.0268483036313654`}, {
       0., 0, 0.940357894663429}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.20661447088629326`}, {0., 0, 0.06149939106594586}, {
       0., 0, 0.019562741148584313`}, {0., 0, 0.008629243291989887}, {
       0., 0, 0.005866267449632667}, {0., 0, 0.0030912268241177153`}, {
       0., 0, 0.00030402560466082583`}, {0., 0, 0.00030402560466082583`}, {
       0., 0, 0.0030912268241177153`}, {0., 0, 0.005866267449632667}, {
       0., 0, 0.008629243291989887}, {0., 0, 0.019562741148584313`}, {
       0., 0, 0.06149939106594586}, {0., 0, 0.20661447088629326`}, {
       0., 0, 0.3550089910191663}, {0., 0, 0.5088534286842651}, {
       0., 0, 0.6704695795197733}, {0., 0, 0.8422893392711752}, {
       0., 0, 0.940357894663429}, {0., 0, 1.0268483036313654`}, {
       0., 0, 1.1330876424350123`}, {0., 0, 1.2268001899005905`}, {
       0., 0, 1.3426821590466516`}, {0., 0, 1.4449468115536537`}, {
       0., 0, 1.5720335184974656`}, {0., 0, 1.6842586145316265`}, {
       0., 0, 1.8242770298530933`}, {0., 0, 1.948011359715007}, {
       0., 0, 2.102548127324656}, {0., 0, 2.2392428907307504`}, {
       0., 0, 2.411669939914764}, {0., 0, 2.564211004042013}, {
       0., 0, 2.658943168377744}, {0., 0, 2.748555761172645}, {
       0., 0, 2.9124222321399587`}, {0., 0, 3.025314853442413}, {
       0., 0, 3.131813674448878}, {0., 0, 3.2319186951593526`}, {
       0., 0, 3.325629915573837}, {0., 0, 3.499157711444073}, {
       0., 0, 3.657683817988824}, {0., 0, 3.8032633019939595`}, {
       0., 0, 3.938835826524592}, {0., 0, 3.9961839476042997`}, {
       0., 0, 4.}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.615150238048216, 0, 
        2.606671660032332}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-0.4508472305899801, 
        0, -0.0006223534734132175}, {-0.4519102317955285, 0, 
        0.002052459797771116}, {-0.45297202353177674`, 0, 
        0.004714216978962717}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.9631455784784726`, 0, 
        4.}, {-0.45403224651532675`, 0, 
        0.007361929874962352}, {-0.45509089496706795`, 0, 
        0.009995715025470501}, {-0.45930960543955024`, 0, 
        0.020394427891451652`}, {-0.4635026936213463, 0, 
        0.03057924297799198}, {-0.48001192645407365`, 0, 
        0.06934459817965533}, {-0.4960886482652927, 0, 
        0.10516561727050586`}, {-0.5560364368377505, 0, 
        0.22650731056930176`}, {-0.6236574416639563, 0, 
        0.34504545780095564`}, {-0.6997028359110279, 0, 
        0.4633384361663958}, {-0.785146806905196, 0, 
        0.5841168766507125}, {-0.8810940377698682, 0, 
        0.7099784161604377}, {-0.988712241291212, 0, 
        0.8432716147967347}, {-1.0522895419898448`, 0, 
        0.9192949093724756}, {-1.1092139312517193`, 0, 
        0.9861170298394981}, {-1.1803002572004013`, 0, 
        1.0681519247610765`}, {-1.2438738100875364`, 0, 
        1.1404876588458108`}, {-1.3231715208767152`, 0, 
        1.2295437929549842`}, {-1.3940620650861661`, 0, 
        1.3082986843521291`}, {-1.4823356596938733`, 0, 
        1.405384709056026}, {-1.561260917582762, 0, 
        1.4914646748595537`}, {-1.6594045855266857`, 0, 
        1.597677060471335}, {-1.7471895441800593`, 0, 
        1.692062892032875}, {-1.8558569782575827`, 0, 
        1.8081986033230544`}, {-1.9531377727465162`, 0, 
        1.9116395958466084`}, {-2.015724105283298, 0, 
        1.9779337016428498`}, {-2.075106120854849, 0, 
        2.0407211257147297`}, {-2.1842572011022585`, 0, 
        2.155775928685404}, {-2.247460134287695, 0, 
        2.2221977210683703`}, {-2.307686267594807, 0, 
        2.2854074560571758`}, {-2.4192081345740584`, 0, 
        2.402190753852302}, {-2.5209777940538993`, 0, 
        2.508490571900711}, {-2.615150238048216, 0, 
        2.606671660032332}, {-2.7026493639914895`, 0, 
        2.6977370307219073`}, {-2.784818266146349, 0, 
        2.783142261780165}, {-2.825708118880678, 0, 
        2.825604399739409}, {-2.8284271247461903`, 0, 
        2.8284271247461903`}, {-2.9148109239149207`, 0, 
        2.9180032810892556`}, {-2.9965473815112187`, 0, 
        3.002677947556025}, {-3.076313355785439, 0, 
        3.085280342068965}, {-3.152138363415504, 0, 
        3.163738192674246}, {-3.2244413288131475`, 0, 
        3.2384967801224978`}, {-3.2936411763901043`, 0, 
        3.3100013851643504`}, {-3.3600281005397568`, 0, 
        3.3785593668107103`}, {-3.4238922956554863`, 0, 
        3.444478084072484}, {-3.495245196380465, 0, 
        3.518091798645756}, {-3.564037289733921, 0, 
        3.5890341289851047`}, {-3.630268575715854, 0, 
        3.6573050750905303`}, {-3.6939390543262642`, 0, 
        3.7229046369620336`}, {-3.8151011870876856`, 0, 
        3.8476696745232917`}, {-3.9290272856733552`, 0, 
        3.9649093081888993`}, {-3.9631455784784726`, 0, 4.}, {-4., 0, 
        0.}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.95783689075547, 
        0, -0.000019353267771655817`}, {-0.961092300646874, 0, 
        0.0000769237499386639}, {-0.9662159425174818, 
        0, -0.00001488193379741379}, {-0.9721105398623225, 
        0, -0.000016915439908901546`}, {-0.9780009407858267, 
        0, -9.4549287566133*^-6}, {-0.9942993307051649, 
        0, -7.456878992814016*^-11}, {-1.0199196653057947`, 
        0, -3.9322448336344656`*^-17}, {-1.0441270251617791`, 
        0, -4.188185796670771*^-17}, {-1.0656356343777014`, 
        0, -5.4802539523734544`*^-17}, {-1.103916954700594, 
        0, -6.291355848473771*^-17}, {-1.1377329748978304`, 
        0, -5.76856472652891*^-17}, {-1.168435411235916, 
        0, -5.3449874850035726`*^-17}, {-1.2233866892487932`, 
        0, -5.740898543844758*^-17}, {-1.271879969872249, 
        0, -7.169875969936316*^-17}, {-1.315650737829236, 
        0, -7.605557225169879*^-17}, {-1.462781775715857, 
        0, -6.195397641957862*^-17}, {-1.6359101241905045`, 
        0, -6.91889657643285*^-17}, {-1.7418228968663727`, 
        0, -9.134338558355556*^-17}, {-1.834842206447462, 
        0, -1.1016553625876325`*^-16}, {-1.9561859590610056`, 
        0, -1.2750168763888024`*^-16}, {-2.0629181836586, 
        0, -1.2852140541589372`*^-16}, {-2.198008519300975, 
        0, -1.1889401531607424`*^-16}, {-2.3172727734015335`, 
        0, -1.1054620693552894`*^-16}, {-2.4766784141082288`, 
        0, -9.95753777841507*^-17}, {-2.6169578678929475`, 
        0, -9.005579148493101*^-17}, {-2.783896798840014, 
        0, -7.887204757512249*^-17}, {-2.9321701035746295`, 
        0, -6.903823762048957*^-17}, {-3.044313586024579, 
        0, -6.165853380675537*^-17}, {-3.149680299973699, 
        0, -5.475095370032912*^-17}, {-3.248270245421992, 
        0, -4.8315497301210835`*^-17}, {-3.340083422369456, 
        0, -4.2352164609400495`*^-17}, {-3.5093126446991736`, 
        0, -3.141433203114722*^-17}, {-3.663301140900122, 
        0, -2.150991764901277*^-17}, {-3.8042329302218385`, 
        0, -1.2486008105883193`*^-17}, {-3.9352085680591986`, 
        0, -4.12644982310117*^-18}, {-3.9959643887654526`, 
        0, -2.56863717785067*^-19}, {-4., 0, 0.}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.615150238048216, 
        0, -2.606671660032332}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-0.5560364368377501, 
        0, -0.2265073105693007}, {-0.6236574416639562, 
        0, -0.3450454578009553}, {-0.6997028359110276, 
        0, -0.4633384361663953}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.9631455784784713`, 
        0, -4.}, {-0.7851468069051954, 
        0, -0.5841168766507117}, {-0.8810940377698676, 
        0, -0.7099784161604366}, {-0.9887122412912115, 
        0, -0.8432716147967337}, {-1.0522895419898441`, 
        0, -0.9192949093724744}, {-1.1092139312517186`, 
        0, -0.9861170298394968}, {-1.1803002572004013`, 
        0, -1.0681519247610756`}, {-1.243873810087536, 
        0, -1.1404876588458095`}, {-1.3231715208767147`, 
        0, -1.2295437929549828`}, {-1.3940620650861657`, 
        0, -1.3082986843521278`}, {-1.482335659693873, 
        0, -1.4053847090560252`}, {-1.5612609175827614`, 
        0, -1.4914646748595521`}, {-1.6594045855266848`, 
        0, -1.5976770604713333`}, {-1.7471895441800587`, 
        0, -1.6920628920328735`}, {-1.8558569782575818`, 
        0, -1.8081986033230528`}, {-1.9531377727465153`, 
        0, -1.911639595846607}, {-2.0157241052832973`, 
        0, -1.9779337016428487`}, {-2.0751061208548487`, 
        0, -2.0407211257147284`}, {-2.184257201102258, 
        0, -2.155775928685403}, {-2.2474601342876945`, 
        0, -2.22219772106837}, {-2.3076862675948067`, 
        0, -2.285407456057175}, {-2.4192081345740584`, 
        0, -2.4021907538523015`}, {-2.5209777940538993`, 
        0, -2.508490571900711}, {-2.615150238048216, 
        0, -2.606671660032332}, {-2.7026493639914895`, 
        0, -2.6977370307219073`}, {-2.784818266146349, 
        0, -2.783142261780165}, {-2.825708118880678, 
        0, -2.825604399739409}, {-2.8284271247461903`, 
        0, -2.8284271247461903`}, {-2.914810923914921, 
        0, -2.9180032810892556`}, {-2.9965473815112196`, 
        0, -3.0026779475560255`}, {-3.07631335578544, 
        0, -3.0852803420689656`}, {-3.152138363415505, 
        0, -3.1637381926742467`}, {-3.224441328813149, 
        0, -3.2384967801224986`}, {-3.2936411763901057`, 
        0, -3.3100013851643517`}, {-3.3600281005397576`, 
        0, -3.3785593668107117`}, {-3.4238922956554876`, 
        0, -3.4444780840724856`}, {-3.4952451963804663`, 
        0, -3.518091798645757}, {-3.564037289733921, 
        0, -3.5890341289851055`}, {-3.6302685757158537`, 
        0, -3.657305075090531}, {-3.6939390543262633`, 
        0, -3.7229046369620336`}, {-3.815101187087684, 
        0, -3.847669674523291}, {-3.9290272856733526`, 
        0, -3.964909308188898}, {-3.9631455784784713`, 0, -4.}, {
       0., 0, -4.}, {0., 0, -3.9961839476042997`}, {
       0., 0, -3.938835826524592}, {0., 0, -3.803263301993959}, {
       0., 0, -3.6576838179888234`}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.35500899101916583`}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.325629915573836}, {
       0., 0, -2.4116699399147636`}, {0., 0, -2.7485557611726437`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.025314853442412}, {0., 0, -2.9124222321399573`}, {
       0., 0, -2.658943168377743}, {0., 0, -2.5642110040420123`}, {
       0., 0, -2.23924289073075}, {0., 0, -2.102548127324655}, {
       0., 0, -1.9480113597150066`}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.444946811553653}, {0., 0, -1.34268215904665}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.0268483036313651`}, {0., 0, -0.9403578946634288}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.20661447088629314`}, {
       0., 0, -0.06149939106594575}, {0., 0, -0.01956274114858419}, {
       0., 0, -0.008629243291989764}, {0., 0, -0.005866267449632543}, {
       0., 0, -0.003091226824117591}, {0., 0, -0.0003040256046607018}, {
       0., 0, -0.0003040256046607018}, {0., 0, -0.003091226824117591}, {
       0., 0, -0.005866267449632543}, {0., 0, -0.008629243291989764}, {
       0., 0, -0.01956274114858419}, {0., 0, -0.06149939106594575}, {
       0., 0, -0.20661447088629314`}, {0., 0, -0.35500899101916583`}, {
       0., 0, -0.5088534286842648}, {0., 0, -0.6704695795197727}, {
       0., 0, -0.8422893392711748}, {0., 0, -0.9403578946634288}, {
       0., 0, -1.0268483036313651`}, {0., 0, -1.1330876424350118`}, {
       0., 0, -1.2268001899005898`}, {0., 0, -1.34268215904665}, {
       0., 0, -1.444946811553653}, {0., 0, -1.5720335184974648`}, {
       0., 0, -1.684258614531626}, {0., 0, -1.8242770298530928`}, {
       0., 0, -1.9480113597150066`}, {0., 0, -2.102548127324655}, {
       0., 0, -2.23924289073075}, {0., 0, -2.4116699399147636`}, {
       0., 0, -2.5642110040420123`}, {0., 0, -2.658943168377743}, {
       0., 0, -2.7485557611726437`}, {0., 0, -2.9124222321399573`}, {
       0., 0, -3.025314853442412}, {0., 0, -3.1318136744488765`}, {
       0., 0, -3.2319186951593517`}, {0., 0, -3.325629915573836}, {
       0., 0, -3.4991577114440724`}, {0., 0, -3.6576838179888234`}, {
       0., 0, -3.803263301993959}, {0., 0, -3.938835826524592}, {
       0., 0, -3.9961839476042997`}, {0., 0, -4.}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       0.5560364368377496, 0, -0.22650731056930012`}, {
       0.6236574416639553, 0, -0.3450454578009543}, {
       0.6997028359110269, 0, -0.4633384361663946}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.963145578478472, 0, -4.}, {
       0.7851468069051949, 0, -0.5841168766507113}, {
       0.8810940377698671, 0, -0.7099784161604363}, {
       0.988712241291211, 0, -0.8432716147967337}, {
       1.0522895419898433`, 0, -0.9192949093724738}, {
       1.1092139312517182`, 0, -0.9861170298394968}, {
       1.1803002572004, 0, -1.0681519247610751`}, {
       1.2438738100875353`, 0, -1.1404876588458095`}, {
       1.3231715208767136`, 0, -1.2295437929549826`}, {
       1.3940620650861653`, 0, -1.3082986843521283`}, {
       1.4823356596938726`, 0, -1.4053847090560254`}, {
       1.561260917582761, 0, -1.4914646748595524`}, {
       1.6594045855266844`, 0, -1.5976770604713337`}, {
       1.7471895441800587`, 0, -1.6920628920328742`}, {
       1.8558569782575818`, 0, -1.8081986033230537`}, {
       1.9531377727465156`, 0, -1.9116395958466077`}, {
       2.0157241052832977`, 0, -1.9779337016428498`}, {
       2.0751061208548487`, 0, -2.0407211257147293`}, {
       2.1842572011022585`, 0, -2.155775928685404}, {
       2.247460134287695, 0, -2.2221977210683708`}, {
       2.307686267594807, 0, -2.285407456057176}, {
       2.4192081345740584`, 0, -2.402190753852302}, {
       2.5209777940538993`, 0, -2.5084905719007113`}, {
       2.615150238048216, 0, -2.6066716600323323`}, {
       2.7026493639914895`, 0, -2.6977370307219077`}, {
       2.784818266146349, 0, -2.7831422617801653`}, {
       2.825708118880678, 0, -2.825604399739409}, {
       2.8284271247461903`, 0, -2.8284271247461903`}, {
       2.914810923914921, 0, -2.9180032810892556`}, {
       2.9965473815112196`, 0, -3.0026779475560255`}, {
       3.07631335578544, 0, -3.0852803420689656`}, {
       3.1521383634155047`, 0, -3.1637381926742467`}, {
       3.2244413288131484`, 0, -3.2384967801224986`}, {
       3.2936411763901052`, 0, -3.3100013851643513`}, {
       3.3600281005397576`, 0, -3.3785593668107117`}, {
       3.423892295655487, 0, -3.444478084072485}, {
       3.4952451963804663`, 0, -3.5180917986457576`}, {
       3.564037289733923, 0, -3.5890341289851073`}, {
       3.6302685757158564`, 0, -3.6573050750905343`}, {
       3.6939390543262673`, 0, -3.7229046369620376`}, {
       3.8151011870876896`, 0, -3.8476696745232966`}, {
       3.9290272856733597`, 0, -3.9649093081889046`}, {
       3.963145578478472, 
        0, -4.}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{228, 229, 230, 244, 245, 246, 247, 248, 249, 250, 251, 
          252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 
          265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 
          278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 
          291, 292, 293, 294}], 
         Line3DBox[{333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
          344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 
          357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 
          370}], Line3DBox[{412, 413, 414, 428, 429, 430, 431, 432, 433, 434, 
          435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 
          448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 
          461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 
          474, 475, 476, 477, 478}], 
         Line3DBox[{516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 
          527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 
          540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552}], 
         Line3DBox[{585, 586, 587, 601, 602, 603, 604, 605, 606, 607, 608, 
          609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 
          622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
          635, 636, 637, 638, 639, 640, 641, 642}], 
         Line3DBox[{681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 
          692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
          705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 
          718}], Line3DBox[{751, 752, 753, 767, 768, 769, 770, 771, 772, 773, 
          774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 
          787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 
          800, 801, 802, 803, 804, 805, 806, 807, 808}]}}}], 
     NCache[{{{
        Rational[1, 4] (1 + 5^Rational[1, 2]), 
         Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {0, 0, 
        1}}, {0, 0, 
       0}}, {{{0.8090169943749475, 0.5877852522924731, 
         0}, {-0.5877852522924731, 0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 
       0}}]]}, GraphicsComplex3DBox[CompressedData["
1:eJxM3Hc01+//+HEjK5E9iyRFO6slly0ZRRkpKxmRBkWpkIaZnWSPkOy9XVb2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    "], {
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxVnXXYldXzd0+H3S12t4JISAlIiKiIghgoNiIiWJggiKAYKCgiiIWCiAEq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         "]]],
       Lighting->"Neutral"]}, {}, {}, {}, {}},
    VertexColors->{
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143381, 0.4523915157143381, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977495`, 0.20933181110977495`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.3443927181955512, 0.3443927181955512, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.899113673809771, 0.899113673809771, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.]},
    VertexNormals->CompressedData["
1:eJztzrsJgEAQBNBBI8uwEnuwBMHYFizUIizBwEjksvMTvEkG3sIy/bSMc5Nk
65I2t6xn7QPnnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeec
v+zhnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeecc84555xz
zjnnnHPOOeecc84555xzzjnnnHPOOeecc875b33lnHPOOeecc84555xzzjnn
nHPOOeecc84555xzzjnnnHPOOeec848813t1r7Wz5E/v8b/gB/iCRMo=
     "],
    VertexTextureCoordinates->CompressedData["
1:eJxl3UHILeddx/FBcKGIoZCFuClCNy7ERaVYWnrBrrpx0W5cSWloMaAIkoUb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     "]]},
  Boxed->True,
  ImageSize->500,
  ViewAngle->0.46277048851247315`,
  ViewPoint->{1.1004452256288109`, -2.0935060158119154`, 2.4199696004599067`},
  
  ViewVertical->{-0.04243928700645738, 0.1703132695964074, 
   0.9858814238432139}]], "Output",
 CellChangeTimes->{3.65091361629817*^9, 3.650914304725438*^9, 
  3.650973645086563*^9, 3.650974663789798*^9},
 CellID->534625233]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<fieldLinePlot3D.tiff\>\""}], "}"}], "]"}], ",", "fieldLinePlot3D", 
   ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650974442986474*^9, 3.6509744468082457`*^9}, {
  3.6509811996538553`*^9, 3.650981206013487*^9}},
 CellID->1244809848]
}, Open  ]],

Cell[CellGroupData[{

Cell["Several plots of the behavior of the potential", "Subsection",
 CellChangeTimes->{{3.650973766053192*^9, 3.650973776588108*^9}},
 CellID->936611601],

Cell["\<\
Comparing the potential for the uniform disk with the non-uniform disk along \
the z axis:\
\>", "Text",
 CellChangeTimes->{{3.6509737886437073`*^9, 3.650973824409552*^9}},
 CellID->576045497],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PotentialSqrtDisk", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}], ",", 
     RowBox[{"PotentialUniformDisk", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellID->414376105],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw1mHk0FHzcxW1jN8PI9pAshRBFiUrfXyKptKFURBQekuVJ0iIiZSlZkyWJ
si9lzdJvsoRChCxhxpY12zAY29t7zvv+dc/95/51zz2fc2VtXM5eY2NhYeFi
ZWH5X1UD0fGNDRJlvzrJHsVTwdRR8ckyk0SZ1fY0k0iiwp0obQX6AonyuUOu
nP6WCrUTF21+T5Ao5mNj81m5VLCOSexu6CBRLo83K+yqokLYrNK3l7kkyq33
knK+41SYT96fpWlForzQPSktt5kGpdxXbth/IlL2eG0/Ci40eND4c+LzFQHK
nV/Sf36p9sPYWwmxvVL8lBf1r62q//SDMvUoD6mXl8L0hm9fygYgRTh5vush
D6W8Jc2gNW8Qqi59fYqBm7IWpsNTnTUEUolSMjH9nJSPM05Xdv4ahuOHL3m1
BhIo7n2DhFaFEdiyYuez3YiD4n7hy55kn1HYkZPg4/6HjULMVQ2qURgH2s0k
tZ9prBSbT+SSxOEJ+Dc+LDnekYVy+7vMUfmOP2DufUE+S24d+8S4zw3LzoDS
xPZLpq9W8HAwRYrDfRYK/X9EOEas4GNs7J8Vb8+CnvTdBp8nK3hc8uT9U96z
YHGmQTfbfQU/CPQ1zgyahefFN2Q4DVfwoYTFj5HJs7Dslz9cPM3EYYXXQOPn
LHyV0nWVPMTENS+l+goOzoHTydOPBgaX8IS1anTzZjqsH9vZptK1hD97Kpcv
b6VDuKGgvEfTEt5YNBhXVKVDKWqmcH1cwlbkIveIfXTg1jy9qvpsCYcGMSip
5+nwTuz0f57aS/irks63+nA6DNBOXeF/uojNDxzMEBeYh4v/ndLV0mLgTdYv
amWEFyC4M+GKtioDT+bWDMpJLkC57uSjfXIM7Dk580ZZfgGkuQObDhIZ2PkJ
yBzXXID++Eorw98LWPux1odmkwVw+LLnoXn0Ala/p7uNHrUAtySkau8w5nFg
oiF8kmZABB49jYvomNFAVmw8vAiv7rEIjGXSsVn/GVntk4uQpiNeT06i4wsM
UmKm+SJ8yjc8ZBdMx1Ly7MeznBdhNPXdLgFrOm6nXXETiVmEg8+vki/x0PHM
ef3HoVOLMGZNa2VcmsOqjr9Jjm+WANg6z6mxzmKXF8cdZZWY8Fvx8qjg4gxW
45v8unU3E54ZD3nRJ2dw+3AWlwZiQl/MTHxJ5wymV5UgR3MmeKvzDOrlzWCN
f8UGzgYyodxin8t5qxnc9SgmhviHCTdv6JBY707jcOnn93zKV6D6o4HGF7tp
nFb81rS9fgU2Ec6aBZ+dxuKC/vf3dKxAfpxjnIjyNFYfUpgXm1uBubo4ReWu
KaxtY9Ftp7QKLvLrYLJ3Cos+axnf+2IVHDsrXd/SJ7GY3o0wgvcaOLdeqfrY
O4nTj5x1lXq2Bq5NLKJNtZO4YUA/Vu/VGnhWHyxjxE3ivPicfyo+rYF/Xinh
qP4kDnBJHbjOsg6vnnyIHY+cwM9TBp/WBaxDq/abanWtcbz7QELrWuIG/NQ8
JKYvM46lz4sGb/2wAd1qtH/NecexgPW4pGX1BtC2SpN8+8ZwggpVjmNsA6YE
Yy/8CBjDKbdipaMlWBD3WNjUzY5RnCpVb33vGgs68NJXvPT2CL4qXrA7ioMV
GV8MfbHbdgTPuywMZRFZ0WXJBNFc4xFsZCue0iTOih4klGxKkRvBHZltPjt3
sKLKpGnBZw2/8RYZ200u51iRYYYlj43Mb7zsxugeyGBFZ8t0mDx1Q/hhYRAn
mwUbsr1n6OX/YQhXJOSN37RnQzd1zZbW44ewyFR/MN2dDUVhVwbdbQgfr82G
TUFsqLMqda5Xcgh79H7hHi5hQ5YNIhPvXQaxSRfa3yLOjhx6Z39dEBvAIKdd
igbYUb5LD+EI+wCOZQt55jDFjtZZa9U1pvuxz4W7xvFMdhSpEO/HW9uPZ8d5
KhWFORDF5YhK2a1+vJa6g6dZnwOJs8XdkfpJw40qVhfdMzjQc+MnGp+2U/G0
noyr7QMCUnC3DIhmpeKc3NP6W58SUHm0RveNrj7cfs7/51wsAY1Se3y3BPZh
7ZwL/30sIiDkvqvFZ7QXp1e1H5maIqCZ6G6Xw6k9OOKswVEOG050iqaaXbe1
G8+YO90yNeFCJ64qWsNyF/72wtJA9yoXOjYqK1zU2IXrLLIztD24kP6MqFfy
rS6cZUUJs3/BhbRZWA286zpxemuDYVoPF5KTae/RvN6B1dPljOodudGC1X3+
xPw23F9h/nxHNA+aG/TEIk/acHmR8lpUOg+asXd3D7FowwGDlDnhCh407mLf
6UVow1m1rb9OD/GgvgdnUkzPt+IiQaJtiyYvqkvcdoB3pQVPHex0Ze/gRVo4
rmPcvwkbryWU0NT40T/8HGOvNJtwQ5L947zD/GjN/Drz7EAjnv8wNx1lzo+q
5w5sLoNGfEm09HfSQ35kotBnE8z8hl0MyjspHfzI9anMlIprPTZ58dhWLUAA
pV96y+F8qRq7fU4Xtp8nopA0AVFZ3mosvDe7QYSfhFwXPBTbS6qwb/CbpR55
EtIOPXJMV7QKPxax4jE2JaEvlSOhAi2fMeev/rBnBX+9iamWxdNP+K5/FJe3
riDSmbG07bMtwNaS+4fzBYTQ9dKUMc/qfHzRTjRz+B8h9Mp/wkVoWz6+HXLg
9VYlIcQu4XVP//d7HLtX98hXPSH00k9JxawlB1dvP1FZeFsIURSiQv90p2D+
Y7FBYiNCaFuZXLxMfDLuh75U2QUhFHQqL83E8g3+Gh6SpcNORqkz0X7/4UTc
eNUmNmILGTVFsI/y1UfhGZXy4zPmZBRTLs3qfjwCm+8XHXW0JyObYZ1/Ohuf
40S/a3V0DzIad6bFHH37GDfaaPntjCAjbyz6bVPGQ+xzc+DmUBIZycnFMj9b
3sW5/3R2vssjI6MaTquL9m44QCSn1BOTESWpUeBblSW2Xlvcdr6JjI4mb1De
qeiDbmZpbUE7Gfm/sRspWXQA1jEL5aYvZCSZc4Sk734LuN2UpBjFZHSH4Nxu
ttsHlhxDw1TTyeh3vlZyoPojyGIsebvFkpGJDYtbhXIQPPD73lkdTEbRVKOA
cMFwaGq4nhx9g4waitScVZ9FwmIMz9omazJieyZs+oXvBdw0wpFJZ8jI5UCv
LJMzHkz3KJ4e3k1GKSdK+vLW3wBnxNQHkVUhpOI3zUvxyIerxPy4G7JCyGK/
MHe2XAHYdc7UiAkLoRC6FiH2ewGcMEu43swhhKZsvTf+214Eo6sd8y6jguiD
vsC8Ym8JSCgkm9vlCSJtTpXeUP1PwG3ZVSx/WBC90c/vyA2shnF5Wc6l30RU
KmNwToFWDZWaZe6zjUTUuvqzLV6rBjLUHA5xFhIRRyGzJXCwBtQXWiJ9/Yjo
2ja9BlvdWjA1u0solyUiJc4WithsPRR+kK1RtBVAubVT6Q/Mv4M+Tfe45DIf
6rsscF89/Tv8sCgZxkN8iMhQOU1d/g5Mgz+2Xs18SCt8991E42b4oqFXpJzG
hyIpbrIbU81wX8jP2t+cD53ZPOn8adcPUGPoXGOt4EVff9I4dYvbIO9pWUVY
JA+ykXOdiaS2wSTvvbsZD3nQsvNG1yRXO2yRPRXS7sqDlAjS2fHm7TBdXm1u
Y8yDHmteMlldbgfJZaO7plw8SP95e2LZgQ742W/AG+TNjSqMvmrvq+wCNru8
h0VeXGhqz+4q+p8uOMlibZfswIWk5V4ZZ0t0g8R6ICn5PBfyZrrZyLh1w0tL
DfPuPVwIZUqEcMr8goSwptMKdE5Uzf8v9cf9Hjip0RQl48aJvn7nCnDSoYL/
xqYI7jsExCxzE9x2jQqxWaviW50ISDntV2zfcypU7C4qP2VBQME+ublnRqmg
eP00seMgAb2LyZyMO04DlW/Z+ckcBORgZCL6kEmDy7vCJbZGcKCJjDf/njQf
gN36m+BgGTtidDuw1TgPAHskw8Yjhx2x8KnH7fcbgNdh8q0fk9iRqFNZg1LO
ADhpwXnHJ+xIT6VNnZ1jEM7w1Ss7nGNHMZkERnHuIIT2z0vXz7Mh/SyHh7Jc
w8B0e8RauI8NJWSrxc0XjoChy34tkVEWdINfPHC5fgR6pPwk2/tY0EEnVs/1
3hHQThF/mNDOgvqU2s5yc45C8MSpLMMqFiST4sUrdW4UwMLJniWRBaXEVnsd
ZozC14lvu1bOs6CsxxfNw7XGIUufyyLrLy+UXwkQ2Vk8CeIajK9BGWvQJdjb
OtwwCS5FRpU+sWvAwJrhcQOTYM0xXfsoaA12SvcTuYh/QFzfoLDccQ2Su/dz
9139A5oeIlt6VNYgyGSWGUyegkiJgcKWvFUwN7CgjThPg7B+1B+ZmhW4s+ll
+ynyLBT1fzOiCjPBif0c1U1qFmgHUzpnuJhgMUcei1CYBQ138W38q8sAzSGr
HftmwfdQYIPV0DJwhPjIW9vOAs9hu513CpfhGbuDm2vBLHiYFRu7X1iG5Dkt
gbBzc5AYcM1fOW0JGprb9H/E0qHlshtv8eVFKLK4qP05hQ7S5il1m80WIWmU
qpKXQwc3wxP5wccX4RbLBPlZJR22t3TN3NNeBJmdrP1G43T4kTytV0BeBI/Q
Hfc/68yDGGcwybWOAdInAwrzOudh9E6+3aQ2A9y+7VUIFWVAal4pDlddgIcb
dN9zsgy415esPPCXv8M183o3qzKgn/hdRfsvnxfEKUVlHWKAoO/F9kWeBVhy
kuD4ep0BX4g6nDUj8+DNv9LPUcWA8OZhtrCUeQgy/pRwx2URgh2T9lXKzUPK
d30Ru7ol0OV/kaOzkw4hWcVpXCdW4OxGymrh61lgjWgzqiKsA97+RnxWfQbE
0jNrU46yoEH/7GOaglPwM9VHnvCEFe18cvwMQXQSLmUqB7gP/OWs1vhAzj3j
cCCOa3/NNg70mmSsq5M+CoOhHxlb/QmITbuw4LXqCBTIP5iQ7eFEnl4moaq0
YaAle2pwbOZGlrs2i5nUD8EPJQMf+m0eJHhCmbqrZBC2xBrI1P3dne/k/Hdz
zQMQnXFhWWeVD5lF7tV7zToArVivq8RMAPFT/IoLNPvB6fNlvs0xRKQa+4+V
oR8NbBK7ossTiKgip1jPxIcGF++bylkkE9Gyx5Zd1vdpcFTnmE5cDhHVXpNT
ve9Jg63v99hL1BCRX3JLcJUTDXpe81eJzBFRQOGYl68pDU74lN4hniChd+vh
Vz8p0ODw5T2cOWdIqO4EJXZcngb7DuSFGZ8noaJetm9isjRQWnqbFmJDQu9v
14l5SNKAwzXsJ68XCS2rOJvuF6RBhZWDBtc7EjrfQe2YoFOhQHew4l3mX59x
XdB2igpZkpeNjrwnoe2mt3b0/N2h2A4T60flJLQUoCLU1kuFW6f+VrqVhLqf
uF7trqWC845SieROEnryQeOddSUVrvLteavXR0JnhjurR8upcLZWudx37G/+
rGDU+nsqGL19ayg7TUIrm6v1Q7KogPxkWinzJHRvOaFRMpUKe6/EXbZmkpDQ
xzy17CQq/N+/gP7/X/gf0b0S3A==
     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw1l3k01PsfxseYsc98u5JySyEhlK7spfcnJLqWikpkrRsl2RUhRYuyFHLt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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.4},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650973829020277*^9, 3.650974669416408*^9},
 CellID->1362245277]
}, Open  ]],

Cell["Comparison at x=1 along the z-axis:", "Text",
 CellChangeTimes->{{3.6509738441608057`*^9, 3.650973864719795*^9}},
 CellID->1269442998],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PotentialSqrtDisk", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "z"}], "}"}], "]"}], ",", 
     RowBox[{"PotentialUniformDisk", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "z"}], "}"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6509738346908903`*^9, 3.650973838665247*^9}},
 CellID->1778500012],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw1Vmk4lWsbtZ+Qkv3qFKU4hkyRKTJE3/2EMjQowyFjFJqUlE40KUNzKg0y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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwtVnk0lWsfPRMNct5KhjJkyBSJZOb+nuooiiQ0IGNpooFS6haV3OqSTyJj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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.4},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650973840832719*^9, 3.6509746712970037`*^9},
 CellID->933209872]
}, Open  ]],

Cell["Comparison at x=2 along the z-axis:", "Text",
 CellChangeTimes->{{3.6509738441608057`*^9, 3.65097387484061*^9}},
 CellID->2001393821],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PotentialSqrtDisk", "[", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0", ",", "z"}], "}"}], "]"}], ",", 
     RowBox[{"PotentialUniformDisk", "[", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0", ",", "z"}], "}"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6509738346908903`*^9, 3.650973838665247*^9}, {
  3.6509738768074408`*^9, 3.650973878615079*^9}},
 CellID->1389586586],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw113k0Ve33AHBz5qtJeQ2ZU4ZKRUT7pmuM8hrKlEwJkaFSZCoSGohI5nJl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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwt13k0VdsfAHCEZLjXS6FBIVNIg4ik7/nJUElUvMpYKkMSyfDIlHmKNMis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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.42},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650973881686284*^9, 3.6509746739436626`*^9},
 CellID->1385244663]
}, Open  ]],

Cell["\<\
And a visualization corresponding to those in the uniform case but with the \
representation of the charged disk inserted (the charged disk has some \
transparency here so that the contours can be seen through it:\
\>", "Text",
 CellChangeTimes->{{3.650930015181098*^9, 3.650930055114554*^9}, {
  3.650973945797256*^9, 3.65097397640189*^9}},
 CellID->846380207],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"potentialSlicedPlot3D", "=", "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"plotRange", "=", "2"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "disk", "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"disk", "=", 
        RowBox[{"revolutionDisk", "[", 
         RowBox[{".05", ",", ".5"}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Show", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SliceContourPlot3D", "[", 
          RowBox[{
           RowBox[{"PotentialSqrtDisk", "[", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], ",", 
           "\"\<CenterPlanes\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", 
             RowBox[{"-", "plotRange"}], ",", "plotRange"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", 
             RowBox[{"-", "plotRange"}], ",", "plotRange"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", 
             RowBox[{"-", "plotRange"}], ",", "plotRange"}], "}"}], ",", 
           RowBox[{"RegionFunction", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
              RowBox[{
               RowBox[{"x", "<", "0"}], "||", 
               RowBox[{"y", ">", "0"}]}]}], "]"}]}], ",", 
           RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}], ",", 
         "\[IndentingNewLine]", "disk"}], "\[IndentingNewLine]", "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.650901046695985*^9, 3.650901075830052*^9}, {
   3.650901153994342*^9, 3.650901186440036*^9}, {3.650907505442649*^9, 
   3.650907513470635*^9}, {3.650929899233596*^9, 3.650929902192123*^9}, {
   3.650930309330007*^9, 3.650930309481834*^9}, {3.650930367137465*^9, 
   3.650930370502963*^9}, {3.650930596121159*^9, 3.6509306190060377`*^9}, 
   3.650930656568931*^9, {3.650930887823114*^9, 3.650930926851273*^9}, {
   3.650931495176671*^9, 3.6509314999823112`*^9}, {3.650931810054625*^9, 
   3.650931811243556*^9}, {3.650931960440609*^9, 3.6509319685819273`*^9}, {
   3.6509740116771307`*^9, 3.650974038259384*^9}, {3.650974465063778*^9, 
   3.6509744757894506`*^9}},
 CellID->766512483],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJytvXm4TmX/928LlaSRaFQhlaR51FYaNUky1a2SRElo0iRDCcWNVHKXVBpI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    "], {{
      {RGBColor[0.2913888888888889, 0.40611111111111114`, 0.6477777777777778],
        EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV01toz3EYx/HvbDPnLTdMFDk2uSBu5FhutswOTou4wGb/HWNzaI45FNdL
whoiIaIoYzaEIsfNnM+R09DmrITX7+LT+3me7/M83+f7/f5+AxaU55Z1CCEs
pHgqTg5hVKcQSvButxAOx4XQgvkpIRzpEkIBplorTgqhN07lTxXPxNk9QtiQ
GEIezrP2R858rOev7RjCGUzkp4on4A+q7hzCR9xPI9j7MJ66yemAb7vbMyGE
L/iNatjfcaZea+w1C7fKazTzFjxl1uFmrsNl/Bzx5diPlurZF6eZNcvMWbiX
P8i+e7CKFslfhe32qLZXG6bLmyA/Izqjtef65GGatQUubzi+52/R5x1WULY+
ldFZ1LwST8ASeV/ll2KF+c6570q8ba26awi3MMVavJxkfMQ/KP4Qm2kbuwlP
OPNi93kS+8gbIj8VG6nWIzZgqb410XviaTWT1NbhcRrIPobF6h+4wxK8y68R
b8H7dIB9D3OslcjJxVLnGetcZRjjN4gX4SGaYp7DeEPNerXX8ZI56s1zEfvT
eHMOwFlmyjXbbMyjwexMnBuJPQevqq/Q5wpe1nef/pdwhb2nm2FlRGtV3mUG
Bn6cd/kn55M9Yt7uNTZTuxma8Bn1FH+KL2kg+wX+VHvBG/3CJTRR/6X4ylqh
nDf4gP7qcx972CM4e3eskfdb/i4s47eKl+NNZ1jhO7yBhWquOXsMi6Je7GJ8
R8v1/xy9NSWzH+JZNePU1mOSvqOdq2P0jfMnizfgE3kp8h9jC/022x3MdheV
7iQn+i/lDTVqOsai70a8CG/zV+tzC7NpgpwcXGzuOvMX4gz+GPFpmEHD2NNx
tzn+OW8tbrDfSPtuxE38o+KbsZW/zmwfsFf0zZi/Mzar327fJiyPZnYPazCf
zrMLcKe8Nn124Fp+mv7rMNFMT/VMwv/eDadB
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJxNmmeUlVWWhm9dbuW6datAFBFQJINIkWxBou2IQCsICgIGQHIsKIIi2Q6G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          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwl1VtsVUUUgOHd9py2tOf0FDVR8AEvFMRAYhRIQKjUmCiKXEpLDWpEtBQo
FFRoY6Et8CLqIypioSgiKqD4oBEpLQjqg8hNbhUkIAgRQQSMiSRA/Xbm4U/m
n5m1Zs3a++xz59Q55XXZURRNQRKTiqKoyaAFS1DFj6ej6KZEFN2Mjpwo+p5f
RD2fjBn4i5/FdOMpqMYZfgp9jUtwN37jJ9Nh3A/F+DWOc85m57WjAzP4LHQZ
n8YZzOYzi8J6ZzKs1fK6TBQNz4+iUXgIL/Hf06GumkSo6TS/gGbjBWjBeZ4R
ny1PdyI0oIgfS4e6eiKDo/wSlhm/hXfwNz+CG/rRjas4yKeJ3yTPF8lwnxr+
cibUVYZSzOXn7G2QZ34i9PEPfhjX5YkSIW8X/yUdauiNW3CCz5HzvNwXcBFz
+YFUFK3NiqI1WI6f+TznjHdeOSZgPm83P8L6SAzDFt6BMuPSrLC2lX8pZ02u
3mEmvuLPiL+a5764hmf5FvPN1ptQj2/4d/jQeA1asZPfZm+tmFEYjlt5Ar2M
i5BCDm9yv6teyG7cqwfNPDsT1gvjPciKc5nvsucK/sGsuFfFUfRJYRR9imXY
x/PtHSZmKAYjj7ekQ+6BGIRFPDcT1h/ICzUleW/UGc/OC7X34l1yfiz3+sJw
1lE+Qb9KPbbhGIlyvhsNejkHdfiJV9jbWOA8LEZlHIt5xvVoQDnfa+9CMY1Z
Iccevj8VnmtTVljbx8fZO05MTUHIMZ7XZ8KzrsGLaOQ93S9fj3KRg2L+hPi+
au2D/hjDR6fCuB/uweN8YiqMe2EIKni355mlH9c923X4ge9x9mL92Ih1OMLH
pkLMYAzFOL5UPZ3q2oZ2vMYPm//MnTZgPQ7x58zfcEaFPRPRwFfgkvEFbMcb
POmcsz303f1LMZq3me+2fh3XsIrPk3ObGjrxLebzNeb7iy1BX3zA17vLI+70
KEZjA38/E9aLeoS8q3lr/FswvpwfanqP73J2i7svwSLs5h+Zv1/cfRiEtXyn
/rd77zqxGTv4q+Yr5Xk6P/xmX+G5zj4Rfx9xHEl+Jf7GGL+QCN+jy3xBJjzr
aajGQj4JR/XvJE6giv+JN9XwOpbiHB8ovto7sRXbUc2fVPcYvRxbEN6vsbxW
v1bqWyvaMIv3sXeImBEYiTvi2uzdKOZzbIrfTb4Zo/SjDA/iaz47HX63/+I/
1PEOtOnHaqzA1vgbjl3Wd2eH3/vM+N0VXyb3YwWhzjH8dvMDrPdHP/TmlWqs
VOvE+DcZ/7fxGvM7rP+YHfJO5/vFv62ud/EwtvBsHNOjUziNHH4QK62vwnIc
4APET5bneUyNv1m8KhXOuwsleIrvLQ7fpLbCkOMQr/A8G32/m5PhP7eS/w99
gQAr
          "],
          VertexColors->None]}]}, 
      {RGBColor[0.4652777777777778, 0.4672222222222222, 0.5455555555555556], 
       EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwl1WtM11Ucx/GfIPIXFMxspj3osqZZrrYeZLVarbk2b+AFoRLzBorgBRVF
MlKnRTPTaqlYmtWkdbE2HUwl3SJA8wJopojZNJXyEqk9MEuxXmc8eO/9Od/f
Oed3zuH8/tw7efboWXFRFH2NeGxKjaI+XaPoY57WQz0piqbySLwkp/NozJdH
8Qsok1/kTCyXs3giNsiTOL1bFA0ydxqPxrPyKC72jvbEKJrAr2JKLIoW8TwM
lUt4rPGLzJPB47Wv6Z/NhXhKn7k8B0/Is3g+0uUivolD9tLOw40fbJ5hnIYR
8gg+ineTo6iJ3zCuDHu1q7Wf4cP8ttpKHNRezstQl9zh11Gf3OEwfo/8ivel
yQv4iPFr1X7iE6iQj/MQ/G5tCZyMG/Kj3Bz2q08jx+Okehx3xXU5iQ/hPX1a
OBGX1WO8Ktax1gbPsry7xVll8jbP+qtt5TXap/R5n8tQLb/Jq8JZhfHB3a3X
ZWjiRhyRG3idZ+f1WcvTcYecH+4Jesl5nINUOTecAWqsIT3cKcyQ+/J1c9V1
tmf+ILT1/5A34pb8Ecejt/6deQVq1dfzv8bUGPs3Hwjrs7b9XIUlciXPcLc2
uWMFXBPurr1/xxnaz6mP4TrtLPVarsJAuZI/C+cuV/CecL/l+vAdoIe8JdSM
zzRPFs/H93IRb/PuEmvYytVYKe/kTM8y9BnLt8K6rb+dk1LcZ7kP90a9/I96
T7ld7hbq9pzrHO7k1bGOv3GjdQw314PmHBb2qN+aLvbIk7SXqb/M47FEnsi9
zHuzUxSlcD9k+Oj7cw8kyLfxa7jfmkvDWeIheTGfRHfrOc1tWCb/yZewVP6D
y7w7yRre4vPaC9UvcCsK5N/4LPLlc+E5+pq/hHON+SLBN8RTrHWFNeeE/Xk2
ztoGcJZnS/XJ5Jk4Ic/gsSiRM7gQbfJsnobt8lQuQLOcz9NRLefxr+a9z3rO
hPdor1bPDmeIjfJk/hxP29c3XBXGy5Vciw1yHe9EsVzNX+F5+cuwF2w2Tw7f
4x2P2cvd/E6s42/ZFH4XtK87h2Y+ha7W08JXw/cm/8WXsUa+whOcy3LnU8qz
tK+Zc2a482iRC3guYuacx4WIl+fwYmOqjC3kudglL+ShGCAP4e3u95PWtYPz
jTlmzuncoF2qfoBztfPUBwajVp7GPxif7Y7t5XTtzeoj+Uft9epH+Ci2yMfC
d4M0uYar8bj8baiH79maa3lX+H+hvptPaKc4h5+5PjzT55dglMu7+ThuyMf4
kDFrjT3MKf4G8f4WqXxJO0/9AF/FPrmNG1EiN/FBLJAbeD+myPs4wfjT1tCF
H/aOOfY4lIeF31Lf6XDuq/2A+l3h2wpt9S48Bg1yBm/GI363K/gKyuXLfCH8
3skXORmD9U/iRAySY9yKYn3Ohd9j69jhvu0L91D7kntVzp+gnz6f8p7wfenz
H19Eq3yBO3nW2ZxxfDvGyT25O4bI3fgsisxzhv8H92AowA==
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJxdmwe0ltWxhk+vfzlIVbpYQEFUEBC7gIoIAhoLvfem9JIo0hSlqDE39kbv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          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwl1324j+UBB/DHeem8/s7vGC2pdsWmmVRr1xbrvcjGcLyFiC1yON6JOEwU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          "],
          VertexColors->None]}]}, 
      {RGBColor[0.6391666666666667, 0.5283333333333333, 0.44333333333333336`],
        EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwl1NtvlFUUxuFNtafpgQbwEDGoMRCIkcQD/Qc8EMCCtBGxUG0Hq+iFgAcE
kzZiOg0WvLCgoHhACBARgUKroIkFgSltqRUS8QJCIpVSQQxoFKaUxGenF29+
71p7rbX3t+f75p7kovJXskIIDXQTnRwZQkV+CEdwHV3IC2E9flESwmAihI24
Wtwj/x5+QOf4D3FUcQi3ZYcwGteIz8ivxSuFIfSOCKGoKIRXKcdGS/B1yudf
wzE0ykFuwcW0hX8SE2YN3RxCQZxN95p/OzZRcU4In+OX9jhlr2bc7Hw3nHMT
LrV2Tf2yOMOsY+bcwEHq4K/jNUrzGfyPfuSvRpo13T18h/XOf9bd1OFpc9+3
13XcZ+0xNd/E/cVN8oNYbb+P7PsGHhSXFYTQjneKJ8mPxd3x+T37LsxYW6m3
buQw36VOPX/Z77B7u1A4nIvzu+Sz9fTIX5ZfQKucLYmz5De5t5n4BG3ky7DL
Wq36bnxYnJIvxVPiufJpvEhp/k88Q9/yp/E5da3qq3G5+KS9luFdnuEXd5WF
s61tU1OFd4gnesa7cQpN5sfhYc84x9k78C11Yz37clxi1vdmLsYJ4nJzxuNW
dVnqj2CanuIP4aPuaHeue8cF5m42P4m1tJV/Hl+09oOaWfgCJdzbyzia5suP
wZdiLL8QV9h7wBneifcpLpSvxUbxefm3scDeGb91AnPpEp+DQ+q6+AwG8a/8
rXhOXMf3436axp/FPlrK/x6/LWft9w4n+Bm0z9kqsYCm8oU40axx3udJOFPc
Ll+GD4jHyz+Eu8ypMGcnXrb2sflXMN/a33weLvQMax0xhUXx3TanGLfpKdG7
CkvV3WfmI5ikT/ma+J77PZr8Xvtxip7P9JbiVT0Dei/iXHUp9U/jPPFqv0Ul
1lAzX4Xrrf2jZh02Uh+fit5arjkpnCOeIP8gTrNHm72m4+PUwk/FBnXZ6lfi
1/H/wtl24AF6k2+J37i1f9Vk8Cjt4TvxOKX5XjxPv/H9uFdPvd5WHBD3yf+B
beI6+R78mTr5Y9ge/+PUHMDK+O078zPY4H4vuecN+JO6E+p7sTuK78Qaa41q
qrHC83R7rnKsEq+Qnx+/O0rxz+Ineqr0bsDmvOH/n+O+hzV5w/EJfqhkOK43
55Ce2b7fDvxKzyK923FvfGfUtuCeeM98K26nBL8Dj+pJ6u3ENvEI+S04Oc7x
bd4f79naDDUH8X+hF+bI
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJw1WGl0VdUVvi9vynu5wyNMkbYgNYBCAaur+KPDn4piQrqAEEiYQbSr/VFq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          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwt1vmTz3UcwPHPnl+7+/3u92vVdF8Ti5SZDvUHlGilYp2Ta6VJ/ZBSpENF
Kbpm0oZErkg5wqCQis2ylkXpGjJTzkiSaUKox3ve/fCc7/v5/rzP1/v6XjV4
WPeH85MkeR5FaJ1Jkp4yqtEdlXxGeZKUFydJc7TGLF6XTZJuJUnSBVVYzz9W
9vGCJBmBx7CYn0J9YZK01PjVuEDdRuUb0DydJJv8bsZG5erUqccjWMSrtLki
lSRrsAS38VfVzxlDFiV4mf+t7Hp9bMJGnOYds7HOMizF7Xyc/mrNcQIO4iV+
v/x0syQpRgmG8Eu02dZYW6MNLuZDME96LubgPr4Y1cbQBhWYz0fgHd+n4iRG
8te1uVXb2/A13uDlxrgjzzhQIc7n8d45YyzVLyrRi+er/605fYOdyOOd1V9u
TitTMT538LHmcsic9uMIXuDblK03rg2oQxPfrJ9N4rsBjQF+QP7Pvu/Bbuzn
R7VZa12eRTW+42uNp3OZ/nDC+KbwX5Xdq84+HMBh/iXekq7FJKzj/2Ti2jQU
xv1wks9U/7R2/sEpzOAr9dNRfwfF6QBWhLnKryyL5fL8ruBfokq6E7piHR+v
nyL9FSONCfxdcTgqHr8hX6yn8feVPaetf3EWc/jqbNzHnUti/5/yy9S/1hpW
FsX9cCnvIX+2mM9EI6r5A9p8S/sTk7i/hvIK+T1974V+aMEHyX/J95cxBv35
AIyTHp/EbzW8n37e1N8beA338tm5ONakLMZsFl+YiWflUQzDAv5RJqafKohn
cUk4g+r/FdYGh/A3n2I8h5vF+d6BVXypsk+oMxKjsIwvx7PST2M0VvB30V96
EAZgOr9T/VXm+Qk+RZfQnjG2Mt6WZXH9lvFfsrG/cG+MxF7eKRvPaMp4ClHD
78bn8j7DF7iLN4bzag3rUI8j/Nv/z1UTjutjp99R5fHsFRTH/fAiH1wez+0U
TEQNP1Ie43GwOO7/g+Gca/M1YX4dr+I+vhHd9Ncbg7GJ16OPdC9UY0M4b+Lw
tXhsRAO284Z0rDMkL459M8+aS4+wd1JxXU7rd7T8X/S3N4n7YSBfpf4r2hmI
GqzmZ9XdURLv0HBvnuHHlG0MY8BX+J2fVXaLc9aErTjHH0Wxdua7b+biEb41
E9f1mYI49iY+zjrttcfKxTONBbwOPaV7oBe+4v/qe2e4G/A9EnnH5L0tPRlT
8Qcvzca74Vd0Mucyvi8b1/8ZjMZ+Psq4v9PM91iL4fwisWllvdrhjHmU8jTO
SV8Y3hNU8Gb6/jP0h6NI8SvL4/29uTDeoVfwGvnTzW0yJmEQ72/OH4jHh1iO
gXygsrXqTi6K9/kg3jXcWb7Py4/lu/G5uXgnhXOZj3n8nkyM7xzMxt38aHjr
rE0TtuE435CLdcI9FGJbzyeKwy57+Ef8gDd5W/mXK9MSrXA9fyjE1fdmaIEH
eYMxLhPjn4rjnXyIVyp7XDxOlMQ22vCh2VhnbSqesQf4QvmlxpBCBovCW6R+
SjuFxfHtu5/fKr+ddiagFv1y8fyF920LjpXFs/ikOV9iP52P88J9wp9Px3f3
QBLfqjH8Fn3PMIZZeA8dwj2ZietQoV6L8H+C35CLb2KIwSlzKeN98QofXxrf
zT78cDqegfX4BHv4jbkYt/CuXoMOfJ38Lr53xT2hPE9n4/7sjCpk+GP6LjGG
VEE8O8N5rfw95rgP+/E2352O/fXNi/fCLp4Kb6v0dmxFEZ+UjXXC+xbu38m8
S7hTzXd6ftxfd/KbQ6zF/Dq0RwdeJX+a71MxDO35jRgr/SLG4abwJuh7jfge
xj48x5vEbAtapON/r3B/lOZiLMPeCGenhP8HQhhvLA==
          "],
          VertexColors->None]}]}, 
      {RGBColor[0.8130555555555555, 0.5894444444444444, 0.34111111111111114`],
        EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV01toz2Ecx/Fncz5zocSEJWbKMBuuDGOOxeLK2Y0toZbT5ZixUWJtUpvN
nM3fIQtDK2e1C0pIjiGERjtgTvH6XXx6f5/v8/k+3+f7f37/ISvXZa+NDyEs
oXYUeofwqEsI/3qFcKZHCHmSZ3EBxRgX4nyqFs/Fgu4hfFG2FZdZn5dfgkup
VrwCXzhzV+cQ/uIc60r52bhHTZPaSjxnnatXDS7vGcK+Ds7DLfY+8uTjdmoW
F2Km+9V0CmEW7rRukd+BOVQmXhXdixriQviKw/Ue2DWEkfjM+qL8c3xPdeIX
OMlZJ52ZgSui+cVZuJeeun8JpqlPck4qjqFB4hG4mNLFU7GDGd46sxMetv4j
fwTTzJNprnQ8Zi/HvEdxv71mnnpsc4/raj9iknWC/DDsSx3F/TCuTwil7pPv
PgfUL3JOOZ6g1eLjeIrvNX9hdEf9UvUdjKftreG5i+PsjeDJwFGUKB4dzceX
xp+Ik/WI+R2m4Ck1a9XGotro7b1javQtqPmh9hAOUTNO7VAsi74V/lLcQBf4
l2OR2Vq90W58SZfN+wkrqJ24HOPUP24fQjw+1DvbN3kLt+nxRq8CLLAX39G7
4EtqED/AG3zz+G/iBcoUX8Q6yhJfwQl8Y90zGRMoRTwQY/Ym8tTgVZouvoR5
9lp51mM1DdWrCivc45v7lOM26188m/Gamrlq63GT9U/5fCymbmqLsD8lyw/A
e3RL/j6OUlPiN0/BjdY/eDZEpBaen1gVfSv6HsQyahKX4gd7b3g+R7+f+lx3
aIzmoLPOnIYzqVY8A39Hc/G34XhvU+yNpuI761fy76OZ6Lu4F/9tb7PQG93B
Sv2+63sAv/I08nyJvh2+CuePj/43fLX8T/A/MsGi0w==
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJxNlm1MlmUUx28EHt6e+7rv1sunamsmy7RATJhWtiVDXK2C5EuZ2svm7HXm
qjWnq2gu8kNqgFogKWRYyy/NrRbFWJoLtJe1ZOjKRF0LFBRaK7KX33/nuPXh
v+f/nOu8Xdd1zrnu6x55pv7paVEUvQ/yQHV+FC0GS0AN2MjiS2A9aAQTSRSt
KYqitWASPpFG0R3ZKPq+JIo28L8LnubA0Z0TR9EYsieKzEa258DqIpNprcZj
3QvuBpXBcpC8KphMa3XgnnzLRb7XeU7XoFOGfA64Fj5JPleQwxH8Z+EVsdlo
H/Pgq1hrYZ/bwWr4rR5Dvm8Ltpcr3V5+5LscVHgM5VTjucp2ihibCqNogP0f
T82nfO8Aj2ftDDb4GSqXgM43+P4BXA5fgY9WfLWA5cEgfozLyAtmq/OMc2zP
o9j8VmIxf4R/CsaKyQWsgH+ViaJ+8DM4AW4CN4Pmgih6E3Tic5bLu+C/kmMf
vnvBL/DvgvmQ7Rn4Iu7oQ+ym+P8P/9vRyUc3F7RlTaa1P8Hfyh3dVtAG3i6w
WLM9h0sx9atcyvF9AB9L8dUADmZNpjX5mZMYWtzXLb7W7DEkn46v60EpmAE+
B33gEDgAIlACYjANvBxMJt4I34qPdvAR6Aa7yKEkx/aovaomVBs9Olf4QLAY
8v11sJilvsdZrtPjeUj3HdfRWqf7Ui33ZkxP6PWcZbOROxzmLv8AHanVkGpJ
Z6Sz2p21WlCOyvU9dIbQPQ664Q/mcpZgKXgA3A/OoXsW1MN3xLYuvfbYbGR7
EnyQWk+rt+VTvl9A5xPq7mPwPLwH2Xix1Zxqr8Fj1HvMz5BNFJuOdGUj2/3g
OXgXsousXQDb4Ntjs2/w3LKx5SuZ1sqyVu9HqfdJfp9FvgzUgVWgLbb/ku+D
LwJNxOoA9fDlxFhArCrwUGo9ol6RTGtlidWA7n5hYnayfw3sBJXozET3BjDP
e085DXgPyqd8V4Jl8C+J+WSunZnO7hB4KtdkWtNM0mzRDNAsmEps3mjuaJaq
59X7QyAX/gXr96FbDw7Cvw1W26qXI6ov7Ao5rwA64WeD9b5mwE/BZFrTDLk0
m4PXj+pohsfTzFkDvz3YvNVMXgC/LLH+1gxYCX8DH+PU4wWw2ee+ctesbC40
34XeP4rxerDeUw82wQ8Hq3f1wEJ4KXu+mrPLgKvghZzRGexGZR/br/6fBiP/
k6lGVCvyUedvhHK/Mdis1syeCU/I+XefT2liENeetLc9wWaT+vfdYJjtPb07
GEp9xuwKlsspMOw5rfT5uA88DN/k/ao3oAk+N7Z3U29VOfyV1HpNPbcuNYir
316EP+r9ovp5DH4qtdpX3Wn2F8fWyzqLIr1tiZ27zl9vn96gAa/RkdR0RjzX
TGwxFEs9fhLbu2Krc9V7ZWw5rvf3tSw2iKtWNHvmJjZ7NYMrEoO4zlBn2YFO
xmtAtVmV2FsgG9mqppb4N8b8YHoZf09UM4u9X9WjtfCtPm80U1rhW/y9k0xr
td7PkmmtNrFZrplemVidjPp56dzUM30+c1WLr5Ljee5qDDTCB/090h3qLk/4
946+V4YSg7i+YQb1vRPbHNI8aontjE97feTF9k2kHtEdXSS/bv4fgw+CPYnd
wVr/PlIs9dW456O8NiemK5st8HFy6sf3YXAePj3YrFAPq5cl7/f3XO/6v4l9
a2je/JVYTam2NI/2wltjm906G9XWXnTmo1sN9ieWo+KrBlWLO4O9uXrT9Lbd
mdrs0wysTq3mVHua1cOpzTDldxTkwLfF9k4opmK/Fds7JZnWCmLrL/WZZkG1
z1fVhGrjP+Vtc1s=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlFlIlUEUgCdNW7z/f+9LEGWZGpQGlnm1emk1pUhIyZdWq4eMykjaHrXM
1IcK0YjcstXslpFkVkQLUhSF1UP7hoHSZm6pZUHf4czDB/ebOWfm/DPnTuSG
7Rk5QcaYdAiBVK8xl0YYE4AGSMEXetVl/CIswm9A6ihj0mA53MPnw3mbJ/EL
8MVedRmvh2S82mNMN3t1QegwY2rwpV6dr4NGWII3QTJrp4zSvZrxV8Q2kpMJ
K+Al3uYzpjfMmBcjcThCXBJUsU4FVEIiPuga0xdKLPyAn3gH+bdZ5zo0Qzvu
92qe5JdCHJ7hUCcHVQsBWIHf8ur3p9oab+LvyG+ya8maH/AkYovIKYT94McP
MN7D9/dCOWTjiY7GSGwxzMLzGP/CfJ/R+EJ8OONtrP0Y7sIgY5mO1nUFGmEt
nuZovVJ3NSzDh6ixlVqfwBjy/uBlnF/3aGP+Qj9U41nEXrVryZrr8PGcVyxN
MgOmQzhe5dOcAfgFlfh6R/Mkvxk24hU+nR+ENijA73v0HuU+5cze4u89enZN
dvwNvsbRGgL2/NPxFrkT23tyB3fwQx49Jzmvn3AY/+rRe5A7fgSd+E7pA+of
gN+wB98Lf6zL+G68BibTJ9HgQAl+wqff8Mt+cy2e52qe5Bvi8vEiCAtVl/EC
/Ax1Zwcbsxk2wWl8EuMJzCeG6NmOw88xvoX5nGCNP4uXMh5k65B6qvEuj/aA
9MJnCCHupE/r6rf3eQpPgKn8joIIiMfrHa0j2+5zAZ/h0xiJjQE/HuPTnAkQ
LnN4BbGryFkJq6ESn+bTmAi7Txx+0KP93WP7twgvIzbd5kn+cXwssaF2fVlj
Cj6H70vlPOJhJszGzxO7lZxtwXo+dfgOxsuZPxqid5qLd7r6/26DT/Adn+vV
t6XevkXz8BhXeznWnv9UvJgaj9n/pNRegu+DTttT0lv5eJSrOXJ3fojEJ7pa
r9SdLGtK/7g6/2K4Ma8hGq8gP3iYvn3yBhbg17z6hsh7NwcC+G9X3yp5s/ql
j/BdrvZnn/3mLPw5PGL+ITyAp3gDZ5Nr+0zu+TIe5Godflt3BP5PeteuL/sM
4d9cPbsf9q0cwFuhxa4v+zzD2+GjPWOJ78ADjvbTFntPF/H/IGHxyg==
          "],
          VertexColors->None], 
         Polygon3DBox[{{4160, 2601, 4150, 4163, 2614, 4162}, {4246, 2802, 
          4248, 4247, 2801, 4245}, {4115, 2517, 4096, 4118, 2566, 4117}, {
          4227, 2786, 4230, 4229, 2785, 4226}, {4055, 2409, 4054, 4037, 2386, 
          4052}, {4010, 2361, 4009, 3986, 2266, 4008}},
          VertexColors->None]}]}, 
      {RGBColor[0.9138888888888889, 0.6547222222222222, 0.33305555555555555`],
        EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt0ltoz3EYx/HvZgw5hqxcMMOwNi7GjhgKF2o1lpKUY3JBDiUpNtScj6Ns
M6cd2Ky0HC4coly4UWgaykaJCzNkm2VOr9Xv4un9HD+/5/v8/4mrNxdsig0h
FLA+LG1YCOMGhpCChwaF0CV3ECcPCSGnbwhTMIll8CfgB7W7MSG8xxRxrnwa
HhB3mi3BpqEhbBgQQjNmDQ7hiA9m40e1B2Y/YYa4RH4GJpqfSWc8Zpupivdt
zGXV/Fm4UK1QTx6miU/Ip2MrrZs0X+MZb/jmLWfxCN0FHngYU81kmU3GvWrv
9OzD+ebr6czDZHG8fAJOY0n8LKxgHfzzWEVrPc1qzKS1iGYW7mBd/O04OtIZ
gw/oLnaHe1hqvx73OYnPxfnyj/CouFv+ND6M8o9xavS7pOIcca09Z2N6tNt0
nCgukZ+EZdGe5/ACrXg3qez9raId7mMjy+E34DF9n/Ufxa32/mH/LThPnC6f
h8Xif/JFeNVMptk6bFE70z+Ev7hNrVPPThwljjM7Aq9H37qDReJW+T24S99v
/bt7Nd1xo3tew7n6arwlD7+qtfdzF9wfzZZjpThB/hSWs7H8Cjzunb/c8BhW
Ru8qxSV06/3HlmGXvu/6O7CH/eT/wTK1fDuU4iW2hn8Rr7C1/Mu4lNXRKcBu
32h22zj+cnZDfgXGDnd7Nym2/3e6bfS/4Bq123pWYY3ZkWYbsEa8jn5t7yxr
kY/BNjOfzbbjG3235N/iSrUGOoX4Uu2pniZsVmvU8wqfiZ/Iv8D/tN+NNg==

          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlctvzFEUx+9oO1Vm5vfzCGXjFYQQKhqD1KvFsEAq/gFEpAuvlceCsvCq
tJ16BAmSVr0SEgt20lhZaCKpaklMNSSISiQeRbw+X+csvpnv7557z+N7zz0z
afPO2h1DQgh7QTGYHoVwvDSERjALnkiHUEiE0At+pEI4yvoxcKLU9h1iT+/w
EM4PZe+IEHr43l4WQh14Dm+KQ/g4LIRPoAWex9+6ohBy4BS8nrVX2F6A/fBB
YjwjVgd4Bz/Dng3s3Qba4NMiy0GxlWtzJoSxyRDGgRb4YZBI2ppsSc48x1cf
KEtbTaqtGcz23JcRZ0zKaihmT0/Czuhsi8dXzsq9z23SQ7oswcc19zcnMo1k
Uw2qZQ3nVoNVXvMV1sqwlYLL8FXUvJDaB0AjfH2Rncl5TOU2FvwqsxznSTMu
7CCogG8F9+H3wBb4SfYMco938d+TMo1zHr8B/iU2P/KXhi9Do00lIWwES+ED
rH1DkzNoUYAv4kwDvvNgBbwW3ISfBtVpW8v7dw28Fd9Rwmr8X6tr1g+GwdtY
G5GwPdpbydrRIVaTapMG0kI9o975HJsGuif12nH4t2A1qtbR+BnpeirmubTp
Jx0vpK1P1KtN3tN9+NhF7XtAf2Q9ql7Vmmxv8fnA++89fG7K9JiP/Su/Z9N2
n4qhWNJM2lWBWRnbqzNPXcMmaU2uP0FjyrRq8HpV9xrO1HJ2A8jB77g+ut9s
2jSTdoqp2Lpz2bRHWqoXe7zf1HdnY3tr0i8Pn4rPLL4XgCkZq1m192Lfh72T
tYe8lUfgCfyIv5+/7K93Wyfo8j2v/Lz0Kuj9uH56893wWyALrwTX4B9i00Pa
vYbvjS22fMiX9miv9H2DbTXIYq8ENfAr5DCeuOXgEvwx6Eh6XvADsc0OzZDD
sdXU6/NEtmbvJ72xHPy296f0k9Z9+Oj2+l5mLAflonvUW1ji96OYit0KJiYt
J+WWiu19qkfVq3m/b/Xk1ZT57HINu+H1kc0ZvUG9xZex9Yo0klZ5n5fKWbm3
cWZy0mK2+qwr9/iaeV2uh3JUL92gP+qKbCZoNhS833VHuqv9rpc00l385swg
57+DP/CczwLNhLUlNlMVZwK4CK/KWK8qnrRp9/vTnV+Hz43s/0E5K/eKyN6f
1mSbH9lb1JpsiqnYt/iu5nuh56DYi+C/Y3tH0khaReAPsYrJf3RsM0yzTGuy
6cxaf0/KteD3+wEMZOxOdDeaG+3w5bH1mnpuZWy1jne9VfNuznwusTektzQq
ttiKl4EvVb94v8rXDPYs9nkwM2M+s95/mvU5n/daU6/XeHz5WAH/B3sEA+s=

          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtk0tIlFEUgO/MkCL9j4jAdqX0otI25XOiJyktSjIJIoQsXbQoqCAi6LkY
KSsbp11FDxvDMCKsFoFIqzZtehfkIEUUmSE1D3KovsM5iw/ud+/9773n8Vd0
HNi2P+qca4AZsDhwrp5BLdTBIvyj59zDiHNPYAS+4AXmJ0ucm4I8TOMJ5rOc
UYAcnMW/wSjfvIG3UMBPsvcfZxchB0fwIebnsF4GIdzDjzKftT2y9xg+4DvX
GXNuL+yDO/ht6GK8J6Zrafx4oN/IPRHedxpPwlzG5SU6dwa/AvMYz4dKuIqn
+H4r52yBFriM74C7JGoI7sNO/KvFNmK5+Yzf9PVtnfaeG3gMxlnPwBhE8Q54
HNUYZP8tvMjdBcun5DWHX+DMP+Ry2mluu/HlzK8mrkaIwzL8uq/3ddmb+/D1
IW8uJT+QhnX4buYfWQwSSzu+AVKMk5CAWvwFZz7jDS/hNYzhhwOthdTkFxzE
FwTaK9IzNVAhbwv1Trlb4pG4KgNdj9u7l+DviWWYfDyAPLH1eNpvdXa+3HMI
X2rxtkKz9GWge/PWZ9Jv5z2tndSwm3sTsJB3XPI0d5LDIiTxPk+/yVpeU/in
WfhM51aWObcK0nwbMPeXcRHK2ePhVXImZw9APzTgK2zuIvRCNT7uaU/IfyMx
ZvA2X3MufTQI2/F3nsY/bHs/4Lt8rY/USXpEeuUHsU0Q23erRwb/HWifyH8o
a1P4K3jO+CmMSv3wjVbfQbu7Fa8OtBY1VrsqyTvzJ1g/BT1Qjzcz38L6ZmiD
Jrwx1NjT1ltxfG2o3m+5WYNPBvreCXvjT/wcZ26iP5ti+k/Iv3GNmEsZz45o
jXrx/8mpsEo=
          "],
          VertexColors->None], 
         Polygon3DBox[{{4237, 2795, 4254, 4253, 2804, 4250}, {4223, 2783, 
          4228, 4227, 2784, 4225}, {4249, 2804, 4252, 4251, 2783, 4224}, {
          4123, 2567, 4135, 4139, 2592, 4138}, {4116, 2564, 4117, 4120, 2567, 
          4119}, {4033, 2383, 4032, 4029, 2380, 4030}, {4053, 2408, 4052, 
          4036, 2383, 4049}, {4013, 2363, 4012, 4010, 2360, 4011}, {4153, 
          2595, 4148, 4160, 2612, 4159}, {4141, 2592, 4142, 4144, 2595, 
          4143}, {4243, 2800, 4245, 4244, 2795, 4238}, {4028, 2380, 4027, 
          4023, 2363, 4018}},
          VertexColors->None]}]}, 
      {RGBColor[0.9416666666666667, 0.7241666666666666, 0.4191666666666666], 
       EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt0ktI1VEQx/FJsUy0FILIVi4qKK/lquvN0iCoTS0Mih6rS21r0cqyl0tN
oW4ZSmnlMhTKXVTQuk1vCKpr0cKC6EkQlfX5c89i+M7M+c2cmfP/txSP9hyp
iohOVs2+L4n4vDDiC65vjGipi8jhWlbHX4nbnR2oidiBT9lD+mdY3RAxuyBi
EAfp5ugHcLo+oll+CjeKW+XzuGqp/mqvqi2quWWQgzgj371YjGfo3tCPYlXq
n91TFo/URvzDJ3SH6B9hu15dZtuAJ529UtuH7919T+0cjok/yA/hbr0uuXdb
Q2WObJ4r+JN94//Bs3Sv6U/j1/Q+P7DMXvA/4bCzjzQl7NBrQM88Tqa9sv2O
0RXMtjqbka6NvgMnnBU9/jiuENfKN+P1lL+BJbaTfw1v2rNg3ym8zbby7+Jy
NTVqlzVW5s7m3yxftvMdu7+tr9ydzbAGj7Pf/D7MpXdrwxG6ef/CZXyXamfx
sV6H3fUcz4l/0bzEvHhykV3wROrZi50pvwnvs11qH+DF1L+E6+i20LfiHrtN
e6t9eMHZX5rzuD/l92JB/bCeOexXM6/2VPbvNfmu/od++aE0Wzbjf8tvaH0=

          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlMtLlVEUxY+aZnq935U00jQQoohuRQYZhtrNDCNyENEkcxBFTcqZRVCh
RA/T1CTpMbaIwIicRn9AEYHdXuYDSq2oUQ8TSvst9h4s7rrf2Wef/Vh7Vxxu
3XcyM4RwHCwCU4kQtiwJ4U9+CN/hOwpC6MegG1TDC/hWEgshBX7Cx0Ea2038
/wb/y+9oBt/Ab/gCGMuwbzrrx+ZrXggzoBfejc+GrBD2gOvw3ngIy3JCKAMD
cYP4SnALfh7MZ4dQxP9u+CR4BX8B3sM/gtc59k1n8infe0E/vJw4VoBSUAbq
sTmAv/0gBU/HzZfuj8FXRSFcXBxCF1gbGcSvgXXwDnA7N4Tl5PYrYTEq1guc
V3DWF7dYFXMHvBabzeQ+DS7D10fmSz6T8DX+nu6vjqwH6sUAb0zAO8Fn7n4B
XfBRbE7Qr2NgJLKa6D3VULVUDPIln8rlJnH+o89Lyf0e/Jx6iK8P4Ky/pV6m
/c1TfHvDWRq0wVNgI3wDqIM3gMo8+6azhzGrq+o7FLMaqpbqyQT8jvdT8fXD
d3k95EO+FJNiKwb34T/ACPwJmIpZj9Wf5/IZN41Ja7KRbdL7o3xVS9V42vV2
Bd6FBuqzTHPS3m58HKI3z/A3At/JtxuZpnlpX7VQTTQTs/n2pt5u4U4TvMHn
Q3caC8yXzmTzzHNUruqJtCCNSWu1oDJuM6M35PsT/FHM9CmdDsMPYtfsPuX7
ksevmdJsJbjzj9gWQCG8FOSSax4og896/VSjOfi7fJtd6VW6HaZGKe5uB48j
y6nF39wDr/N4NSPb4cm4xa5vOnsbmfakwXH4NuK76vuiDl7telF/a9RfbKqw
rQYP4D0+n+pHJ7wxbjkrV/WmiDvZeZZfJO3HTAvKSbnNef+1XzK4n8bnUZ8H
xZbkTgX3k6AqYZoq9h2gWnf6/lFNVdshj0/91i7Ujkt53dojy1G5toJJ+Bmf
jzHQnrBvOtO8nE4YxGUj2xqfF2leu+CuxyPND8as5s1eb+2mQZ8Hzex1eI/r
Wfc1O9qhM75PdPaS94/wfhN4Cp9P2BxrnrWrt5JjZ6bNqGZ1zONVTtol6l25
70bZaadJK9KYtCZN6lx26rV63O3zollQjVQraSuz0GpX4vflp6/AdrF6rt63
eX0Ug2L5D6EP5Ks=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkT0vQ1EYx/9tc1vK7b0GpCqSDjWJbuidKoZuHQwWnYTYGC0SHSxc9QVq
ZiLhG5grTSgxeImhiZcvYGr4nZwz/JLze+7zcs5zixu7qztJSRPgwVEofWal
H/iCGL8NpPqwtAlbcI9XiM/zfQ6KUMZ7xLddjsl9wGfhMCPNpMmDEt4n93dE
WiBnES6IBcT+OA8gPyr5+FJo+5s5ZYjwfXjl/AbPsIdfUh9RV4VluMETvvSS
IA8+IIk/5qQOd7iDLjzh14Gti9xdrvCD0PY3c96hiUfUt1hUDMdQwc9y9k3m
bdPQxmPfzjNzV1LSCV6gPkufIfBg0tyZN06RU4BxOMdbxL/d3s3+T/ExtxfP
1efxKnPW+FkNWIca/g//4TjT
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkLlKA2EURj8NKg5qBFubVELGGLXSqJF0NloYiLhUeQAtrFyIL5AIwT1F
1l4QrETNWwRs3C0sxF0QMXgGb3E4H3PvzP/NH0guTS82SuqCZphvl454UMFl
SPqkAn7pkJ5ZeMVPUCPf4apfmmqVzvEpxMjH2IXNFimCR6BCHsIPbdJZg3SP
b+CEfItnOeOQc+fwgnXwuuww+6ZXBm9BnbyLPzn7jQ5f+MO6veM929nGWfgl
7+N+ZuNNUgj3QIQcxnn7xxIuwiQ5iweZRdlxcZ+9O4CvrfMVvrBuXsewfXMZ
r8APeRUP27+P4jH/f2ev+7rtrOEU1MkbON0pPTpSDh/AJTmFJ7y74E7ieMbu
KoG7mTnsBHEIAuRe/Ad3+kaZ
          "],
          VertexColors->None]}]}, 
      {RGBColor[0.9694444444444444, 0.793611111111111, 0.5052777777777777], 
       EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtjz1LgmEUhu+MirJeq6WiLwqioaKPyYL8SIKIJgdB3BoalVqCkBqqITQo
qHTSHxCYQqPg1iIkJQTWEom7IC2C5PXyNtxc55znnPucZ2Y/4g/bJM2jTjTl
kM57pGk4PEitT5qETvJr6gvw15Dq3dI68UO/9MfcPbwckLYwuYCLzNiZnYBp
8ieWhOAt2qMnBe/wGccnAcfos9E/BI/RB3EUfvH2Rk8F7qJgl7RtWPvMvd/w
jLxFPQpd+N6wywPfue+gVyrDVxQiLsLG//3mP36Yz3dINbjBviX2OuEJbx48
l2EVVeivG9YfzL8E4QtebjyzMECepL4DH/EaxTMLY3jV8LyCLfJP6k24ipcX
/zWYYX4TnxxM8iZ6EvCZ3Ee94LDuMO9ZgUd4lfA8hLNohHgOnqIycRxGUJE4
DNujMkGe
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlMtLlVEUxY9pD6/3u/cTyUKTUhr0hMwgSMu8Jr2koElJswaNQonKRiYU
opmaQZjUH1DRICqbBc2CclA+ULo3STJpVIMeQlbUb7X3YMH6zrfP3vustc+p
PNV2rHVJCOEEKAA9cQgfEyFUgz3wiXQIpwtDOANy8PlkCM/yQhgH3+DdUQiZ
/BD2gV54JzHTRSHcWkGy4hAWiJkkNgt+wzvIOUbuCXAptpzK3Qpm4D9YyxCX
JcdlvnfyXUpsEdgCrwD58EKwTr2mQni7jJrgA/wee0uptRo8gD8kxy9y1cC/
EN9BzJ+lIZQQ3wdvAi18HwcZ+GdithP7kz3z8EXfqxx19DhETDl7V4JB+Hry
dy0P4QqohG8G/fBrYGPaIK4YxV4l53zCNJbWfbFpMQ564UfJeQQcBs2ggtqN
oAyEhGlT7lxr097fomt+HQ8O4UUzuBGZJ/JGa/qnM+qsDWAHfBpMeU3VlubS
/g658vHvOd+NnLsFvEmb5/JensrbJ6xlCi1mJG2aSBvp258yLRddO2mq3Bk/
j2qMsuek53+VtljtmfLzKIdyybNO+EuvVw9epM3TGtdBs7efMw4x0MPgIPxA
ZFxrTZHNiGZlDOTUX8q0+K8J/Cm5RkAtsXWgoNj6zJF/llob3E95vAley9o2
vy91sc1Uic/HQMpqqvYgqI9sTf80Qzfht+Vlns2sZvd9bGeXBprFxaTdHen9
Hf43Nl0Uo9j7SZt17b+btB6qfb66Y1vTP9UYTlqOSb+/X+Fr0za7ms8q+Dm/
n6OgDR7HNm/yTHfzAphM2H19R3yPz5fegK7I1lr9vcjCzxL/2uf7fGwaSkvN
9EJsNbv8vkjbMp/3nM9gNmVeybPZlEFcd34O/pjYR+6ZvJvx+uqxnfwDfh/U
o3pt8PnXnW9MmQbSQm/aHHxNbG+N3pcyeKW/P6tAVWw9qz/dy0/w3e7/VrAL
vjcyr+W5ZrHd9ZoCF2N7U+WP9mjvYGR3VT2q13/HQcFr
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkD0vQ2EYhm9tkKM+XouDJuIMRomNpGjSbphsTTeDSSrxsTGRNGExEf5B
F9H6FdWk1ZKKM+uPkBCuk/cZrtznfs7z9T7R3uFuJSUphGG4nJAKaamK/o0T
QD8npe6IFKN9+IB4SjoIpH0oQxt/RzxL3i16Dw9w4qTemPQGXTjGz0PAdxpS
MIdftFgGZiDC71C/DUUosdyW9Ux6R8y7GJUW0Cub0YEBXOPX2TsHebjhgZvo
E++ZHZJqaB0aiVK/wf55KMAzfon6kD7LsAI5/AvxEv+LltfEV4l/2cxk9pHz
90ru9gMxs37RV6st2716+AG53xn2DPz8R2IVYi369OEdTvFnzvuW3e8cP+38
3QRZ+jv8mvP7hna/Vfw/d1E8uA==
          "],
          VertexColors->None], 
         Polygon3DBox[{{3416, 687, 3487, 3486, 844, 3472}, {3635, 1344, 3706, 
          3708, 1533, 3709}, {3299, 444, 3298, 3296, 255, 3225}, {3636, 1345, 
          3633, 3632, 1344, 3635}, {3826, 1776, 3827, 3824, 1753, 3812}, {
          4016, 2367, 2365, 2364, 3067, 4015}, {4327, 3101, 2560, 2562, 2563, 
          4114}, {3401, 664, 3414, 3417, 687, 3416}, {3225, 255, 3222, 3223, 
          256, 3226}, {3882, 1933, 3896, 3897, 1776, 3826}},
          VertexColors->None]}]}, 
      {RGBColor[0.9972222222222222, 0.8630555555555555, 0.5913888888888887], 
       EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtjz1LQmEYhu9TKpbmOSeahE4JtbRWk+EQNBRNLblJrYVBH2M0FLRFWylG
PyHpT2gS2haJRFHQWLjUEnS9PA031/P9kdvcWSsPSJpCgygRStdJ6diXzkek
CskiPMxIi3FpNmP5GnpOSffUrQ9JTfgaSFfE48x4CawmFlqP652Du8Tbw9Ip
vExafY85K+RK1KzCAvvO2LsAH/E7CekJ7tHzQO8+PEB32GVYSUueJ73BX9TD
Fr033FTgtjpsow3sLvyiZ566TzcDv0i85duf7t9lOErOY/4H3EYN7C0YIR97
Alb/97r9efws8Wn4zq1dbu7DHP4Y8Umo0H4+8i3namawIzSOXSX2Td0S834C
8138At4Si9hVT9tv7scT+Ae2hTvt
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtk0tLVlEUhtcnJXo8t0FS5vXTBuJYB5E1ECWERIlCcVJ+jctCG0YjrSCs
gZJF0bSZYOhP0DTNZoqIiAU1ioiKKLOel7UHD/vda5+9bnudYmn04o0yMzsN
R6A9Nes6ajYEXeilzOxyJXtYQZ/KzWoiszW4id7GNsLZNdhB/8LWE5sV4XPu
dp1fhRIcVpl1cPaP9RL7D+hCwew4fEM34aMRmqEFurE1Qky8BtbdKrdJv6xw
f+3oHdYX7Kv5LoMUjkV+dhhi/WW9Tk5vIs9lA/8/2dfxzXPu7qGbc/ehu0X0
cua5KuevuceRzwPWWe58wlaI3Id8yWcp1Lueee7KV+f67kFidh8mYDJxe3eo
Szksqgf0YopHOcv5cOi93mCw0uMqvmo5x76FmCcifxO9zWrm3+veW3RtONM3
J6Ezcd+KsYCfC7zxFd56BPrRA6lr2frQ77mzCsuwDiuRv6lqVB87c48h32fQ
+9zZKmcu4CP6YRpmCe6gp4j/hPhP4TF6C9tGucdU7LuZ91V1fsHfH3L8Dd/h
B9zD9i7ymIrdH/KVj83U564nzIdmZiH0swHmY/d5EHo3R6xXsc+eZvAZui3z
3FVDK7op91nQPNWjexPPXTWcTzyXtdBj5fRINcI0zMBo7v1TH8fQ47lr9fIW
+nXsuSlHvb3+IfVXfb7N+X9QZ3a4
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkMsuQ1EUhn8S4tL27ImQJk5pI/EChgRREomJCTFxmaLFK7iERGpCaiKm
goHEQ7i1Na3opF5AIkRCNL6VfQZf/vOvvde/1tn9K/nZXLOkJLTAdiCdt0lh
TMrCt5O+0E/4gO4m6RI9SUjHUITeVukUzdCbhkGoUqtTm4FFgqfRLEzCO5lD
ZDQ6pTNm1Z3vt5yQ3hT0BX6OzbtAr+Aa9uLSLuxAjbNGzGda9jjMM2si4et2
/of+wK/do6fIzxbQfTiI+0zLvoGQ+7foJvuUO6QSVGALv+G8t/odrOFXnf9+
hHtYx6cg4LsLeiCDH4Bk5K2edn5H2/UQLcARjLHPKExFe9q+9ob2lm/oK9Sg
zNsstUsLMAcl/DB3C/SMRBmWlWPOQ7Sb7Zh3vt9yXuCZ3Cr6FPgsy1yGCv4f
oUJLsw==
          "],
          VertexColors->None], 
         Polygon3DBox[{{4125, 2574, 2572, 3103, 2561, 4114}, {4040, 2391, 
          2389, 2388, 3071, 4039}, {4016, 2366, 3069, 2388, 2389, 4038}, {
          4328, 3105, 2572, 2574, 2575, 4126}},
          VertexColors->None]}]}, 
      {RGBColor[1, 0.95, 0.75], EdgeForm[None], 
       GraphicsGroup3DBox[{
         Polygon3DBox[{{4343, 3039, 3971}, {3398, 657, 3393}, {3652, 1370, 
          3654}, {4126, 2573, 4328}, {3804, 1746, 3809}, {3727, 1370, 3652}, {
          4205, 2757, 4203}, {2210, 2208, 3041}, {4204, 2758, 4208}, {4321, 
          3037, 4335}, {4044, 2397, 4045}, {3244, 281, 3242}, {3242, 281, 
          3317}, {4039, 2390, 4040}, {3465, 657, 3398}, {3809, 1746, 3875}, {
          2206, 2209, 3040}, {4131, 2578, 4127}},
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtUjlLA2EUnKwmJLubdaOVlbk0jbVWFjZJGkEsLMSL9B7/QRCsgoVgJR6t
neAv8KhEsbJQNNpY2ghCIDjDe8Wwk+9dM++l0tlZ2g4ATBPDQgy0iSlivQD8
8jueASaIPvl8EThkQZeYI98vGtfbAfnDCLDGug3ikfyaNRWvvyIHMUNkiGXm
fEVAi7xOXOSB3RS4C4Exop4axEeJGvlsbBqlbYjfhQTYzAIdYjGxmZp9y/wt
5vfYv8m8KnHO/mXGn3KWf5yYJmmTx8vYeiimnJfEPMqfPMjLHuvf2fOUvXIl
610j0tBmTMbmp+pviimnTBQ9R3H5lp6f1HaiXdyzd414ztl8af2IbF/KOWF+
k5pWsuZZ3ge+X2nULQLfr+rO8uax4/lH5NmS9XljvJeaLunruafv1HTq/S+1
GtVqZpf8M7IbaI766xb6rXfdTzuTdnl4Teyubb+Z4i3fUSm0WOD1uuVqwbQH
zvUf6ft95HHgvRrETWj/0Ya/1b3nP+j1Tp8=
          "],
          VertexColors->None], 
         Polygon3DBox[{{2757, 2399, 2398, 3110, 2756}, {2399, 2397, 2396, 
          3075, 2398}, {4335, 3037, 2206, 3072, 4336}, {2209, 2210, 3043, 
          2211, 3042}, {2758, 2756, 3111, 2577, 2579}, {2579, 2577, 3109, 
          2576, 2578}, {4344, 3104, 2208, 3039, 4343}, {4203, 2757, 2756, 
          2758, 4204}},
          VertexColors->None], 
         Polygon3DBox[{{4127, 2578, 2576, 3107, 2573, 4126}, {4040, 2390, 
          3073, 2396, 2397, 4044}},
          VertexColors->None]}]}}, {
      {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwt0s8qhGEUB+DvQySELCRJkyQxzKc0ZKbhFoiSjVhIGpNcgKQhK1mJkpSS
laz8KaQUZecClJ1CjT3lmVg8/Rbn7fSe04nN5EYXwyAI8pRSRjlV1NBMCzHa
GGOcSaaKqoNgTs6TJVd8p2E7nVyod8kkg6TJsECWJZZZYZU8G6yzyRbbHHPC
KWdUlARBJbXU00EnvUTsGGaXAw4555Jb7mg0aBOtxEgySIYRhkmTIiJBnG7C
sr9F/ejzzRfPllWQn3wwwjBpUqypRzJBnG7C0r+l//jvN18U+OSDd9545YUH
7rnmilmmmWSCDCn66eNJ+0fuuOGYI/bZY4gBInpooI4Kwv97+AWzNzk2
        "],
        VertexColors->None]}, 
      {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0ksrBFAYBuBDLqNcfoHETqHYmzISSTKThSRpkiRmGCXENJR/IGqyURaS
JPkBskBWshIlKSUrKSUKjyye3sWp7z232mQ6kSoIIazRURRCOzG6iNNPmgwL
LHHHPU8880NhcQhllDNbEsIcy+TYJM82O3zxTXFpCBFqqKOeBhppopkWWonS
RowpUsyQobpKl8yywurfjIgZNDNpvUW2EqWNGFOkmCHDMllWWCXHIvMkGWGQ
AQoJfOr64JEHbrn525fzTTPBOAn66KaLN/f0ygvPXHPFJedccMYpJxxzxAH7
5MiyyDyTxCv1yTFGOfQuB+yxy3tFCFsyzwbrjJJkmCF66aGz6P8//AJ1KESA

        "],
        VertexColors->None]}, 
      {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0jtrU1EAwPGTpsakEbQ4lU7BSZzESSyICAXXfgJpN6EJNHsCia+Ythr7
UFurRhGRYIJNoYRAQnTyGwhuQkZxEBUfffwuHX7874N77rnnnsxsbiYbCyGs
M0yH8DoZwhsa3DoZwjvt0KXPgG985wc/iaVCiHOcFEnSjHOas5zjPBeoUKXG
Cr+85602eE+bCXOZJEPrVAhn9CKXuMJVnrBJnVd06DLgIx/o06PNdjQWTcqU
KFIgzyfvWdAc2WiMMWPQp8cN99u6TYsmZUoUKZBngRxZ5qPnmOM615jmMlMM
fetXvvCZAb+tR0932SFxIoRF67zEMvd5wD/zqelDVvjvfDX6H+PWRkd0Q+O6
qaP6VJ+TcPxCX1LnGcdc29LHBMeP9MCY67qva7qnVf2r97TCXf44v6O3o31D
mZvJoz11CDctWUI=
        "],
        VertexColors->None]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
      {GrayLevel[0.2], CapForm["Butt"], 
       Line3DBox[{3163, 3162, 3161, 3157, 3158, 3159, 3160, 3149, 3147, 3148, 
        3145, 3146, 3155, 3156, 3150, 3151, 3152, 3153, 3154, 3181, 3179, 
        3180, 3182, 3183, 3187, 3188, 3189, 3190, 3191, 3358, 3359, 3360, 
        3361, 3362, 3368, 3369, 3370, 3371, 3372, 3429, 3430, 3431, 3432, 
        3433, 3434, 3435, 3436, 3437, 3438, 3439, 3453, 3454, 3455, 3456, 
        3457, 3458, 3459},
        VertexColors->None], 
       Line3DBox[{3256, 3255, 3257, 3258, 3259, 3260, 3261, 3262, 3276, 3277, 
        3278, 3279, 3280, 3281, 3282, 3283, 3284, 3285, 3286, 3343, 3344, 
        3345, 3346, 3347, 3353, 3354, 3355, 3356, 3357, 3515, 3516, 3517, 
        3518, 3519, 3521, 3522, 3523, 3524, 3525, 3549, 3550, 3551, 3545, 
        3546, 3547, 3548, 3552, 3553, 3554, 3539, 3540, 3543, 3544, 3542, 
        3541, 3537, 3538},
        VertexColors->None], 
       Line3DBox[{3573, 3572, 3571, 3567, 3568, 3569, 3570, 3559, 3557, 3558, 
        3555, 3556, 3565, 3566, 3560, 3561, 3562, 3563, 3564, 3591, 3589, 
        3590, 3592, 3593, 3597, 3598, 3599, 3600, 3601, 3768, 3769, 3770, 
        3771, 3772, 3778, 3779, 3780, 3781, 3782, 3839, 3840, 3841, 3842, 
        3843, 3844, 3845, 3846, 3847, 3848, 3849, 3863, 3864, 3865, 3866, 
        3867, 3868, 3869},
        VertexColors->None], 
       Line3DBox[{3665, 3666, 3667, 3668, 3669, 3670, 3671, 3672, 3686, 3687, 
        3688, 3689, 3690, 3691, 3692, 3693, 3694, 3695, 3696, 3753, 3754, 
        3755, 3756, 3757, 3763, 3764, 3765, 3766, 3767, 3925, 3926, 3927, 
        3928, 3929, 3931, 3932, 3933, 3934, 3935, 3959, 3960, 3961, 3955, 
        3956, 3957, 3958, 3962, 3963, 3964, 3949, 3950, 3953, 3954, 3952, 
        3951, 3947, 3948},
        VertexColors->None], 
       Line3DBox[{3973, 3972, 3974, 3975, 3976, 3977, 3978, 3993, 3994, 3995, 
        3996, 3997, 3998, 3999, 4000, 4001, 4002, 4003, 4004, 4005, 4072, 
        4073, 4074, 4075, 4076, 4086},
        VertexColors->None], 
       Line3DBox[{4087, 4088, 4097, 4098, 4099, 4100, 4101, 4169, 4170, 4171, 
        4172, 4173, 4174, 4175, 4176, 4177, 4178, 4179, 4180, 4181, 4197, 
        4198, 4199, 4200, 4201, 4202},
        VertexColors->None], 
       Line3DBox[{4271, 4272, 4278, 4279, 4280, 4281, 4282, 4305, 4306, 4307, 
        4308, 4309, 4303, 4304, 4313, 4314, 4312, 4310, 4311, 4302, 4300, 
        4301, 4299, 4298, 4296, 4297},
        VertexColors->None], 
       Line3DBox[{4345, 3965, 4329, 3979, 3980, 3981, 3982, 3983, 3987, 3988, 
        3989, 3990, 3991, 3992, 4025, 4066, 4067, 4068, 4069, 4070, 4071, 
        4079, 4080, 4081, 4084, 4085, 4265, 4266, 4268, 4269, 4270, 4275, 
        4273, 4274, 4276, 4277, 4261, 4262, 4293, 4294, 4291, 4292, 4295, 
        4290, 4288, 4289, 4287, 4286, 4196, 4195, 4194, 4193, 4192, 4187, 
        4186, 4185, 4184, 4183, 4182, 4146, 4107, 4106, 4105, 4104, 4103, 
        4102, 4094, 4093, 4092, 4089, 4326, 4337, 4316, 4347},
        VertexColors->None], 
       Line3DBox[{4346, 4315, 4330, 4322, 3984, 3985, 3986, 4009, 4021, 4022, 
        4024, 4026, 4034, 4035, 4037, 4054, 4077, 4078, 4082, 4083, 4263, 
        4264, 4267, 4229, 4230, 4255, 4256, 4257, 4258, 4259, 4260, 4247, 
        4248, 4285, 4284, 4283, 4191, 4190, 4189, 4188, 4163, 4150, 4149, 
        4147, 4145, 4137, 4136, 4134, 4118, 4096, 4095, 4091, 4090, 4338, 
        3966, 4348},
        VertexColors->None], 
       Line3DBox[{4349, 4317, 4331, 4323, 4006, 4008, 4010, 4012, 4023, 4027, 
        4029, 4032, 4036, 4052, 4055, 4057, 4063, 4065, 4217, 4219, 4226, 
        4227, 4228, 4251, 4252, 4253, 4254, 4244, 4245, 4246, 4242, 4241, 
        4168, 4167, 4164, 4162, 4160, 4148, 4144, 4142, 4139, 4135, 4120, 
        4117, 4115, 4110, 4108, 4339, 3968, 4353},
        VertexColors->None], 
       Line3DBox[{4350, 4318, 4332, 4324, 4007, 4011, 4013, 4018, 4028, 4030, 
        4033, 4049, 4053, 4056, 4062, 4064, 4216, 4218, 4225, 4223, 4224, 
        4249, 4250, 4237, 4238, 4243, 4240, 4239, 4166, 4165, 4161, 4159, 
        4153, 4143, 4141, 4138, 4123, 4119, 4116, 4111, 4109, 4340, 3969, 
        4354},
        VertexColors->None], 
       Line3DBox[{4351, 4319, 4333, 4325, 4014, 4017, 4019, 4020, 4031, 4048, 
        4050, 4051, 4059, 4061, 4214, 4215, 4220, 4221, 4222, 4236, 4234, 
        4235, 4233, 4232, 4158, 4157, 4154, 4152, 4151, 4140, 4124, 4122, 
        4121, 4113, 4112, 4341, 3970, 4355},
        VertexColors->None], 
       Line3DBox[{4352, 3967, 4334, 4015, 4016, 4038, 4041, 4042, 4043, 4046, 
        4058, 4060, 4213, 4206, 4207, 4211, 4212, 4209, 4210, 4231, 4156, 
        4155, 4133, 4130, 4129, 4128, 4125, 4114, 4327, 4342, 4320, 4356},
        VertexColors->None], 
       Line3DBox[{4357, 4321, 4335, 4336, 4039, 4040, 4044, 4045, 4047, 4205, 
        4203, 4204, 4208, 4132, 4131, 4127, 4126, 4328, 4344, 4343, 3971, 
        4358},
        VertexColors->None], Line3DBox[CompressedData["
1:eJwl0Ls2AnAAwOG/vUzE2imZeJAGOZ3TVujCmEpDNzwTym2pGLqK98DQG/jO
MXwP8PvFS5fZ6kYIIUc+EkKBM4qccMo1N9xSo06DFm06dOmRiIaQZI8U+xxw
SJojMhxTo06DK5q0aNOhS48pMxbMWfLFJys+GNDngXvuGPHKC8888cguO8TY
ZotNoqw1/PLDNwvmzJgy4Z03xowYcsE5JcpUIv8//wARvTHF
        "],
        VertexColors->None], 
       Line3DBox[{3175, 3176, 3205, 3206, 3200, 3201, 3202, 3203, 3204, 3227, 
        3228, 3229, 3233, 3234, 3375, 3376, 3379, 3380, 3382, 3403, 3404, 
        3405, 3409, 3421, 3423, 3424, 3445, 3446, 3447, 3526, 3527, 3501, 
        3500, 3499, 3498, 3504, 3503, 3502, 3484, 3483, 3485, 3481, 3480, 
        3340, 3339, 3336, 3335, 3333, 3312, 3311, 3310, 3306, 3294, 3292, 
        3291, 3270, 3269, 3268, 3178, 3177, 3175},
        VertexColors->None], 
       Line3DBox[{3207, 3208, 3214, 3215, 3216, 3230, 3231, 3232, 3235, 3236, 
        3377, 3378, 3381, 3383, 3395, 3410, 3412, 3413, 3422, 3425, 3427, 
        3428, 3497, 3496, 3495, 3494, 3493, 3492, 3477, 3476, 3482, 3479, 
        3478, 3338, 3337, 3334, 3332, 3320, 3305, 3303, 3302, 3293, 3290, 
        3288, 3287, 3211, 3209, 3210, 3207},
        VertexColors->None], 
       Line3DBox[{3212, 3213, 3219, 3220, 3217, 3218, 3237, 3238, 3245, 3246, 
        3247, 3384, 3385, 3386, 3394, 3396, 3411, 3415, 3418, 3420, 3426, 
        3491, 3490, 3489, 3488, 3475, 3474, 3469, 3468, 3467, 3331, 3330, 
        3329, 3321, 3319, 3304, 3300, 3297, 3295, 3289, 3212},
        VertexColors->None], 
       Line3DBox[{3222, 3221, 3296, 3298, 3301, 3315, 3318, 3324, 3327, 3463, 
        3466, 3471, 3473, 3486, 3487, 3419, 3417, 3414, 3400, 3397, 3391, 
        3387, 3252, 3249, 3241, 3239, 3224, 3223, 3222},
        VertexColors->None], 
       Line3DBox[{3226, 3225, 3299, 3314, 3316, 3322, 3325, 3328, 3460, 3461, 
        3464, 3470, 3472, 3416, 3401, 3399, 3392, 3390, 3388, 3253, 3250, 
        3248, 3243, 3240, 3226},
        VertexColors->None], 
       Line3DBox[{3244, 3242, 3317, 3323, 3326, 3462, 3465, 3398, 3393, 3389, 
        3254, 3251, 3244},
        VertexColors->None], Line3DBox[CompressedData["
1:eJwl0DdSQmEAhdHfFnkwQ1JK1qOIghYSCh8gYAGrQAsWopWpN1ABO1EXoJg9
DsVpvztzS/GoOlwLIRzwGoXwxgefLHlnIxXCJkUSrJMkQ5YceQrccc8Dj0yZ
MWfBE8+8/LfSWiSJSJEhS448BWLadOlwzAkD+vSosEOZbbaos0+NKnvscmv7
hmuuuOSCcyacccqYLh3axBzRokmDOocEfn31xTc/0erPP/76LVk=
        "],
        VertexColors->None], 
       Line3DBox[{3585, 3586, 3615, 3616, 3610, 3611, 3612, 3613, 3614, 3637, 
        3638, 3639, 3643, 3644, 3786, 3787, 3790, 3791, 3793, 3813, 3814, 
        3815, 3819, 3831, 3833, 3834, 3855, 3856, 3857, 3936, 3937, 3911, 
        3910, 3909, 3908, 3914, 3913, 3912, 3894, 3893, 3895, 3891, 3890, 
        3750, 3749, 3746, 3745, 3743, 3722, 3721, 3720, 3716, 3704, 3702, 
        3701, 3680, 3679, 3678, 3588, 3587, 3585},
        VertexColors->None], 
       Line3DBox[{3617, 3618, 3624, 3625, 3626, 3640, 3641, 3642, 3645, 3646, 
        3788, 3789, 3792, 3794, 3806, 3820, 3822, 3823, 3832, 3835, 3837, 
        3838, 3907, 3906, 3905, 3904, 3903, 3902, 3887, 3886, 3892, 3889, 
        3888, 3748, 3747, 3744, 3742, 3730, 3715, 3713, 3712, 3703, 3700, 
        3698, 3697, 3621, 3619, 3620, 3617},
        VertexColors->None], 
       Line3DBox[{3622, 3623, 3629, 3630, 3627, 3628, 3647, 3648, 3655, 3656, 
        3657, 3795, 3796, 3797, 3805, 3807, 3821, 3825, 3828, 3830, 3836, 
        3901, 3900, 3899, 3898, 3885, 3884, 3879, 3878, 3877, 3741, 3740, 
        3739, 3731, 3729, 3714, 3710, 3707, 3705, 3699, 3622},
        VertexColors->None], 
       Line3DBox[{3631, 3632, 3633, 3634, 3649, 3651, 3659, 3662, 3798, 3802, 
        3808, 3811, 3824, 3827, 3829, 3897, 3896, 3883, 3881, 3876, 3873, 
        3737, 3734, 3728, 3725, 3711, 3708, 3706, 3631},
        VertexColors->None], 
       Line3DBox[{3635, 3636, 3650, 3653, 3658, 3660, 3663, 3799, 3801, 3803, 
        3810, 3812, 3826, 3882, 3880, 3874, 3871, 3870, 3738, 3735, 3732, 
        3726, 3724, 3709, 3635},
        VertexColors->None], 
       Line3DBox[{3652, 3654, 3661, 3664, 3800, 3804, 3809, 3875, 3872, 3736, 
        3733, 3727, 3652},
        VertexColors->None]}}},
    VertexColors->CompressedData["
1:eJx0undYjn/4/09KRpLQklUpkUpDFD0JDSUz0VIaykioVKKpkiQks7REaMuo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     "]], GraphicsComplex3DBox[CompressedData["
1:eJxM3Gc419//wHEjK5E9iyRFO6slx5aMooyUlYxIg6JUiMrMTrJHqOy9HSt7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    "], {
     {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.5], EdgeForm[None], 
      Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxVnXXYldXzd0+H3S12t4JISAlIiKiIghgoNiIiWJggiKAYKCgiiIWCiAEq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         "]]],
       Lighting->"Neutral"]}, {}, {}, {}, {}},
    VertexColors->{
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143381, 0.4523915157143381, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977495`, 0.20933181110977495`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.3443927181955512, 0.3443927181955512, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.899113673809771, 0.899113673809771, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.]},
    VertexNormals->CompressedData["
1:eJztzrsJgEAQBNBBI8uwEnuwBMHYFizUIizBwEjksvMTvEkG3sIy/bSMc5Nk
65I2t6xn7QPnnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeec
v+zhnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeecc84555xz
zjnnnHPOOeecc84555xzzjnnnHPOOeecc875b33lnHPOOeecc84555xzzjnn
nHPOOeecc84555xzzjnnnHPOOeec848813t1r7Wz5E/v8b/gB/iCRMo=
     "],
    VertexTextureCoordinates->CompressedData["
1:eJxl3UHILeddx/FBcKGIoZCFuClCNy7ERaVYWnrBrrpx0W5cSWloMaAIkoUb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     "]]},
  Axes->False,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 1},
  DisplayFunction->Identity,
  Lighting->{{"Ambient", 
     GrayLevel[0.6]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]]},
  PlotRange->{{-2, 2}, {-2, 2}, {-2, 2}},
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650974201625613*^9, 3.650974825906701*^9},
 CellID->1387372852,ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<potentialSlicedPlot3D.tiff\>\""}], "}"}], "]"}], ",", 
   "potentialSlicedPlot3D", ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650974480840468*^9, 3.650974483664304*^9}, {
  3.650981215037458*^9, 3.650981220668857*^9}},
 CellID->733426262]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
ScreenStyleEnvironment->"Working",
WindowSize->{973, 874},
WindowMargins->{{182, Automatic}, {Automatic, 0}},
WindowTitle->Automatic,
Visible->True,
DockedCells->{},
TaggingRules:>{
 "WorkLifeNotebookCreationVersion" -> "3.0.0:76", "Notebook", 
  "CreatedOn[{2015, 9, 10, 21, 44, 32.057875}]", 
  "LastOpened[{2015, 9, 10, 21, 44, 32.804830}]", 
  "OpenedDate[{2015, 9, 10, 21, 44, 32.917277}]", Diary`Diary`Organization :> 
  None, "SaveBackupToolbarDockedCell", 
  "GUIDTag[40071833881492802569652320677032680713]"},
CreateCellID->True,
DefaultNewCellStyle->"Input",
FrontEndVersion->"10.2 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 6, \
2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], ShowGroupOpener -> True], 
   Cell[
    StyleData["Subsection"], ShowGroupOpener -> True], 
   Cell[
    StyleData["Subsubsection"], ShowGroupOpener -> True]}, 
  WindowSize -> {808, 905}, 
  WindowMargins -> {{132, Automatic}, {16, Automatic}}, Visible -> False, 
  FrontEndVersion -> 
  "10.2 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 6, 2015)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "DiaryDate[{2015, 9, 10, 21, 44, 32.265350}]"->{
  Cell[603, 23, 244, 7, 92, "Title",
   CellOpen->True,
   CellTags->{
    "DiaryDate[{2015, 9, 10, 21, 44, 32.265350}]", 
     "CellGUID[97660343305484732195791915835262927755]"},
   CellID->887157224]},
 "CellGUID[97660343305484732195791915835262927755]"->{
  Cell[603, 23, 244, 7, 92, "Title",
   CellOpen->True,
   CellTags->{
    "DiaryDate[{2015, 9, 10, 21, 44, 32.265350}]", 
     "CellGUID[97660343305484732195791915835262927755]"},
   CellID->887157224]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"DiaryDate[{2015, 9, 10, 21, 44, 32.265350}]", 1325757, 22796},
 {"CellGUID[97660343305484732195791915835262927755]", 1326017, 22803}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[603, 23, 244, 7, 92, "Title",
 CellOpen->True,
 CellTags->{
  "DiaryDate[{2015, 9, 10, 21, 44, 32.265350}]", 
   "CellGUID[97660343305484732195791915835262927755]"},
 CellID->887157224],
Cell[CellGroupData[{
Cell[872, 34, 116, 2, 64, "Section",
 CellID->180589747],
Cell[991, 38, 520, 9, 68, "Text",
 CellID->1893466378],
Cell[1514, 49, 159, 2, 30, "Text",
 CellID->920068908],
Cell[1676, 53, 527, 10, 69, "Text",
 CellID->230290156]
}, Open  ]],
Cell[CellGroupData[{
Cell[2240, 68, 130, 2, 64, "Section",
 CellID->1865458936],
Cell[2373, 72, 246, 5, 30, "Text",
 CellID->1654574799],
Cell[2622, 79, 205, 5, 31, "Text",
 CellID->1518235781],
Cell[CellGroupData[{
Cell[2852, 88, 444, 14, 53, "Input",
 CellID->505435398],
Cell[3299, 104, 7414, 134, 242, "Output",
 CellID->1860267114]
}, Open  ]],
Cell[10728, 241, 568, 12, 50, "Text",
 CellID->348050185],
Cell[11299, 255, 539, 13, 46, "Input",
 CellID->663446425],
Cell[11841, 270, 267, 7, 31, "Text",
 CellID->926003645],
Cell[12111, 279, 335, 7, 50, "Text",
 CellID->1739007708]
}, Open  ]],
Cell[CellGroupData[{
Cell[12483, 291, 117, 2, 64, "Section",
 CellID->1454947651],
Cell[CellGroupData[{
Cell[12625, 297, 143, 2, 44, "Subsection",
 CellID->2010225878],
Cell[CellGroupData[{
Cell[12793, 303, 185, 3, 35, "Subsubsection",
 CellID->248880934],
Cell[12981, 308, 503, 12, 50, "Input",
 CellID->858673513],
Cell[13487, 322, 649, 20, 64, "Input",
 CellID->259879548],
Cell[14139, 344, 982, 30, 64, "Input",
 CellID->312793153],
Cell[15124, 376, 549, 14, 51, "Input",
 CellID->1171745599],
Cell[15676, 392, 1750, 47, 76, "Input",
 CellID->17249391],
Cell[17429, 441, 1079, 30, 76, "Input",
 CellID->1455839901]
}, Open  ]],
Cell[CellGroupData[{
Cell[18545, 476, 192, 4, 35, "Subsubsection",
 CellID->340216895],
Cell[18740, 482, 2970, 78, 232, "Input",
 CellID->805446546],
Cell[21713, 562, 1737, 47, 114, "Input",
 CellID->814147825],
Cell[23453, 611, 284, 8, 31, "Input",
 CellID->1323435006],
Cell[23740, 621, 393, 10, 31, "Input",
 CellID->1704025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[24170, 636, 200, 5, 35, "Subsubsection",
 CellID->472502647],
Cell[24373, 643, 3316, 84, 284, "Input",
 CellID->493008203],
Cell[27692, 729, 1951, 53, 104, "Input",
 CellID->996957695],
Cell[29646, 784, 308, 9, 31, "Input",
 CellID->861970878],
Cell[29957, 795, 415, 11, 31, "Input",
 CellID->219863884]
}, Open  ]],
Cell[CellGroupData[{
Cell[30409, 811, 221, 4, 35, "Subsubsection",
 CellID->610290968],
Cell[30633, 817, 1239, 36, 91, "Input",
 CellID->116977404]
}, Open  ]],
Cell[CellGroupData[{
Cell[31909, 858, 202, 4, 35, "Subsubsection",
 CellID->1840899936],
Cell[32114, 864, 1380, 39, 91, "Input",
 CellID->1316350825],
Cell[33497, 905, 677, 21, 45, "Input",
 CellID->1562829634]
}, Open  ]],
Cell[CellGroupData[{
Cell[34211, 931, 183, 4, 35, "Subsubsection",
 CellID->817609279],
Cell[34397, 937, 1576, 45, 104, "Input",
 CellID->342221411],
Cell[35976, 984, 723, 22, 45, "Input",
 CellID->983919930]
}, Open  ]],
Cell[CellGroupData[{
Cell[36736, 1011, 417, 8, 59, "Subsubsection",
 CellID->1712598878],
Cell[37156, 1021, 5765, 148, 591, "Input",
 CellID->926021805]
}, Open  ]],
Cell[CellGroupData[{
Cell[42958, 1174, 195, 4, 35, "Subsubsection",
 CellID->1662874529],
Cell[43156, 1180, 1754, 43, 120, "Input",
 CellID->1495100134],
Cell[44913, 1225, 287, 7, 28, "Input",
 CellID->2003832896]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45261, 1239, 204, 3, 64, "Section",
 CellID->701478177],
Cell[CellGroupData[{
Cell[45490, 1246, 138, 2, 44, "Subsection",
 CellID->999040880],
Cell[45631, 1250, 267, 6, 49, "Text",
 CellID->1216818166],
Cell[CellGroupData[{
Cell[45923, 1260, 4269, 107, 380, "Input",
 CellID->1331015451],
Cell[50195, 1369, 27786, 455, 375, "Output",
 CellID->1140380999]
}, Open  ]],
Cell[77996, 1827, 563, 14, 46, "Input",
 CellID->238626571]
}, Open  ]],
Cell[CellGroupData[{
Cell[78596, 1846, 142, 2, 44, "Subsection",
 CellID->647777880],
Cell[78741, 1850, 270, 6, 30, "Text",
 CellID->2009998118],
Cell[79014, 1858, 272, 6, 30, "Text",
 CellID->131289048],
Cell[CellGroupData[{
Cell[79311, 1868, 423, 9, 28, "Input",
 CellID->1608222517],
Cell[79737, 1879, 688808, 11648, 515, "Output",
 CellID->534625233]
}, Open  ]],
Cell[768560, 13530, 514, 13, 46, "Input",
 CellID->1244809848]
}, Open  ]],
Cell[CellGroupData[{
Cell[769111, 13548, 154, 2, 44, "Subsection",
 CellID->936611601],
Cell[769268, 13552, 202, 5, 30, "Text",
 CellID->576045497],
Cell[CellGroupData[{
Cell[769495, 13561, 506, 15, 28, "Input",
 CellID->414376105],
Cell[770004, 13578, 11040, 195, 243, "Output",
 CellID->1362245277]
}, Open  ]],
Cell[781059, 13776, 140, 2, 30, "Text",
 CellID->1269442998],
Cell[CellGroupData[{
Cell[781224, 13782, 575, 16, 28, "Input",
 CellID->1778500012],
Cell[781802, 13800, 6787, 125, 243, "Output",
 CellID->933209872]
}, Open  ]],
Cell[788604, 13928, 139, 2, 30, "Text",
 CellID->2001393821],
Cell[CellGroupData[{
Cell[788768, 13934, 626, 17, 28, "Input",
 CellID->1389586586],
Cell[789397, 13953, 10657, 189, 243, "Output",
 CellID->1385244663]
}, Open  ]],
Cell[800069, 14145, 371, 7, 49, "Text",
 CellID->846380207],
Cell[CellGroupData[{
Cell[800465, 14156, 2493, 54, 250, "Input",
 CellID->766512483],
Cell[802961, 14212, 520869, 8525, 406, 459658, 7520, "CachedBoxData", \
"BoxData", "Output",
 CellID->1387372852]
}, Open  ]],
Cell[1323845, 22740, 521, 13, 46, "Input",
 CellID->733426262]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
